@@ -36,6 +36,8 @@
 #include <QTime>
 #include <QHeaderView>
 #include <QPainter>
+#include <QVBoxLayout>
+#include <QSvgRenderer>
 
 // KDE includes
 
@@ -46,20 +48,23 @@
 #include <kurl.h>
 #include <kstandarddirs.h>
 
+
 // Local includes
 
+#include "commoncontainer.h"
 #include "imagedialog.h"
+#include "advanceddialog.h"
+#include "imageslist.h"
 #include "slideshow.h"
 #include "slideshowgl.h"
 #include "slideshowkb.h"
-#include "imageslist.h"
 
 using namespace KIPIPlugins;
 
 namespace KIPIAdvancedSlideshowPlugin
 {
 
-MainDialog::MainDialog( QWidget* parent, SharedData* sharedData)
+MainDialog::MainDialog(QWidget* parent, SharedContainer* sharedData)
           : QWidget(parent)
 {
     setupUi(this);
@@ -70,7 +75,8 @@ MainDialog::MainDialog( QWidget* parent, SharedData* sharedData)
     // --------------------------------------------------------
 
     QVBoxLayout *listBoxContainerLayout = new QVBoxLayout;
-    m_ImagesFilesListBox                = new ImagesList(sharedData->interface, m_ImagesFilesListBoxContainer,
+    m_ImagesFilesListBox                = new ImagesList(m_sharedData->iface(),
+                                                         m_ImagesFilesListBoxContainer,
                                                          KIconLoader::SizeMedium);
     m_ImagesFilesListBox->listView()->header()->hide();
 
@@ -87,7 +93,7 @@ MainDialog::MainDialog( QWidget* parent, SharedData* sharedData)
     // --------------------------------------------------------
 
     // Prepare a preview pixmap (KIPI logo) for no image selection
-    QSvgRenderer svgRenderer( KStandardDirs::locate("data", "kipiplugin_advancedslideshow/KIPIicon.svg") );
+    QSvgRenderer svgRenderer( KStandardDirs::locate("data", "kipi/data/kipi-icon.svg") );
     m_noPreviewPixmap = QPixmap(ICONSIZE, ICONSIZE);
     m_noPreviewPixmap.fill(Qt::transparent);
     QPaintDevice* pdp = &m_noPreviewPixmap;
@@ -238,7 +244,7 @@ void MainDialog::showNumberImages()
     m_totalTime = totalDuration;
 
     // Notify total time is changed
-    emit totalTimeChanged(m_totalTime);
+    emit signalTotalTimeChanged(m_totalTime);
 
     m_label6->setText(i18np("%1 image [%2]", "%1 images [%2]", numberOfImages, totalDuration.toString()));
 }
@@ -346,10 +352,10 @@ void MainDialog::slotImagesFilesSelected(QTreeWidgetItem* item)
     KUrl url;
     url.setPath(pitem->url().path());
 
-    connect(m_sharedData->interface, SIGNAL(gotThumbnail( const KUrl&, const QPixmap& )),
+    connect(m_sharedData->iface(), SIGNAL(gotThumbnail(const KUrl&, const QPixmap&)),
             this, SLOT(slotThumbnail(const KUrl&, const QPixmap&)));
 
-    m_sharedData->interface->thumbnail(url, ICONSIZE);
+    m_sharedData->iface()->thumbnail(url, ICONSIZE);
 
     QModelIndex index = m_ImagesFilesListBox->listView()->currentIndex();
     if (index.isValid())
@@ -432,16 +438,16 @@ void MainDialog::slotSelection( void )
     if (m_selectedFilesButton->isChecked())
     {
         m_ImagesFilesListBox->listView()->clear();
-        urlList = m_sharedData->interface->currentSelection().images();
+        urlList = m_sharedData->iface()->currentSelection().images();
     }
     else if (m_allFilesButton->isChecked())
     {
-        KUrl currentPath = m_sharedData->interface->currentAlbum().path();
+        KUrl currentPath = m_sharedData->iface()->currentAlbum().path();
         QList<KIPI::ImageCollection> albumList;
-        albumList = m_sharedData->interface->allAlbums();
+        albumList        = m_sharedData->iface()->allAlbums();
 
         m_ImagesFilesListBox->listView()->clear();
-        urlList = m_sharedData->interface->currentAlbum().images();
+        urlList = m_sharedData->iface()->currentAlbum().images();
 
         QList<KIPI::ImageCollection>::iterator it;
         for (it = albumList.begin(); it != albumList.end(); ++it)
@@ -464,10 +470,10 @@ void MainDialog::slotSelection( void )
     m_ImagesFilesListBox->enableDragAndDrop(customize);
 }
 
-void MainDialog::slotPortfolioDurationChanged ( int )
+void MainDialog::slotPortfolioDurationChanged(int)
 {
     showNumberImages();
-    emit totalTimeChanged( m_totalTime );
+    emit signalTotalTimeChanged( m_totalTime );
 }
 
 void MainDialog::slotThumbnail(const KUrl& /*url*/, const QPixmap& pix)
@@ -477,7 +483,8 @@ void MainDialog::slotThumbnail(const KUrl& /*url*/, const QPixmap& pix)
     else
         m_previewLabel->setPixmap(pix.scaled(ICONSIZE, ICONSIZE, Qt::KeepAspectRatio));
 
-    disconnect(m_sharedData->interface, 0, this, 0);
+    disconnect(m_sharedData->iface(), 0,
+               this, 0);
 }
 
 void MainDialog::slotPrintCommentsToggled( void )
