@@ -8,7 +8,7 @@
  *
  * Copyright (C) 2006-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
  * Copyright (C) 2009      by Andi Clemens <andi dot clemens at gmx dot net>
- * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -25,9 +25,15 @@
 #include "plugin_advancedslideshow.h"
 #include "plugin_advancedslideshow.moc"
 
+// C ANSI includes
+
+extern "C"
+{
+#include <sys/time.h>
+}
+
 // C++ includes
 
-#include <ctime>
 #include <cstdlib>
 
 // Qt includes
@@ -59,6 +65,7 @@
 #include "slideshow.h"
 #include "slideshowgl.h"
 #include "slideshowkb.h"
+#include "commoncontainer.h"
 
 using namespace KIPIAdvancedSlideshowPlugin;
 
@@ -69,7 +76,7 @@ Plugin_AdvancedSlideshow::Plugin_AdvancedSlideshow(QObject *parent, const QVaria
                         : KIPI::Plugin(AdvancedSlideshowFactory::componentData(),
                                        parent, "AdvancedSlideshow")
 {
-    kDebug(51001) << "Plugin_AdvancedSlideshow plugin loaded" ;
+    kDebug(AREA_CODE_LOADING) << "Plugin_AdvancedSlideshow plugin loaded" ;
     m_sharedData = 0;
 }
 
@@ -80,7 +87,7 @@ void Plugin_AdvancedSlideshow::setup(QWidget* widget)
     m_actionSlideShow = actionCollection()->addAction("advancedslideshow");
     m_actionSlideShow->setText(i18n("Advanced Slideshow..."));
     m_actionSlideShow->setIcon(KIcon("slideshow"));
-    m_actionSlideShow->setShortcut(Qt::ALT + Qt::SHIFT + Qt::Key_F9);
+    m_actionSlideShow->setShortcut(KShortcut(Qt::ALT + Qt::SHIFT + Qt::Key_F9));
     m_actionSlideShow->setEnabled(false);
 
     connect(m_actionSlideShow, SIGNAL(triggered(bool)),
@@ -92,7 +99,7 @@ void Plugin_AdvancedSlideshow::setup(QWidget* widget)
 
     if (!m_interface)
     {
-        kError(51000) << "Kipi m_interface is null!";
+        kError() << "Kipi m_interface is null!";
         return;
     }
 
@@ -115,14 +122,14 @@ void Plugin_AdvancedSlideshow::slotActivate()
 {
     if (!m_interface)
     {
-        kError(51000) << "Kipi m_interface is null!";
+        kError() << "Kipi m_interface is null!";
         return;
     }
 
-    m_sharedData = new SharedData();
+    m_sharedData = new SharedContainer();
 
+    m_sharedData->setIface(m_interface);
     m_sharedData->showSelectedFilesOnly = true;
-    m_sharedData->interface             = m_interface;
     m_sharedData->ImagesHasComments     = m_interface->hasFeature(KIPI::ImagesHasComments);
     m_sharedData->urlList               = m_urlList;
     KIPI::ImageCollection currSel       = m_interface->currentSelection();
@@ -152,7 +159,7 @@ void Plugin_AdvancedSlideshow::slotAlbumChanged(bool anyAlbum)
 
     if (!m_interface)
     {
-        kError(51000) << "Kipi m_interface is null!";
+        kError() << "Kipi m_interface is null!";
         m_actionSlideShow->setEnabled(false);
         return;
     }
@@ -161,7 +168,7 @@ void Plugin_AdvancedSlideshow::slotAlbumChanged(bool anyAlbum)
 
     if (!currAlbum.isValid())
     {
-        kError(51000) << "Current image collection is not valid.";
+        kError() << "Current image collection is not valid.";
         m_actionSlideShow->setEnabled(false);
         return;
     }
@@ -173,7 +180,7 @@ void Plugin_AdvancedSlideshow::slotSlideShow()
 {
     if (!m_interface)
     {
-        kError(51000) << "Kipi m_interface is null!";
+        kError() << "Kipi m_interface is null!";
         return;
     }
 
@@ -264,7 +271,7 @@ KIPI::Category Plugin_AdvancedSlideshow::category(KAction* action) const
     if (action == m_actionSlideShow)
         return KIPI::ToolsPlugin;
 
-    kWarning( 51000 ) << "Unrecognized action for plugin category identification";
+    kWarning() << "Unrecognized action for plugin category identification";
 
     return KIPI::ToolsPlugin; // no warning from compiler, please
 }
