@@ -42,7 +42,16 @@
 
 // LibKIPI includes
 
+#include <libkipi/interface.h>
+
+// local includes
+
 #include "kpaboutdata.h"
+#include "commoncontainer.h"
+#include "maindialog.h"
+#include "captiondialog.h"
+#include "soundtrackdialog.h"
+#include "advanceddialog.h"
 
 namespace KIPIAdvancedSlideshowPlugin
 {
@@ -60,11 +69,11 @@ public:
     }
 
     KIPIPlugins::KPAboutData* about;
-    SharedData*               sharedData;
+    SharedContainer*          sharedData;
     KConfig*                  config;
 };
 
-SlideShowConfig::SlideShowConfig (QWidget *parent, SharedData* sharedData)
+SlideShowConfig::SlideShowConfig (QWidget *parent, SharedContainer* sharedData)
                : KPageDialog(parent), d(new SlideShowConfigPrivate)
 {
     setObjectName("Advanced Slideshow Settings");
@@ -103,14 +112,16 @@ SlideShowConfig::SlideShowConfig (QWidget *parent, SharedData* sharedData)
     d->sharedData->page_advanced->setIcon(KIcon("configure"));
 
     // --- About --
+
     d->about = new KIPIPlugins::KPAboutData(ki18n("Advanced Slideshow"),
                                             0,
                                             KAboutData::License_GPL,
                                             ki18n("A Kipi plugin for image slideshows"),
-                                            ki18n("(c) 2003-2004, Renchi Raju\n(c) 2006-2008, Valerio Fuoglio"));
+                                            ki18n("(c) 2003-2004, Renchi Raju\n"
+                                                  "(c) 2006-2008, Valerio Fuoglio"));
 
     d->about->addAuthor(ki18n( "Renchi Raju" ), ki18n("Author"),
-                        "renchi@pooh.tam.uiuc.edu");
+                        "renchi dot raju at gmail dot com");
     d->about->addAuthor(ki18n( "Valerio Fuoglio" ), ki18n("Author and maintainer"),
                         "valerio.fuoglio@gmail.com");
 
@@ -199,7 +210,7 @@ void SlideShowConfig::readSettings()
 
     if (d->sharedData->soundtrackRememberPlaylist)
     {
-        QString groupName(objectName() + " Soundtrack " + d->sharedData->interface->currentAlbum().path().path());
+        QString groupName(objectName() + " Soundtrack " + d->sharedData->iface()->currentAlbum().path().path());
         KConfigGroup soundGrp = d->config->group(groupName);
 
         // load and check playlist files, if valid, add to tracklist widget
@@ -277,7 +288,7 @@ void SlideShowConfig::saveSettings()
     // of older track entries
     if (d->sharedData->soundtrackRememberPlaylist && d->sharedData->soundtrackPlayListNeedsUpdate)
     {
-        QString groupName(objectName() + " Soundtrack " + d->sharedData->interface->currentAlbum().path().path());
+        QString groupName(objectName() + " Soundtrack " + d->sharedData->iface()->currentAlbum().path().path());
         KConfigGroup soundGrp = d->config->group(groupName);
         soundGrp.writeEntry("Tracks", d->sharedData->soundtrackUrls.toStringList());
     }
