@@ -44,23 +44,27 @@
 #include <libkdcraw/dcrawbinary.h>
 #endif
 
+// Libkipi includes
+
+#include <libkipi/interface.h>
+
 // Local includes
 
-#include "common.h"
+#include "commoncontainer.h"
 
 namespace KIPIAdvancedSlideshowPlugin
 {
 
-LoadThread::LoadThread(LoadedImages* loadedImages, QMutex* imageLock, const KUrl path,
+LoadThread::LoadThread(LoadedImages* loadedImages, QMutex* imageLock, const KUrl& path,
                        const int angle, int width, int height)
           : QThread()
 {
-    m_path          = path;
-    m_angle         = angle;
-    m_swidth        = width;
-    m_sheight       = height;
-    m_imageLock     = imageLock;
-    m_loadedImages  = loadedImages;
+    m_path         = path;
+    m_angle        = angle;
+    m_swidth       = width;
+    m_sheight      = height;
+    m_imageLock    = imageLock;
+    m_loadedImages = loadedImages;
 }
 
 LoadThread::~LoadThread()
@@ -106,8 +110,8 @@ void LoadThread::run()
 
 // -----------------------------------------------------------------------------------------
 
-SlideShowLoader::SlideShowLoader(FileList &pathList, uint cacheSize, int width, int height,
-                                 SharedData* sharedData, int beginAtIndex)
+SlideShowLoader::SlideShowLoader(FileList& pathList, uint cacheSize, int width, int height,
+                                 SharedContainer* sharedData, int beginAtIndex)
 {
     m_currIndex      = beginAtIndex;
     m_cacheSize      = cacheSize;
@@ -126,7 +130,7 @@ SlideShowLoader::SlideShowLoader(FileList &pathList, uint cacheSize, int width,
     for (uint i = 0; i < uint(m_cacheSize / 2) && i < uint(m_pathList.count()); i++)
     {
         filePath = KUrl(m_pathList[i].first);
-        angle    = m_sharedData->interface->info(filePath).angle();
+        angle    = m_sharedData->iface()->info(filePath).angle();
 
         LoadThread* newThread = new LoadThread(m_loadedImages, m_imageLock,
                                                filePath, angle, m_swidth, m_sheight);
@@ -140,7 +144,7 @@ SlideShowLoader::SlideShowLoader(FileList &pathList, uint cacheSize, int width,
     {
         int toLoad = (m_currIndex - i) % m_pathList.count();
         filePath   = KUrl(m_pathList[toLoad].first);
-        angle      = m_sharedData->interface->info(filePath).angle();
+        angle      = m_sharedData->iface()->info(filePath).angle();
 
         LoadThread* newThread = new LoadThread(m_loadedImages, m_imageLock,
                                                filePath, angle, m_swidth, m_sheight);
@@ -172,7 +176,6 @@ SlideShowLoader::~SlideShowLoader()
     delete m_loadingThreads;
     delete m_imageLock;
     delete m_threadLock;
-
 }
 
 void SlideShowLoader::next()
@@ -200,7 +203,7 @@ void SlideShowLoader::next()
     m_threadLock->unlock();
 
     KUrl filePath = KUrl(m_pathList[newBorn].first);
-    int  angle    = m_sharedData->interface->info(filePath).angle();
+    int  angle    = m_sharedData->iface()->info(filePath).angle();
 
     LoadThread* newThread = new LoadThread(m_loadedImages, m_imageLock,
                                            filePath, angle, m_swidth, m_sheight);
@@ -240,7 +243,7 @@ void SlideShowLoader::prev()
     m_threadLock->unlock();
 
     KUrl filePath = KUrl(m_pathList[newBorn].first);
-    int  angle    = m_sharedData->interface->info(filePath).angle();
+    int  angle    = m_sharedData->iface()->info(filePath).angle();
 
     LoadThread* newThread = new LoadThread(m_loadedImages, m_imageLock,
                                            filePath, angle, m_swidth, m_sheight);
@@ -290,7 +293,7 @@ void SlideShowLoader::checkIsIn(int index)
     else
     {
         KUrl filePath = KUrl(m_pathList[index].first);
-        int  angle    = m_sharedData->interface->info(filePath).angle();
+        int  angle    = m_sharedData->iface()->info(filePath).angle();
 
         LoadThread* newThread = new LoadThread(m_loadedImages, m_imageLock,
                                                filePath, angle, m_swidth, m_sheight);
