@@ -176,14 +176,10 @@ void ImagesListView::setup(int iconSize)
     m_iconSize = iconSize;
     setIconSize(QSize(m_iconSize, m_iconSize));
     setAlternatingRowColors(true);
-    setSelectionMode(QAbstractItemView::SingleSelection);
-
-    setDragEnabled(true);
-    viewport()->setAcceptDrops(true);
-    setDragDropMode(QAbstractItemView::InternalMove);
-    setDragDropOverwriteMode(false);
-    setDropIndicatorShown(true);
+    setSelectionMode(QAbstractItemView::ExtendedSelection);
 
+    enableDragAndDrop(true);
+    
     setSortingEnabled(false);
     setAllColumnsShowFocus(true);
     setRootIsDecorated(false);
@@ -216,6 +212,15 @@ void ImagesListView::setup(int iconSize)
             this, SLOT(slotItemClicked(QTreeWidgetItem*, int)));
 }
 
+void ImagesListView::enableDragAndDrop(const bool enable)
+{
+    setDragEnabled(enable);
+    viewport()->setAcceptDrops(enable);
+    setDragDropMode(enable ? QAbstractItemView::InternalMove : QAbstractItemView::NoDragDrop);
+    setDragDropOverwriteMode(enable);
+    setDropIndicatorShown(enable);
+}
+
 void ImagesListView::slotItemClicked(QTreeWidgetItem* item, int column)
 {
     Q_UNUSED(column)
@@ -311,7 +316,6 @@ public:
     {
         listView              = 0;
         iface                 = 0;
-
         addButton             = 0;
         removeButton          = 0;
         moveUpButton          = 0;
@@ -319,7 +323,6 @@ public:
         clearButton           = 0;
         loadButton            = 0;
         saveButton            = 0;
-
         iconSize              = DEFAULTSIZE;
         allowRAW              = true;
         controlButtonsEnabled = true;
@@ -352,7 +355,7 @@ ImagesList::ImagesList(Interface *iface, QWidget* parent, int iconSize)
     // --------------------------------------------------------
 
     d->listView  = new ImagesListView(d->iconSize, this);
-    d->listView->setSelectionMode(QAbstractItemView::SingleSelection);
+    d->listView->setSelectionMode(QAbstractItemView::ExtendedSelection);
 
     // --------------------------------------------------------
 
@@ -376,6 +379,7 @@ ImagesList::ImagesList(Interface *iface, QWidget* parent, int iconSize)
 
     setControlButtons(Add|Remove|MoveUp|MoveDown|Clear);      // add all buttons       (default)
     setControlButtonsPlacement(ControlButtonsRight);          // buttons on the right  (default)
+    enableDragAndDrop(true);                                  // enable drag and drop  (default)
 
     // --------------------------------------------------------
 
@@ -388,9 +392,16 @@ ImagesList::ImagesList(Interface *iface, QWidget* parent, int iconSize)
     connect(d->listView, SIGNAL(signalItemClicked(QTreeWidgetItem*)),
             this, SIGNAL(signalItemClicked(QTreeWidgetItem*)));
 
+    // queue this connection because itemSelectionChanged is emitted
+    // while items are deleted, and accessing selectedItems at that
+    // time causes a crash ...
+    connect(d->listView, SIGNAL(itemSelectionChanged()),
+            this, SLOT(slotImageListChanged()), Qt::QueuedConnection);
+
     connect(this, SIGNAL(signalImageListChanged()),
             this, SLOT(slotImageListChanged()));
 
+
     // --------------------------------------------------------
 
     connect(d->addButton, SIGNAL(clicked()),
@@ -425,6 +436,11 @@ void ImagesList::enableControlButtons(bool enable)
     slotImageListChanged();
 }
 
+void ImagesList::enableDragAndDrop(const bool enable)
+{
+    d->listView->enableDragAndDrop(enable);
+}
+
 void ImagesList::setControlButtonsPlacement(ControlButtonPlacement placement)
 {
     delete layout();
@@ -615,12 +631,11 @@ void ImagesList::slotAddItems()
 
 void ImagesList::slotRemoveItems()
 {
-    QTreeWidgetItemIterator it(d->listView, QTreeWidgetItemIterator::Selected);
-    while (*it)
+    QList<QTreeWidgetItem*> selectedItemsList = d->listView->selectedItems();
+    for (QList<QTreeWidgetItem*>::const_iterator it = selectedItemsList.constBegin(); it!=selectedItemsList.constEnd(); ++it)
     {
-        ImagesListViewItem* item = dynamic_cast<ImagesListViewItem*>(*it);
-        ++it;
-        delete item;
+        d->listView->removeItemWidget( *it, 0);
+        delete *it;
     }
     emit signalImageListChanged();
 }
@@ -663,14 +678,6 @@ void ImagesList::slotClearItems()
     slotRemoveItems();
 }
 
-void ImagesList::slotLoadItems()
-{
-}
-
-void ImagesList::slotSaveItems()
-{
-}
-
 void ImagesList::removeItemByUrl(const KUrl& url)
 {
     bool found;
@@ -731,19 +738,23 @@ bool ImagesList::isRAWFile(const QString & filePath)
 
 void ImagesList::slotImageListChanged()
 {
-    bool enable = !(imageUrls().isEmpty()) && d->controlButtonsEnabled;
+    const QList<QTreeWidgetItem*> selectedItemsList = d->listView->selectedItems();
+    const bool haveImages               = !(imageUrls().isEmpty()) && d->controlButtonsEnabled;
+    const bool haveSelectedImages       = !(selectedItemsList.isEmpty()) && d->controlButtonsEnabled;
+    const bool haveOnlyOneSelectedImage = (selectedItemsList.count()==1) && d->controlButtonsEnabled;
 
-    d->addButton->setEnabled(enable);
-    d->removeButton->setEnabled(enable);
-    d->moveUpButton->setEnabled(enable);
-    d->moveDownButton->setEnabled(enable);
-    d->clearButton->setEnabled(enable);
-    d->loadButton->setEnabled(enable);
-    d->saveButton->setEnabled(enable);
+    d->removeButton->setEnabled(haveSelectedImages);
+    d->moveUpButton->setEnabled(haveOnlyOneSelectedImage);
+    d->moveDownButton->setEnabled(haveOnlyOneSelectedImage);
+    d->clearButton->setEnabled(haveImages);
 
     // All buttons are enabled / disabled now, but the "Add" button should always be
     // enabled, if the buttons are not explicitly disabled with enableControlButtons()
     d->addButton->setEnabled(d->controlButtonsEnabled);
+
+    // TODO: load and save are not yet implemented, when should they be enabled/disabled?
+    d->loadButton->setEnabled(d->controlButtonsEnabled);
+    d->saveButton->setEnabled(d->controlButtonsEnabled);
 }
 
 }  // namespace KIPIPlugins
