@@ -218,11 +218,11 @@ BatchDialog::BatchDialog(KIPI::Interface* iface, DNGConverterAboutData *about)
     connect(this, SIGNAL(user2Clicked()),
             this, SLOT(slotRemoveItems()));
 
-    connect(d->thread, SIGNAL(starting(const ActionData&)),
-            this, SLOT(slotAction(const ActionData&)));
+    connect(d->thread, SIGNAL(starting(const KIPIDNGConverterPlugin::ActionData&)),
+            this, SLOT(slotAction(const KIPIDNGConverterPlugin::ActionData&)));
 
-    connect(d->thread, SIGNAL(finished(const ActionData&)),
-            this, SLOT(slotAction(const ActionData&)));
+    connect(d->thread, SIGNAL(finished(const KIPIDNGConverterPlugin::ActionData&)),
+            this, SLOT(slotAction(const KIPIDNGConverterPlugin::ActionData&)));
 
     if (d->iface)
     {
@@ -254,6 +254,7 @@ void BatchDialog::closeEvent(QCloseEvent *e)
     // Stop current conversion if necessary
     if (d->busy) slotStartStop();
     saveSettings();
+    d->listView->clear();
     e->accept();
 }
 
@@ -262,6 +263,7 @@ void BatchDialog::slotClose()
     // Stop current conversion if necessary
     if (d->busy) slotStartStop();
     saveSettings();
+    d->listView->clear();
     done(Close);
 }
 
@@ -277,6 +279,7 @@ void BatchDialog::readSettings()
 
     d->settingsBox->setBackupOriginalRawFile(group.readEntry("BackupOriginalRawFile", false));
     d->settingsBox->setCompressLossLess(group.readEntry("CompressLossLess", true));
+    d->settingsBox->setUpdateFileDate(group.readEntry("UpdateFileDate", false));
     d->settingsBox->setCompressLossLess(group.readEntry("PreviewMode", (int)(DNGWriter::MEDIUM)));
     d->settingsBox->setConflictRule(
         (SettingsWidget::ConflictRule)group.readEntry("Conflict",
@@ -293,6 +296,7 @@ void BatchDialog::saveSettings()
 
     group.writeEntry("BackupOriginalRawFile", d->settingsBox->backupOriginalRawFile());
     group.writeEntry("CompressLossLess",      d->settingsBox->compressLossLess());
+    group.writeEntry("UpdateFileDate",        d->settingsBox->updateFileDate());
     group.writeEntry("PreviewMode",           (int)d->settingsBox->previewMode());
     group.writeEntry("Conflict",              (int)d->settingsBox->conflictRule());
 
@@ -448,9 +452,12 @@ void BatchDialog::processOne()
     d->thread->setBackupOriginalRawFile(d->settingsBox->backupOriginalRawFile());
     d->thread->setCompressLossLess(d->settingsBox->compressLossLess());
     d->thread->setPreviewMode(d->settingsBox->previewMode());
+    d->thread->setUpdateFileDate(d->settingsBox->updateFileDate());
     d->thread->processRawFile(KUrl(file));
     if (!d->thread->isRunning())
+    {
         d->thread->start();
+    }
 }
 
 void BatchDialog::busy(bool busy)
@@ -577,7 +584,7 @@ void BatchDialog::processingFailed(const KUrl& /*url*/)
     d->currentConvertItem = 0;
 }
 
-void BatchDialog::slotAction(const ActionData& ad)
+void BatchDialog::slotAction(const KIPIDNGConverterPlugin::ActionData& ad)
 {
     QString text;
 
@@ -596,7 +603,7 @@ void BatchDialog::slotAction(const ActionData& ad)
             }
             default:
             {
-                kWarning(51000) << "KIPIDNGConverterPlugin: Unknown action";
+                kWarning() << "KIPIDNGConverterPlugin: Unknown action";
                 break;
             }
         }
@@ -618,7 +625,7 @@ void BatchDialog::slotAction(const ActionData& ad)
                 }
                 default:
                 {
-                    kWarning(51000) << "KIPIDNGConverterPlugin: Unknown action";
+                    kWarning() << "KIPIDNGConverterPlugin: Unknown action";
                     break;
                 }
             }
@@ -657,7 +664,7 @@ void BatchDialog::slotAction(const ActionData& ad)
                 }
                 default:
                 {
-                    kWarning(51000) << "KIPIDNGConverterPlugin: Unknown action";
+                    kWarning() << "KIPIDNGConverterPlugin: Unknown action";
                     break;
                 }
             }
