@@ -23,10 +23,6 @@
 #include "plugin_dngconverter.h"
 #include "plugin_dngconverter.moc"
 
-// Qt includes
-
-#include <QFileInfo>
-
 // KDE includes
 
 #include <kaction.h>
@@ -38,11 +34,7 @@
 #include <klibloader.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-
-// LibKDcraw includes
-
-#include <libkdcraw/kdcraw.h>
-#include <libkdcraw/version.h>
+#include <kwindowsystem.h>
 
 // LibKIPI includes
 
@@ -58,14 +50,16 @@ using namespace KIPIDNGConverterPlugin;
 K_PLUGIN_FACTORY( RawConverterFactory, registerPlugin<Plugin_DNGConverter>(); )
 K_EXPORT_PLUGIN ( RawConverterFactory("kipiplugin_dngconverter") )
 
-Plugin_DNGConverter::Plugin_DNGConverter(QObject *parent, const QVariantList &)
+Plugin_DNGConverter::Plugin_DNGConverter(QObject* parent, const QVariantList&)
                    : KIPI::Plugin( RawConverterFactory::componentData(), parent, "DNGConverter")
 {
-    kDebug(51001) << "Plugin_DNGConverter plugin loaded" ;
+    kDebug(AREA_CODE_LOADING) << "Plugin_DNGConverter plugin loaded" ;
 }
 
 void Plugin_DNGConverter::setup( QWidget* widget )
 {
+    m_batchDlg = 0;
+
     KIPI::Plugin::setup( widget );
 
     m_action = actionCollection()->addAction("dngconverter");
@@ -78,10 +72,10 @@ void Plugin_DNGConverter::setup( QWidget* widget )
     addAction(m_action);
 
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>( parent() );
-    if ( !interface )
+    if (!interface)
     {
-           kError( 51000 ) << "Kipi interface is null!";
-           return;
+        kError() << "Kipi interface is null!";
+        return;
     }
 
     connect(interface, SIGNAL(currentAlbumChanged(bool)),
@@ -92,26 +86,12 @@ Plugin_DNGConverter::~Plugin_DNGConverter()
 {
 }
 
-bool Plugin_DNGConverter::isRAWFile(const QString& filePath)
-{
-
-    QString rawFilesExt(KDcrawIface::KDcraw::rawFiles());
-    QFileInfo fileInfo(filePath);
-    if (fileInfo.suffix().toUpper() != QString("DNG"))
-    {
-        if (rawFilesExt.toUpper().contains( fileInfo.suffix().toUpper() ))
-            return true;
-    }
-
-    return false;
-}
-
 void Plugin_DNGConverter::slotActivate()
 {
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>( parent() );
     if (!interface)
     {
-        kError( 51000 ) << "Kipi interface is null!" ;
+        kError() << "Kipi interface is null!" ;
         return;
     }
 
@@ -121,19 +101,29 @@ void Plugin_DNGConverter::slotActivate()
     if (!images.isValid())
         return;
 
-    BatchDialog *converter = new BatchDialog(interface, new DNGConverterAboutData);
-
     KUrl::List urls = images.images();
     KUrl::List items;
 
     for( KUrl::List::Iterator it = urls.begin(); it != urls.end(); ++it )
     {
-        if (isRAWFile((*it).path()))
+        if (DNGConverterAboutData::isRAWFile((*it).path()))
             items.append((*it));
     }
 
-    converter->addItems(items);
-    converter->show();
+    if (!m_batchDlg)
+    {
+        m_batchDlg = new BatchDialog(interface, new DNGConverterAboutData);
+    }
+    else
+    {
+        if (m_batchDlg->isMinimized())
+            KWindowSystem::unminimizeWindow(m_batchDlg->winId());
+
+        KWindowSystem::activateWindow(m_batchDlg->winId());
+    }
+
+    m_batchDlg->show();
+    m_batchDlg->addItems(items);
 }
 
 KIPI::Category Plugin_DNGConverter::category( KAction* action ) const
@@ -141,6 +131,6 @@ KIPI::Category Plugin_DNGConverter::category( KAction* action ) const
     if (action == m_action)
        return KIPI::BatchPlugin;
 
-    kWarning( 51000 ) << "Unrecognized action for plugin category identification" ;
+    kWarning() << "Unrecognized action for plugin category identification" ;
     return KIPI::BatchPlugin; // no warning from compiler, please
 }
