@@ -7,7 +7,7 @@
  * Description : a kipi plugin to import/export images to Facebook web service
  *
  * Copyright (C) 2005-2008 by Vardhman Jain <vardhman at gmail dot com>
- * Copyright (C) 2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2008-2009 by Luka Renko <lure at kubuntu dot org>
  *
  * This program is free software; you can redistribute it
@@ -26,11 +26,14 @@
 #include "fbwindow.moc"
 
 // Qt includes
+
 #include <QFileInfo>
 #include <QSpinBox>
 #include <QCheckBox>
+#include <QCloseEvent>
 
 // KDE includes
+
 #include <KDebug>
 #include <KConfig>
 #include <KLocale>
@@ -44,9 +47,11 @@
 #include <KToolInvocation>
 
 // LibKExiv2 includes
+
 #include <libkexiv2/kexiv2.h>
 
 // LibKDcraw includes
+
 #include <libkdcraw/version.h>
 #include <libkdcraw/kdcraw.h>
 
@@ -55,12 +60,14 @@
 #endif
 
 // LibKIPI includes
+
 #include <libkipi/interface.h>
 #include "imageslist.h"
 #include "kpaboutdata.h"
 #include "pluginsversion.h"
 
 // Local includes
+
 #include "fbitem.h"
 #include "fbtalker.h"
 #include "fbwidget.h"
@@ -70,16 +77,16 @@ namespace KIPIFacebookPlugin
 {
 
 FbWindow::FbWindow(KIPI::Interface* interface, const QString &tmpFolder,
-                   bool import, QWidget *parent)
-            : KDialog(parent)
+                   bool import, QWidget* /*parent*/)
+        : KDialog(0)
 {
     m_tmpPath.clear();
-    m_tmpDir                 = tmpFolder;
-    m_interface              = interface;
-    m_import                 = import;
-    m_imagesCount            = 0;
-    m_imagesTotal            = 0;
-    m_widget                 = new FbWidget(this, interface, import);
+    m_tmpDir      = tmpFolder;
+    m_interface   = interface;
+    m_import      = import;
+    m_imagesCount = 0;
+    m_imagesTotal = 0;
+    m_widget      = new FbWidget(this, interface, import);
 
     setMainWidget(m_widget);
     setWindowIcon(KIcon("facebook"));
@@ -104,6 +111,7 @@ FbWindow::FbWindow(KIPI::Interface* interface, const QString &tmpFolder,
         m_widget->setMinimumSize(700, 500);
     }
 
+    // ------------------------------------------------------------------------
 
     connect(m_widget->m_imgList, SIGNAL( signalImageListChanged()),
             this, SLOT( slotImageListChanged()) );
@@ -127,12 +135,13 @@ FbWindow::FbWindow(KIPI::Interface* interface, const QString &tmpFolder,
             this, SLOT( slotStartTransfer()) );
 
     // ------------------------------------------------------------------------
+
     m_about = new KIPIPlugins::KPAboutData(ki18n("Facebook Import/Export"), 0,
                       KAboutData::License_GPL,
                       ki18n("A Kipi plugin to import/export image collection "
                             "to/from Facebook web service."),
                       ki18n("(c) 2005-2008, Vardhman Jain\n"
-                            "(c) 2008, Gilles Caulier\n"
+                            "(c) 2008-2009, Gilles Caulier\n"
                             "(c) 2008-2009, Luka Renko"));
 
     m_about->addAuthor(ki18n("Luka Renko"), ki18n("Author and maintainer"),
@@ -187,13 +196,11 @@ FbWindow::FbWindow(KIPI::Interface* interface, const QString &tmpFolder,
     connect(m_talker, SIGNAL( signalListFriendsDone(int, const QString&, const QList <FbUser>&) ),
             this, SLOT( slotListFriendsDone(int, const QString&, const QList <FbUser>&) ));
 
-
     // ------------------------------------------------------------------------
 
-
     readSettings();
 
-    kDebug(51000) << "Calling Login method";
+    kDebug() << "Calling Login method";
     buttonStateChange(m_talker->loggedIn());
     authenticate();
 }
@@ -204,12 +211,39 @@ FbWindow::~FbWindow()
     delete m_about;
 }
 
+void FbWindow::slotHelp()
+{
+    KToolInvocation::invokeHelp("facebook", "kipi-plugins");
+}
+
+void FbWindow::slotClose()
+{
+    writeSettings();
+    m_widget->imagesList()->listView()->clear();
+    done(Close);
+}
+
+void FbWindow::reactivate()
+{
+    m_widget->imagesList()->loadImagesFromCurrentSelection();
+    show();
+}
+
+void FbWindow::closeEvent(QCloseEvent *e)
+{
+    if (!e) return;
+
+    writeSettings();
+    m_widget->imagesList()->listView()->clear();
+    e->accept();
+}
+
 void FbWindow::readSettings()
 {
     KConfig config("kipirc");
     KConfigGroup grp = config.group("Facebook Settings");
-    m_sessionKey = grp.readEntry("Session Key");
-    m_sessionSecret = grp.readEntry("Session Secret");
+    m_sessionKey     = grp.readEntry("Session Key");
+    m_sessionSecret  = grp.readEntry("Session Secret");
     m_sessionExpires = grp.readEntry("Session Expires", 0);
     m_currentAlbumID = grp.readEntry("Current Album", -1LL);
 
@@ -244,13 +278,13 @@ void FbWindow::writeSettings()
 {
     KConfig config("kipirc");
     KConfigGroup grp = config.group("Facebook Settings");
-    grp.writeEntry("Session Key", m_sessionKey);
-    grp.writeEntry("Session Secret", m_sessionSecret);
+    grp.writeEntry("Session Key",     m_sessionKey);
+    grp.writeEntry("Session Secret",  m_sessionSecret);
     grp.writeEntry("Session Expires", m_sessionExpires);
-    grp.writeEntry("Current Album", m_currentAlbumID);
-    grp.writeEntry("Resize", m_widget->m_resizeChB->isChecked());
-    grp.writeEntry("Maximum Width",  m_widget->m_dimensionSpB->value());
-    grp.writeEntry("Image Quality",  m_widget->m_imageQualitySpB->value());
+    grp.writeEntry("Current Album",   m_currentAlbumID);
+    grp.writeEntry("Resize",          m_widget->m_resizeChB->isChecked());
+    grp.writeEntry("Maximum Width",   m_widget->m_dimensionSpB->value());
+    grp.writeEntry("Image Quality",   m_widget->m_imageQualitySpB->value());
     if (m_import)
     {
         KConfigGroup dialogGroup = config.group("Facebook Import Dialog");
@@ -275,23 +309,11 @@ void FbWindow::authenticate()
     connect(m_authProgressDlg, SIGNAL( cancelClicked() ),
             this, SLOT( slotLoginCancel() ));
 
-    kDebug(51000) << "Calling Login method";
+    kDebug() << "Calling Login method";
     m_talker->authenticate(m_sessionKey, m_sessionSecret, m_sessionExpires);
 }
 
-void FbWindow::slotHelp()
-{
-    KToolInvocation::invokeHelp("facebook", "kipi-plugins");
-}
-
-void FbWindow::slotClose()
-{
-    writeSettings();
-
-    done(Close);
-}
-
-void FbWindow::slotLoginProgress(int step, int maxStep, const QString &label)
+void FbWindow::slotLoginProgress(int step, int maxStep, const QString& label)
 {
     if (!m_authProgressDlg)
         return;
@@ -305,7 +327,7 @@ void FbWindow::slotLoginProgress(int step, int maxStep, const QString &label)
     m_authProgressDlg->progressBar()->setValue(step);
 }
 
-void FbWindow::slotLoginDone(int errCode, const QString &errMsg)
+void FbWindow::slotLoginDone(int errCode, const QString& errMsg)
 {
     m_authProgressDlg->hide();
 
@@ -317,8 +339,8 @@ void FbWindow::slotLoginDone(int errCode, const QString &errMsg)
     if (!m_import)
         m_widget->m_albumsCoB->addItem(i18n("<auto create>"), 0);
 
-    m_sessionKey = m_talker->getSessionKey();
-    m_sessionSecret = m_talker->getSessionSecret();
+    m_sessionKey     = m_talker->getSessionKey();
+    m_sessionSecret  = m_talker->getSessionSecret();
     m_sessionExpires = m_talker->getSessionExpires();
 
     if (errCode == 0 && m_talker->loggedIn())
@@ -334,7 +356,7 @@ void FbWindow::slotLoginDone(int errCode, const QString &errMsg)
     }
 }
 
-void FbWindow::slotChangePermDone(int errCode, const QString &errMsg)
+void FbWindow::slotChangePermDone(int errCode, const QString& errMsg)
 {
     if (errCode == 0)
     {
@@ -347,9 +369,17 @@ void FbWindow::slotChangePermDone(int errCode, const QString &errMsg)
     }
 }
 
-void FbWindow::slotListAlbumsDone(int errCode, const QString &errMsg,
-                                  const QList <FbAlbum>& albumsList)
+void FbWindow::slotListAlbumsDone(int errCode, const QString& errMsg, const QList <FbAlbum>& albumsList)
 {
+
+    QString albumDebug = "";
+    foreach(FbAlbum album, albumsList)
+    {
+        albumDebug.append(QString::number(album.id) + ": " + album.title + "\n");
+    }
+    kDebug() << "Received albums (errCode = " << errCode << ", errMsg = "
+                  << errMsg << "): " << albumDebug;
+
     if (errCode != 0)
     {
         KMessageBox::error(this, i18n("Facebook Call Failed: %1\n", errMsg));
@@ -368,6 +398,7 @@ void FbWindow::slotListAlbumsDone(int errCode, const QString &errMsg,
     {
         m_widget->m_albumsCoB->addItem(i18n("<auto create>"), 0);
     }
+
     for (int i = 0; i < albumsList.size(); ++i)
     {
         QString albumIcon;
@@ -395,8 +426,7 @@ void FbWindow::slotListAlbumsDone(int errCode, const QString &errMsg,
     }
 }
 
-void FbWindow::slotListPhotosDone(int errCode, const QString &errMsg,
-                                  const QList <FbPhoto>& photosList)
+void FbWindow::slotListPhotosDone(int errCode, const QString& errMsg, const QList <FbPhoto>& photosList)
 {
     if (errCode != 0)
     {
@@ -430,8 +460,7 @@ void FbWindow::slotListPhotosDone(int errCode, const QString &errMsg,
     downloadNextPhoto();
 }
 
-void FbWindow::slotListFriendsDone(int errCode, const QString &errMsg,
-                                   const QList <FbUser>& friendsList)
+void FbWindow::slotListFriendsDone(int errCode, const QString& errMsg, const QList <FbUser>& friendsList)
 {
     if (errCode != 0)
     {
@@ -476,7 +505,7 @@ void FbWindow::slotBusy(bool val)
 
 void FbWindow::slotUserChangeRequest()
 {
-    kDebug(51000) << "Slot Change User Request";
+    kDebug() << "Slot Change User Request";
 
     if (m_talker->loggedIn())
     {
@@ -491,15 +520,15 @@ void FbWindow::slotUserChangeRequest()
 
 void FbWindow::slotPermChangeRequest()
 {
-    kDebug(51000) << "Slot Change Permission Request";
+    kDebug() << "Slot Change Permission Request";
 
-    kDebug(51000) << "Calling Login method";
+    kDebug() << "Calling Login method";
     m_talker->changePerm();
 }
 
 void FbWindow::slotReloadAlbumsRequest(long long userID)
 {
-    kDebug(51000) << "Reload Albums Request for UID:" << userID;
+    kDebug() << "Reload Albums Request for UID:" << userID;
     if (userID == 0)
     {
         FbUser user = m_talker->getUser();
@@ -515,11 +544,11 @@ void FbWindow::slotReloadAlbumsRequest(long long userID)
 
 void FbWindow::slotNewAlbumRequest()
 {
-    kDebug(51000) << "Slot New Album Request";
+    kDebug() << "Slot New Album Request";
 
     if (m_albumDlg->exec() == QDialog::Accepted)
     {
-        kDebug(51000) << "Calling New Album method";
+        kDebug() << "Calling New Album method";
         FbAlbum newAlbum;
         m_albumDlg->getAlbumProperties(newAlbum);
         m_talker->createAlbum(newAlbum);
@@ -534,7 +563,7 @@ void FbWindow::slotLoginCancel()
 
 void FbWindow::slotStartTransfer()
 {
-    kDebug(51000) << "slotStartTransfer invoked";
+    kDebug() << "slotStartTransfer invoked";
 
     if (m_import)
     {
@@ -549,6 +578,7 @@ void FbWindow::slotStartTransfer()
 
         m_currentAlbumID = m_widget->m_albumsCoB->itemData(
                                    m_widget->m_albumsCoB->currentIndex()).toLongLong();
+        kDebug() << "upload request got album id from widget: " << m_currentAlbumID;
         m_imagesTotal = m_transferQueue.count();
         m_imagesCount = 0;
 
@@ -611,17 +641,18 @@ QString FbWindow::getImageCaption(const KExiv2Iface::KExiv2& ev)
     return caption;
 }
 
-bool FbWindow::prepareImageForUpload(const QString& imgPath, bool isRAW,
-                                     QString &caption)
+bool FbWindow::prepareImageForUpload(const QString& imgPath, bool isRAW, QString& caption)
 {
     QImage image;
     if (isRAW)
     {
-        kDebug(51000) << "Get RAW preview " << imgPath;
+        kDebug() << "Get RAW preview " << imgPath;
         KDcrawIface::KDcraw::loadDcrawPreview(image, imgPath);
     }
     else
+    {
         image.load(imgPath);
+    }
 
     if (image.isNull())
         return false;
@@ -632,14 +663,14 @@ bool FbWindow::prepareImageForUpload(const QString& imgPath, bool isRAW,
     // rescale image if requested
     int maxDim = m_widget->m_dimensionSpB->value();
     if (m_widget->m_resizeChB->isChecked()
-        && (image.width() > maxDim || image.width() > maxDim))
+        && (image.width() > maxDim || image.height() > maxDim))
     {
-        kDebug(51000) << "Resizing to " << maxDim;
+        kDebug() << "Resizing to " << maxDim;
         image = image.scaled(maxDim, maxDim, Qt::KeepAspectRatio,
                                              Qt::SmoothTransformation);
     }
 
-    kDebug(51000) << "Saving to temp file: " << m_tmpPath;
+    kDebug() << "Saving to temp file: " << m_tmpPath;
     image.save(m_tmpPath, "JPEG", m_widget->m_imageQualitySpB->value());
 
     // copy meta data to temporary image
@@ -652,7 +683,9 @@ bool FbWindow::prepareImageForUpload(const QString& imgPath, bool isRAW,
         exiv2Iface.save(m_tmpPath);
     }
     else
+    {
         caption.clear();
+    }
 
     return true;
 }
@@ -692,10 +725,12 @@ void FbWindow::uploadNextPhoto()
     else
     {
         KExiv2Iface::KExiv2 exiv2Iface;
+
         if (exiv2Iface.load(imgPath))
             caption = getImageCaption(exiv2Iface);
         else
             caption.clear();
+
         m_tmpPath.clear();
         res = m_talker->addPhoto(imgPath, m_currentAlbumID, caption);
     }
@@ -761,8 +796,7 @@ void FbWindow::downloadNextPhoto()
     m_progressDlg->setLabelText(i18n("Downloading file %1", imgPath));
 }
 
-void FbWindow::slotGetPhotoDone(int errCode, const QString& errMsg,
-                                const QByteArray& photoData)
+void FbWindow::slotGetPhotoDone(int errCode, const QString& errMsg, const QByteArray& photoData)
 {
     QString imgPath = m_widget->getDestinationPath() + '/'
                       + QFileInfo(m_transferQueue.first().path()).fileName();
@@ -781,7 +815,9 @@ void FbWindow::slotGetPhotoDone(int errCode, const QString& errMsg,
             errText = imgFile.errorString();
         }
         else
+        {
             imgFile.close();
+        }
 
         if (errText.isEmpty())
         {
@@ -826,8 +862,7 @@ void FbWindow::slotTransferCancel()
     m_talker->cancel();
 }
 
-void FbWindow::slotCreateAlbumDone(int errCode, const QString& errMsg,
-                                   long long newAlbumID)
+void FbWindow::slotCreateAlbumDone(int errCode, const QString& errMsg, long long newAlbumID)
 {
     if (errCode != 0)
     {
