@@ -7,7 +7,7 @@
  * Description : a kipi plugin to import/export images to Facebook web service
  *
  * Copyright (C) 2005-2008 by Vardhman Jain <vardhman at gmail dot com>
- * Copyright (C) 2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2008-2009 by Luka Renko <lure at kubuntu dot org>
  *
  * This program is free software; you can redistribute it
@@ -26,29 +26,34 @@
 #define FBWINDOW_H
 
 // Qt includes
+
 #include <QList>
 
 // KDE includes
+
 #include <KDialog>
 
 // LibKIPI includes
+
 #include <libkipi/interface.h>
 
 // LibKExiv2 includes
+
 #include <libkexiv2/kexiv2.h>
 
-class KProgressDialog;
+class QCloseEvent;
 
+class KProgressDialog;
 class KUrl;
 
 namespace KIPI
 {
-class Interface;
+    class Interface;
 }
 
 namespace KIPIPlugins
 {
-class KPAboutData;
+    class KPAboutData;
 }
 
 namespace KIPIFacebookPlugin
@@ -67,10 +72,16 @@ class FbWindow : public KDialog
 
 public:
 
-    FbWindow(KIPI::Interface *interface, const QString &tmpFolder,
+    FbWindow(KIPI::Interface *interface, const QString& tmpFolder,
              bool import, QWidget *parent);
     ~FbWindow();
 
+    /**
+     * Use this method to (re-)activate the dialog after it has been created
+     * to display it. This also loads the currently selected images.
+     */
+    void reactivate();
+
 private Q_SLOTS:
 
     void slotBusy(bool val);
@@ -101,46 +112,49 @@ private Q_SLOTS:
     void slotImageListChanged();
 
 private:
-    void setProfileAID(long long userID);
+
+    void    setProfileAID(long long userID);
     QString getImageCaption(const KExiv2Iface::KExiv2& ev);
-    bool prepareImageForUpload(const QString& imgPath, bool isRAW,
-                               QString& caption);
-    void uploadNextPhoto();
-    void downloadNextPhoto();
+    bool    prepareImageForUpload(const QString& imgPath, bool isRAW, QString& caption);
 
-    void readSettings();
-    void writeSettings();
+    void    uploadNextPhoto();
+    void    downloadNextPhoto();
 
-    void authenticate();
+    void    readSettings();
+    void    writeSettings();
 
-    void buttonStateChange(bool state);
+    void    authenticate();
+
+    void    buttonStateChange(bool state);
+
+    void    closeEvent(QCloseEvent*);
 
 private:
 
-    bool                        m_import;
-    unsigned int                m_imagesCount;
-    unsigned int                m_imagesTotal;
-    QString                     m_tmpDir;
-    QString                     m_tmpPath;
+    bool                      m_import;
+    unsigned int              m_imagesCount;
+    unsigned int              m_imagesTotal;
+    QString                   m_tmpDir;
+    QString                   m_tmpPath;
 
-    long long                   m_profileAID;
-    long long                   m_currentAlbumID;
-    QString                     m_sessionKey;
-    QString                     m_sessionSecret;
-    unsigned int                m_sessionExpires;
+    long long                 m_profileAID;
+    long long                 m_currentAlbumID;
+    QString                   m_sessionKey;
+    QString                   m_sessionSecret;
+    unsigned int              m_sessionExpires;
 
-    KProgressDialog            *m_progressDlg;
-    KProgressDialog            *m_authProgressDlg;
+    KProgressDialog          *m_progressDlg;
+    KProgressDialog          *m_authProgressDlg;
 
-    KUrl::List                  m_transferQueue;
+    KUrl::List                m_transferQueue;
 
-    FbTalker                   *m_talker;
-    FbWidget                   *m_widget;
-    FbNewAlbum                 *m_albumDlg;
+    FbTalker                 *m_talker;
+    FbWidget                 *m_widget;
+    FbNewAlbum               *m_albumDlg;
 
-    KIPI::Interface            *m_interface;
+    KIPI::Interface          *m_interface;
 
-    KIPIPlugins::KPAboutData   *m_about;
+    KIPIPlugins::KPAboutData *m_about;
 };
 
 } // namespace KIPIFacebookPlugin
