@@ -7,7 +7,7 @@
  * Description : a kipi plugin to import/export images to Facebook web service
  *
  * Copyright (C) 2005-2008 by Vardhman Jain <vardhman at gmail dot com>
- * Copyright (C) 2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2008-2009 by Luka Renko <lure at kubuntu dot org>
  *
  * This program is free software; you can redistribute it
@@ -26,12 +26,14 @@
 #include "plugin_facebook.moc"
 
 // C ANSI includes
+
 extern "C"
 {
 #include <unistd.h>
 }
 
 // KDE includes
+
 #include <KDebug>
 #include <KConfig>
 #include <KApplication>
@@ -40,25 +42,31 @@ extern "C"
 #include <KGenericFactory>
 #include <KLibLoader>
 #include <KStandardDirs>
+#include <kwindowsystem.h>
 
 // LibKIPI includes
+
 #include <libkipi/interface.h>
 
 // Local includes
+
 #include "fbwindow.h"
 
 K_PLUGIN_FACTORY( FacebookFactory, registerPlugin<Plugin_Facebook>(); )
 K_EXPORT_PLUGIN ( FacebookFactory("kipiplugin_facebook") )
 
-Plugin_Facebook::Plugin_Facebook(QObject *parent, const QVariantList &/*args*/)
-                   : KIPI::Plugin(FacebookFactory::componentData(),
-                                  parent, "Facebook Import/Export")
+Plugin_Facebook::Plugin_Facebook(QObject* parent, const QVariantList& /*args*/)
+               : KIPI::Plugin(FacebookFactory::componentData(),
+                              parent, "Facebook Import/Export")
 {
-    kDebug(51001) << "Plugin_Facebook plugin loaded";
+    kDebug(AREA_CODE_LOADING) << "Plugin_Facebook plugin loaded";
 }
 
 void Plugin_Facebook::setup(QWidget* widget)
 {
+    m_dlgImport = 0;
+    m_dlgExport = 0;
+
     KIPI::Plugin::setup(widget);
 
     KIconLoader::global()->addAppDir("kipiplugin_facebook");
@@ -66,7 +74,7 @@ void Plugin_Facebook::setup(QWidget* widget)
     m_actionExport = actionCollection()->addAction("facebookexport");
     m_actionExport->setText(i18n("Export to &Facebook..."));
     m_actionExport->setIcon(KIcon("facebook"));
-    m_actionExport->setShortcut(Qt::ALT+Qt::SHIFT+Qt::Key_F);
+    m_actionExport->setShortcut(KShortcut(Qt::ALT+Qt::SHIFT+Qt::Key_F));
 
     connect(m_actionExport, SIGNAL( triggered(bool) ),
             this, SLOT( slotExport()) );
@@ -76,7 +84,7 @@ void Plugin_Facebook::setup(QWidget* widget)
     m_actionImport = actionCollection()->addAction("facebookimport");
     m_actionImport->setText(i18n("Import from &Facebook..."));
     m_actionImport->setIcon(KIcon("facebook"));
-    m_actionImport->setShortcut(Qt::ALT+Qt::SHIFT+Qt::CTRL+Qt::Key_F);
+    m_actionImport->setShortcut(KShortcut(Qt::ALT+Qt::SHIFT+Qt::CTRL+Qt::Key_F));
 
     connect(m_actionImport, SIGNAL( triggered(bool) ),
             this, SLOT( slotImport()) );
@@ -86,7 +94,7 @@ void Plugin_Facebook::setup(QWidget* widget)
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(parent());
     if (!interface)
     {
-        kError(51000) << "Kipi interface is null!";
+        kError() << "Kipi interface is null!";
         m_actionExport->setEnabled(false);
         m_actionImport->setEnabled(false);
         return;
@@ -105,18 +113,27 @@ void Plugin_Facebook::slotExport()
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(parent());
     if (!interface)
     {
-        kError(51000) << "Kipi interface is null!";
+        kError() << "Kipi interface is null!";
         return;
     }
 
     KStandardDirs dir;
-    QString tmp = dir.saveLocation("tmp", "kipi-fb-"
-                                           + QString::number(getpid()) + '/');
+    QString tmp = dir.saveLocation("tmp", QString("kipi-fb-") + QString::number(getpid()) + QString("/"));
 
-    // We clean it up in the close button
-    m_dlg = new KIPIFacebookPlugin::FbWindow(interface, tmp, false,
-                                       kapp->activeWindow());
-    m_dlg->show();
+    if (!m_dlgExport)
+    {
+        // We clean it up in the close button
+        m_dlgExport = new KIPIFacebookPlugin::FbWindow(interface, tmp, false, kapp->activeWindow());
+    }
+    else
+    {
+        if (m_dlgExport->isMinimized())
+            KWindowSystem::unminimizeWindow(m_dlgExport->winId());
+
+        KWindowSystem::activateWindow(m_dlgExport->winId());
+    }
+
+    m_dlgExport->reactivate();
 }
 
 void Plugin_Facebook::slotImport()
@@ -124,18 +141,27 @@ void Plugin_Facebook::slotImport()
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>(parent());
     if (!interface)
     {
-        kError(51000) << "Kipi interface is null!";
+        kError() << "Kipi interface is null!";
         return;
     }
 
     KStandardDirs dir;
-    QString tmp = dir.saveLocation("tmp", "kipi-fb-"
-                                           + QString::number(getpid()) + '/');
+    QString tmp = dir.saveLocation("tmp", QString("kipi-fb-") + QString::number(getpid()) + QString("/"));
 
-    // We clean it up in the close button
-    m_dlg = new KIPIFacebookPlugin::FbWindow(interface, tmp, true,
-                                       kapp->activeWindow());
-    m_dlg->show();
+    if (!m_dlgImport)
+    {
+        // We clean it up in the close button
+        m_dlgImport = new KIPIFacebookPlugin::FbWindow(interface, tmp, true, kapp->activeWindow());
+    }
+    else
+    {
+        if (m_dlgImport->isMinimized())
+            KWindowSystem::unminimizeWindow(m_dlgImport->winId());
+
+        KWindowSystem::activateWindow(m_dlgImport->winId());
+    }
+
+    m_dlgImport->show();
 }
 
 KIPI::Category Plugin_Facebook::category( KAction* action ) const
@@ -146,6 +172,6 @@ KIPI::Category Plugin_Facebook::category( KAction* action ) const
     if (action == m_actionImport)
         return KIPI::ImportPlugin;
 
-    kWarning(51000) << "Unrecognized action for plugin category identification";
+    kWarning() << "Unrecognized action for plugin category identification";
     return KIPI::ExportPlugin;
 }
