@@ -7,7 +7,7 @@
  * Description : a kipi plugin to import/export images to Facebook web service
  *
  * Copyright (C) 2005-2008 by Vardhman Jain <vardhman at gmail dot com>
- * Copyright (C) 2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2008-2009 by Luka Renko <lure at kubuntu dot org>
  *
  * This program is free software; you can redistribute it
@@ -26,9 +26,11 @@
 #define PLUGIN_FACEBOOK_H
 
 // Qt includes
+
 #include <QVariant>
 
 // LibKIPI includes
+
 #include <libkipi/plugin.h>
 
 class KAction;
@@ -47,8 +49,8 @@ public:
     Plugin_Facebook(QObject *parent, const QVariantList &args);
     ~Plugin_Facebook();
 
-    virtual KIPI::Category category(KAction* action) const;
-    virtual void setup(QWidget*);
+    KIPI::Category category(KAction* action) const;
+    void setup(QWidget*);
 
 public Q_SLOTS:
 
@@ -57,9 +59,11 @@ public Q_SLOTS:
 
 private:
 
-    KAction                       *m_actionImport;
-    KAction                       *m_actionExport;
-    KIPIFacebookPlugin::FbWindow  *m_dlg;
+    KAction                      *m_actionImport;
+    KAction                      *m_actionExport;
+
+    KIPIFacebookPlugin::FbWindow *m_dlgImport;
+    KIPIFacebookPlugin::FbWindow *m_dlgExport;
 };
 
 #endif // PLUGIN_FACEBOOK_H
