@@ -7,7 +7,7 @@
  * Description : a kipi plugin to export images to Flickr web service
  *
  * Copyright (C) 2005-2008 by Vardhman Jain <vardhman at gmail dot com>
- * Copyright (C) 2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009 by Luka Renko <lure at kubuntu dot org>
  *
  * This program is free software; you can redistribute it
@@ -24,7 +24,6 @@
 
 #include "flickrwindow.h"
 #include "flickrwindow.moc"
-#include "flickrnewphotosetdialog.h"
 
 // Qt includes
 
@@ -71,47 +70,52 @@
 #include "flickritem.h"
 #include "flickrlist.h"
 //#include "flickrviewitem.h"
+#include "flickrnewphotosetdialog.h"
 #include "flickrwidget.h"
 #include "ui_flickralbumdialog.h"
 
 namespace KIPIFlickrExportPlugin
 {
 
-FlickrWindow::FlickrWindow(KIPI::Interface* interface, const QString &tmpFolder, QWidget *parent, const QString& serviceName)
-            : KDialog(parent)
+FlickrWindow::FlickrWindow(KIPI::Interface* interface, const QString& tmpFolder, QWidget* /*parent*/,
+                           const QString& serviceName)
+            : KDialog(0)
 {
     m_serviceName = serviceName;
     setWindowTitle(i18n("Export to %1 Web Service", m_serviceName));
-    if ((serviceName != "23") && (serviceName != "Zooomr"))
-        setWindowIcon(KIcon("flickr"));
     setButtons(Help|User1|Close);
     setDefaultButton(Close);
     setModal(false);
 
-    m_tmp                    = tmpFolder;
-    m_interface              = interface;
-    m_uploadCount            = 0;
-    m_uploadTotal            = 0;
-//  m_wallet                 = 0;
-    m_widget                 = new FlickrWidget(this, interface, serviceName);
-    m_photoView              = m_widget->m_photoView;
-    m_albumsListComboBox     = m_widget->m_albumsListComboBox;
-    m_newAlbumBtn            = m_widget->m_newAlbumBtn;
-    m_resizeCheckBox         = m_widget->m_resizeCheckBox;
-    m_publicCheckBox         = m_widget->m_publicCheckBox;
-    m_familyCheckBox         = m_widget->m_familyCheckBox;
-    m_friendsCheckBox        = m_widget->m_friendsCheckBox;
-    m_dimensionSpinBox       = m_widget->m_dimensionSpinBox;
-    m_imageQualitySpinBox    = m_widget->m_imageQualitySpinBox;
-    m_extendedButton         = m_widget->m_extendedButton;
-    m_safetyLevelComboBox    = m_widget->m_safetyLevelComboBox;
-    m_contentTypeComboBox    = m_widget->m_contentTypeComboBox;
-    m_tagsLineEdit           = m_widget->m_tagsLineEdit;
-    m_exportHostTagsCheckBox = m_widget->m_exportHostTagsCheckBox;
-    m_stripSpaceTagsCheckBox = m_widget->m_stripSpaceTagsCheckBox;
-    m_changeUserButton       = m_widget->m_changeUserButton;
-    m_userNameDisplayLabel   = m_widget->m_userNameDisplayLabel;
-    m_imglst                 = m_widget->m_imglst;
+    if ((serviceName != "23") && (serviceName != "Zooomr"))
+        setWindowIcon(KIcon("flickr"));
+
+    m_tmp                       = tmpFolder;
+    m_interface                 = interface;
+    m_uploadCount               = 0;
+    m_uploadTotal               = 0;
+//  m_wallet                    = 0;
+    m_widget                    = new FlickrWidget(this, interface, serviceName);
+    m_photoView                 = m_widget->m_photoView;
+    m_albumsListComboBox        = m_widget->m_albumsListComboBox;
+    m_newAlbumBtn               = m_widget->m_newAlbumBtn;
+    m_resizeCheckBox            = m_widget->m_resizeCheckBox;
+    m_publicCheckBox            = m_widget->m_publicCheckBox;
+    m_familyCheckBox            = m_widget->m_familyCheckBox;
+    m_friendsCheckBox           = m_widget->m_friendsCheckBox;
+    m_dimensionSpinBox          = m_widget->m_dimensionSpinBox;
+    m_imageQualitySpinBox       = m_widget->m_imageQualitySpinBox;
+    m_extendedTagsButton        = m_widget->m_extendedTagsButton;
+    m_addExtraTagsCheckBox      = m_widget->m_addExtraTagsCheckBox;
+    m_extendedPublicationButton = m_widget->m_extendedPublicationButton;
+    m_safetyLevelComboBox       = m_widget->m_safetyLevelComboBox;
+    m_contentTypeComboBox       = m_widget->m_contentTypeComboBox;
+    m_tagsLineEdit              = m_widget->m_tagsLineEdit;
+    m_exportHostTagsCheckBox    = m_widget->m_exportHostTagsCheckBox;
+    m_stripSpaceTagsCheckBox    = m_widget->m_stripSpaceTagsCheckBox;
+    m_changeUserButton          = m_widget->m_changeUserButton;
+    m_userNameDisplayLabel      = m_widget->m_userNameDisplayLabel;
+    m_imglst                    = m_widget->m_imglst;
 
     setButtonGuiItem(User1, KGuiItem(i18n("Start Uploading"), KIcon("network-workgroup")));
     setMainWidget(m_widget);
@@ -128,10 +132,10 @@ FlickrWindow::FlickrWindow(KIPI::Interface* interface, const QString &tmpFolder,
     m_about = new KIPIPlugins::KPAboutData(ki18n("Flickr/23/Zooomr Export"),
                                            0,
                                            KAboutData::License_GPL,
-                                           ki18n("A Kipi plugin to export image collection to "
+                                           ki18n("A Kipi plugin to export an image collection to a "
                                                      "Flickr / 23 / Zooomr web service."),
                                            ki18n( "(c) 2005-2008, Vardhman Jain\n"
-                                           "(c) 2008, Gilles Caulier\n"
+                                           "(c) 2008-2009, Gilles Caulier\n"
                                            "(c) 2009, Luka Renko" ));
 
     m_about->addAuthor(ki18n( "Vardhman Jain" ), ki18n("Author and maintainer"),
@@ -170,15 +174,15 @@ FlickrWindow::FlickrWindow(KIPI::Interface* interface, const QString &tmpFolder,
     connect(m_talker, SIGNAL( signalAddPhotoSetSucceeded() ),
             this, SLOT( slotAddPhotoSetSucceeded() ));
 
-    connect(m_newAlbumBtn, SIGNAL( clicked() ),
-            this, SLOT( slotCreateNewPhotoSet() ));
-
     connect(m_talker, SIGNAL( signalListPhotoSetsSucceeded() ),
-            this, SLOT( populatePhotoSetComboBox() ));
+            this, SLOT( slotPopulatePhotoSetComboBox() ));
 
     connect(m_talker, SIGNAL( signalListPhotoSetsFailed(const QString&) ),
             this, SLOT( slotListPhotoSetsFailed(const QString&) ));
 
+    connect(m_talker, SIGNAL( signalTokenObtained(const QString&) ),
+            this, SLOT( slotTokenObtained(const QString&) ));
+
     //connect( m_talker, SIGNAL( signalAlbums( const QValueList<GAlbum>& ) ),
     //         SLOT( slotAlbums( const QValueList<GAlbum>& ) ) );
 
@@ -198,8 +202,9 @@ FlickrWindow::FlickrWindow(KIPI::Interface* interface, const QString &tmpFolder,
     connect(m_changeUserButton, SIGNAL( clicked() ),
             this, SLOT( slotUserChangeRequest() ));
 
-    connect(m_talker, SIGNAL( signalTokenObtained(const QString&) ),
-            this, SLOT( slotTokenObtained(const QString&) ));
+    connect(m_newAlbumBtn, SIGNAL( clicked() ),
+            this, SLOT( slotCreateNewPhotoSet() ));
+
 
     //connect( m_tagView, SIGNAL( selectionChanged() ),
     //         SLOT( slotTagSelected() ) );
@@ -207,9 +212,6 @@ FlickrWindow::FlickrWindow(KIPI::Interface* interface, const QString &tmpFolder,
     //connect( m_photoView->browserExtension(), SIGNAL( openURLRequest( const KUrl&, const KParts::URLArgs& ) ),
     //         SLOT( slotOpenPhoto( const KUrl& ) ) );
 
-    //connect( m_newAlbumBtn, SIGNAL( clicked() ),
-    //         SLOT( slotNewAlbum() ) );
-
     // --------------------------------------------------------------------------
 
     readSettings();
@@ -223,9 +225,8 @@ FlickrWindow::FlickrWindow(KIPI::Interface* interface, const QString &tmpFolder,
             this, SLOT( slotAuthCancel() ));
 
     m_talker->m_authProgressDlg = m_authProgressDlg;
-    m_widget->setEnabled(false);
 
-    kDebug(51000) << "Calling auth methods";
+    kDebug() << "Calling auth methods";
 
     if(m_token.length()< 1)
         m_talker->getFrob();
@@ -253,11 +254,63 @@ FlickrWindow::~FlickrWindow()
     delete m_about;
 }
 
+void FlickrWindow::slotHelp()
+{
+    KToolInvocation::invokeHelp("flickrexport", "kipi-plugins");
+}
+
+void FlickrWindow::slotClose()
+{
+    writeSettings();
+    m_imglst->listView()->clear();
+    done(Close);
+}
+
+void FlickrWindow::closeEvent(QCloseEvent *e)
+{
+    if (!e) return;
+
+    writeSettings();
+    m_imglst->listView()->clear();
+    e->accept();
+}
+
+void FlickrWindow::reactivate()
+{
+    m_widget->m_imglst->loadImagesFromCurrentSelection();
+    show();
+}
+
 void FlickrWindow::readSettings()
 {
     KConfig config("kipirc");
     KConfigGroup grp = config.group(QString("%1Export Settings").arg(m_serviceName));
-    m_token = grp.readEntry("token");
+    m_token          = grp.readEntry("token");
+
+    m_exportHostTagsCheckBox->setChecked(grp.readEntry("Export Host Tags",      false));
+    m_extendedTagsButton->setChecked(grp.readEntry("Show Extended Tag Options", false));
+    m_addExtraTagsCheckBox->setChecked(grp.readEntry("Add Extra Tags",          false));
+    m_stripSpaceTagsCheckBox->setChecked(grp.readEntry("Strip Space From Tags", false));
+    m_stripSpaceTagsCheckBox->setEnabled(m_exportHostTagsCheckBox->isChecked());
+
+    if(!m_interface->hasFeature(KIPI::HostSupportsTags))
+    {
+        m_exportHostTagsCheckBox->setEnabled(false);
+        m_stripSpaceTagsCheckBox->setEnabled(false);
+    }
+
+    m_publicCheckBox->setChecked(grp.readEntry("Public Sharing",                               false));
+    m_familyCheckBox->setChecked(grp.readEntry("Family Sharing",                               false));
+    m_friendsCheckBox->setChecked(grp.readEntry("Friends Sharing",                             false));
+    m_extendedPublicationButton->setChecked(grp.readEntry("Show Extended Publication Options", false));
+
+    int safetyLevel = m_safetyLevelComboBox->findData(QVariant(grp.readEntry("Safety Level", 0)));
+    if (safetyLevel == -1) safetyLevel = 0;
+    m_safetyLevelComboBox->setCurrentIndex(safetyLevel);
+
+    int contentType = m_contentTypeComboBox->findData(QVariant(grp.readEntry("Content Type", 0)));
+    if (contentType == -1) contentType = 0;
+    m_contentTypeComboBox->setCurrentIndex(contentType);
 
     if (grp.readEntry("Resize", false))
     {
@@ -272,29 +325,6 @@ void FlickrWindow::readSettings()
 
     m_dimensionSpinBox->setValue(grp.readEntry("Maximum Width", 1600));
     m_imageQualitySpinBox->setValue(grp.readEntry("Image Quality", 85));
-    m_exportHostTagsCheckBox->setChecked(grp.readEntry("Export Host Tags", false));
-    m_stripSpaceTagsCheckBox->setChecked(grp.readEntry("Strip Space Host Tags", false));
-    m_stripSpaceTagsCheckBox->setEnabled(m_exportHostTagsCheckBox->isChecked());
-
-    if(!m_interface->hasFeature(KIPI::HostSupportsTags))
-    {
-        m_exportHostTagsCheckBox->setEnabled(false);
-        m_stripSpaceTagsCheckBox->setEnabled(false);
-    }
-
-    m_publicCheckBox->setChecked(grp.readEntry("Public Sharing", false));
-    m_familyCheckBox->setChecked(grp.readEntry("Family Sharing", false));
-    m_friendsCheckBox->setChecked(grp.readEntry("Friends Sharing", false));
-
-    m_extendedButton->setChecked(grp.readEntry("Show Extended Options", false));
-    int safetyLevel = m_safetyLevelComboBox->findData(
-                          QVariant(grp.readEntry("Safety Level", 0)));
-    if (safetyLevel == -1) safetyLevel = 0;
-    m_safetyLevelComboBox->setCurrentIndex(safetyLevel);
-    int contentType = m_contentTypeComboBox->findData(
-                          QVariant(grp.readEntry("Content Type", 0)));
-    if (contentType == -1) contentType = 0;
-    m_contentTypeComboBox->setCurrentIndex(contentType);
 
     KConfigGroup dialogGroup = config.group(QString("%1Export Dialog").arg(m_serviceName));
     restoreDialogSize(dialogGroup);
@@ -305,53 +335,42 @@ void FlickrWindow::writeSettings()
     KConfig config("kipirc");
     KConfigGroup grp = config.group(QString("%1Export Settings").arg(m_serviceName));
     grp.writeEntry("token", m_token);
-    grp.writeEntry("Resize", m_resizeCheckBox->isChecked());
-    grp.writeEntry("Maximum Width",  m_dimensionSpinBox->value());
-    grp.writeEntry("Image Quality",  m_imageQualitySpinBox->value());
-    grp.writeEntry("Export Host Tags", m_exportHostTagsCheckBox->isChecked());
-    grp.writeEntry("Strip Space Host Tags", m_stripSpaceTagsCheckBox->isChecked());
-    grp.writeEntry("Public Sharing", m_publicCheckBox->isChecked());
-    grp.writeEntry("Family Sharing", m_familyCheckBox->isChecked());
-    grp.writeEntry("Friends Sharing", m_friendsCheckBox->isChecked());
-    grp.writeEntry("Show Extended Options", m_extendedButton->isChecked());
+    grp.writeEntry("Export Host Tags",                  m_exportHostTagsCheckBox->isChecked());
+    grp.writeEntry("Show Extended Tag Options",         m_extendedTagsButton->isChecked());
+    grp.writeEntry("Add Extra Tags",                    m_addExtraTagsCheckBox->isChecked());
+    grp.writeEntry("Strip Space From Tags",             m_stripSpaceTagsCheckBox->isChecked());
+    grp.writeEntry("Public Sharing",                    m_publicCheckBox->isChecked());
+    grp.writeEntry("Family Sharing",                    m_familyCheckBox->isChecked());
+    grp.writeEntry("Friends Sharing",                   m_friendsCheckBox->isChecked());
+    grp.writeEntry("Show Extended Publication Options", m_extendedPublicationButton->isChecked());
     int safetyLevel = m_safetyLevelComboBox->itemData(m_safetyLevelComboBox->currentIndex()).toInt();
-    grp.writeEntry("Safety Level", safetyLevel);
+    grp.writeEntry("Safety Level",                      safetyLevel);
     int contentType = m_contentTypeComboBox->itemData(m_contentTypeComboBox->currentIndex()).toInt();
-    grp.writeEntry("Content Type", contentType);
+    grp.writeEntry("Content Type",                      contentType);
+    grp.writeEntry("Resize",                            m_resizeCheckBox->isChecked());
+    grp.writeEntry("Maximum Width",                     m_dimensionSpinBox->value());
+    grp.writeEntry("Image Quality",                     m_imageQualitySpinBox->value());
     KConfigGroup dialogGroup = config.group(QString("%1Export Dialog").arg(m_serviceName));
     saveDialogSize(dialogGroup );
     config.sync();
 }
 
-void FlickrWindow::slotHelp()
-{
-    KToolInvocation::invokeHelp("flickrexport", "kipi-plugins");
-}
-
 void FlickrWindow::slotDoLogin()
 {
 }
 
-void FlickrWindow::slotClose()
-{
-    writeSettings();
-    done(Close);
-}
-
 void FlickrWindow::slotTokenObtained(const QString& token)
 {
     m_token    = token;
     m_username = m_talker->getUserName();
     m_userId   = m_talker->getUserId();
-    kDebug(51000) << "SlotTokenObtained invoked setting user Display name to " << m_username;
+    kDebug() << "SlotTokenObtained invoked setting user Display name to " << m_username;
     m_userNameDisplayLabel->setText(QString("<b>%1</b>").arg(m_username));
+
+    // Mutable photosets are not supported by Zooomr (Zooomr only has smart
+    // folder-type photosets).
     if (m_serviceName != "Zooomr")
         m_talker->listPhotoSets();
-    else
-        // Mutable photosets are not supported by Zooomr (Zooomr only has smart
-        // folder-type photosets). So we're done and can active the Flickr
-        // widget.
-        m_widget->setEnabled(true);
 }
 
 void FlickrWindow::slotBusy(bool val)
@@ -378,7 +397,7 @@ void FlickrWindow::slotError(const QString& msg)
 
 void FlickrWindow::slotUserChangeRequest()
 {
-    kDebug(51000) << "Slot Change User Request ";
+    kDebug() << "Slot Change User Request ";
     m_talker->getFrob();
 //  m_addPhotoButton->setEnabled(m_selectImagesButton->isChecked());
 }
@@ -394,6 +413,7 @@ void FlickrWindow::slotCreateNewPhotoSet()
    // Call the dialog
    QPointer<FlickrNewPhotoSetDialog> dlg = new FlickrNewPhotoSetDialog(kapp->activeWindow());
    int resp = dlg->exec();
+
    if ((resp == QDialog::Accepted) && (dlg->titleEdit->text() != ""))
    {
       // Create a new photoset with title and description from the dialog.
@@ -403,9 +423,10 @@ void FlickrWindow::slotCreateNewPhotoSet()
 
       // Lets find an UNDEFINED_ style id that isn't taken yet.s
       QString id;
-      int i = 0;
-      id = "UNDEFINED_" + QString::number(i);
+      int i                               = 0;
+      id                                  = "UNDEFINED_" + QString::number(i);
       QLinkedList<FPhotoSet>::iterator it = m_talker->m_photoSetsList->begin();
+
       while(it != m_talker->m_photoSetsList->end())
       {
           FPhotoSet fps = *it;
@@ -414,8 +435,9 @@ void FlickrWindow::slotCreateNewPhotoSet()
               id = "UNDEFINED_" + QString::number(++i);
               it = m_talker->m_photoSetsList->begin();
           }
-          it++;
+          ++it;
       }
+
       fps.id = id;
 
       kDebug() << "Created new photoset with temporary id " << id;
@@ -424,11 +446,11 @@ void FlickrWindow::slotCreateNewPhotoSet()
       m_talker->m_selectedPhotoSet = fps;
 
       // Re-populate the photo sets combo box.
-      populatePhotoSetComboBox();
+      slotPopulatePhotoSetComboBox();
    }
    else
    {
-       kDebug(51000) << "New Photoset creation aborted ";
+       kDebug() << "New Photoset creation aborted ";
    }
 
    delete dlg;
@@ -456,9 +478,10 @@ void FlickrWindow::slotOpenPhoto( const KUrl& url )
 }
 */
 
-void FlickrWindow::populatePhotoSetComboBox()
+void FlickrWindow::slotPopulatePhotoSetComboBox()
 {
-    kDebug(51000) << "populatePhotoSetComboBox invoked";
+    kDebug() << "slotPopulatePhotoSetComboBox invoked";
+
     if (m_talker && m_talker->m_photoSetsList)
     {
         QLinkedList <FPhotoSet> *list = m_talker->m_photoSetsList;
@@ -467,28 +490,30 @@ void FlickrWindow::populatePhotoSetComboBox()
         m_albumsListComboBox->insertSeparator(1);
         QLinkedList<FPhotoSet>::iterator it = list->begin();
         int index = 2, curr_index = 0;
+
         while(it != list->end())
         {
-            FPhotoSet photoSet=*it;
-            QString name = photoSet.title;
+            FPhotoSet photoSet = *it;
+            QString name       = photoSet.title;
             // Store the id as user data, because the title is not unique.
-            QVariant id = QVariant(photoSet.id);
+            QVariant id        = QVariant(photoSet.id);
+
             if (id == m_talker->m_selectedPhotoSet.id)
                 curr_index = index;
+
             m_albumsListComboBox->insertItem(index++, name, id);
             it++;
         }
+
         m_albumsListComboBox->setCurrentIndex(curr_index);
     }
-    m_widget->setEnabled(true);
 }
 
-
 /** This slot is call when 'Start Uploading' button is pressed.
 */
 void FlickrWindow::slotUser1()
 {
-    kDebug(51000) << "SlotUploadImages invoked";
+    kDebug() << "SlotUploadImages invoked";
 
     m_widget->m_tab->setCurrentIndex(FlickrWidget::FILELIST);
 
@@ -505,7 +530,7 @@ void FlickrWindow::slotUser1()
                                      (m_imglst->listView()->topLevelItem(i));
 
         KIPI::ImageInfo info = m_interface->info(lvItem->url());
-        kDebug(51000) << "Adding images to the list";
+        kDebug() << "Adding images to the list";
         FPhotoInfo temp;
 
         temp.title                 = info.title();
@@ -515,7 +540,8 @@ void FlickrWindow::slotUser1()
         temp.is_friend             = lvItem->isFriends() ? 1 : 0;
         temp.safety_level          = lvItem->safetyLevel();
         temp.content_type          = lvItem->contentType();
-        QStringList tagsFromDialog = m_tagsLineEdit->text().split(" ", QString::SkipEmptyParts);
+        QStringList tagsFromDialog = m_tagsLineEdit->text().split(",", QString::SkipEmptyParts);
+        QStringList tagsFromList   = lvItem->extraTags();
 
         QStringList           allTags;
         QStringList::Iterator itTags;
@@ -529,32 +555,47 @@ void FlickrWindow::slotUser1()
         }
 
         // Tags from the database
-        QMap <QString, QVariant> attribs = info.attributes();
-        QStringList tagsFromDatabase;
-
         if(m_exportHostTagsCheckBox->isChecked())
         {
+            QMap <QString, QVariant> attribs = info.attributes();
+            QStringList tagsFromDatabase;
+
             tagsFromDatabase = attribs["tags"].toStringList();
-            if (m_stripSpaceTagsCheckBox->isChecked())
+            itTags           = tagsFromDatabase.begin();
+
+            while(itTags != tagsFromDatabase.end())
             {
-                for (QStringList::iterator it = tagsFromDatabase.begin(); it != tagsFromDatabase.end() ; ++it)
-                    *it = (*it).trimmed().remove(" ");
+                allTags.append(*itTags);
+                ++itTags;
             }
         }
 
-        itTags = tagsFromDatabase.begin();
+        // Tags from the list view.
+        itTags = tagsFromList.begin();
 
-        while(itTags != tagsFromDatabase.end())
+        while(itTags != tagsFromList.end())
         {
             allTags.append(*itTags);
             ++itTags;
         }
 
+        // Remove spaces if the user doesn't like them.
+        if (m_stripSpaceTagsCheckBox->isChecked())
+        {
+            for (QStringList::iterator it = allTags.begin();
+                 it != allTags.end();
+                 ++it)
+            {
+                *it = (*it).trimmed().remove(" ");
+            }
+        }
+
+        // Debug the tag list.
         itTags = allTags.begin();
 
         while(itTags != allTags.end())
         {
-            kDebug(51000) << "Tags list: " << (*itTags);
+            kDebug() << "Tags list: " << (*itTags);
             ++itTags;
         }
 
@@ -566,7 +607,7 @@ void FlickrWindow::slotUser1()
     m_uploadCount = 0;
     m_progressDlg->reset();
     slotAddPhotoNext();
-    kDebug(51000) << "SlotUploadImages done";
+    kDebug() << "SlotUploadImages done";
 }
 
 void FlickrWindow::slotAddPhotoNext()
@@ -611,8 +652,8 @@ void FlickrWindow::slotAddPhotoNext()
                                   info,
                                   m_resizeCheckBox->isChecked(),
                                   m_dimensionSpinBox->value(),
-                                  m_imageQualitySpinBox->value()
-                       );
+                                  m_imageQualitySpinBox->value());
+
     if (!res)
     {
         slotAddPhotoFailed("");
@@ -668,7 +709,7 @@ void FlickrWindow::slotAddPhotoSetSucceeded()
   /* Method called when a photo set has been successfully created on Flickr.
    * It functions to restart the normal flow after a photo set has been created
    * on Flickr. */
-  populatePhotoSetComboBox();
+  slotPopulatePhotoSetComboBox();
   slotAddPhotoSucceeded();
 }
 
