@@ -6,7 +6,7 @@
 * Date        : 2003-10-01
 * Description : a plugin to export to a remote Gallery server.
 *
-* Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+* Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
 * Copyright (C) 2006 by Colin Guthrie <kde@colin.guthr.ie>
 * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
 * Copyright (C) 2008 by Andrea Diamantini <adjam7 at gmail dot com>
@@ -69,6 +69,9 @@
 namespace KIPIGalleryExportPlugin
 {
 
+bool GalleryTalker::s_using_gallery2 = true;
+QString GalleryTalker::s_authToken   = "";
+
 GalleryTalker::GalleryTalker(QWidget* parent)
              : m_parent(parent),  m_job(0),  m_loggedIn(false)
 {
@@ -80,18 +83,12 @@ GalleryTalker::~GalleryTalker()
         m_job->kill();
 }
 
-
-bool GalleryTalker::s_using_gallery2 = true;
-QString GalleryTalker::s_authToken = "";
-
-
 bool GalleryTalker::loggedIn() const
 {
     return m_loggedIn;
 }
 
-void GalleryTalker::login(const KUrl& url, const QString& name,
-                          const QString& passwd)
+void GalleryTalker::login(const KUrl& url, const QString& name, const QString& passwd)
 {
     m_job   = 0;
     m_url   = url;
@@ -177,7 +174,7 @@ void GalleryTalker::createAlbum(const QString& parentAlbumName,
                                 const QString& albumTitle,
                                 const QString& albumCaption)
 {
-    m_job = 0;
+    m_job   = 0;
     m_state = GE_CREATEALBUM;
     m_talker_buffer.resize(0);
 
@@ -185,12 +182,16 @@ void GalleryTalker::createAlbum(const QString& parentAlbumName,
     form.addPair("cmd", "new-album");
     form.addPair("protocol_version", "2.11");
     form.addPair("set_albumName", parentAlbumName);
+
     if (!albumName.isEmpty())
         form.addPair("newAlbumName", albumName);
+
     if (!albumTitle.isEmpty())
         form.addPair("newAlbumTitle", albumTitle);
+
     if (!albumCaption.isEmpty())
         form.addPair("newAlbumDesc", albumCaption);
+
     form.finish();
 
     m_job = KIO::http_post(m_url, form.formData(), KIO::HideProgressInfo);
@@ -198,8 +199,11 @@ void GalleryTalker::createAlbum(const QString& parentAlbumName,
     m_job->addMetaData("cookies", "manual");
     m_job->addMetaData("setcookies", m_cookie);
 
-    connect(m_job, SIGNAL(data(KIO::Job*, const QByteArray&)), this, SLOT(slotTalkerData(KIO::Job*, const QByteArray&)));
-    connect(m_job, SIGNAL(result(KJob *)), this, SLOT(slotResult(KJob *)));
+    connect(m_job, SIGNAL(data(KIO::Job*, const QByteArray&)),
+            this, SLOT(slotTalkerData(KIO::Job*, const QByteArray&)));
+
+    connect(m_job, SIGNAL(result(KJob*)),
+            this, SLOT(slotResult(KJob*)));
 
     emit signalBusy(true);
 }
@@ -207,8 +211,10 @@ void GalleryTalker::createAlbum(const QString& parentAlbumName,
 bool GalleryTalker::addPhoto(const QString& albumName,
                              const QString& photoPath,
                              const QString& caption,
-                             bool  captionIsTitle, bool captionIsDescription,
-                             bool  rescale, int maxDim)
+                             bool  captionIsTitle,
+                             bool  captionIsDescription,
+                             bool  rescale,
+                             int   maxDim)
 {
     m_job        = 0;
     QString path = photoPath;
@@ -229,6 +235,7 @@ bool GalleryTalker::addPhoto(const QString& albumName,
     QString rawFilesExt(KDcrawIface::KDcraw::rawFiles());
 #endif
     QFileInfo fi(photoPath);
+
     if (rawFilesExt.toUpper().contains( fi.suffix().toUpper() ))
         KDcrawIface::KDcraw::loadDcrawPreview(image, photoPath);
     else
@@ -239,12 +246,12 @@ bool GalleryTalker::addPhoto(const QString& albumName,
         // image file - see if we need to rescale it
         if (rescale && (image.width() > maxDim || image.height() > maxDim))
         {
-            image = image.scaled(maxDim, maxDim, Qt::KeepAspectRatio,
-                                                 Qt::SmoothTransformation);
+            image = image.scaled(maxDim, maxDim, Qt::KeepAspectRatio, Qt::SmoothTransformation);
         }
+
         path = KStandardDirs::locateLocal("tmp", KUrl(photoPath).fileName());
         image.save(path);
-        kDebug(51000) << "Resizing and saving to temp file: " << path ;
+        kDebug() << "Resizing and saving to temp file: " << path ;
 
         // Restore all metadata.
         KExiv2Iface::KExiv2 exiv2Iface;
@@ -257,7 +264,7 @@ bool GalleryTalker::addPhoto(const QString& albumName,
         }
         else
         {
-            kWarning(51000) << "Image " << photoPath << " has no exif data";
+            kWarning() << "Image " << photoPath << " has no exif data";
         }
     }
 
@@ -267,7 +274,6 @@ bool GalleryTalker::addPhoto(const QString& albumName,
     if (!form.addFile(path, caption))
         return false;
 
-
     if (!caption.isEmpty())
     {
         if (captionIsTitle)
@@ -396,15 +402,14 @@ void GalleryTalker::parseResponseLogin(const QByteArray &data)
     QTextStream ts(&str, QIODevice::ReadOnly);
     QString line;
     bool foundResponse = false;
-
-    m_loggedIn = false;
+    m_loggedIn         = false;
 
     while (!ts.atEnd())
     {
         line = ts.readLine();
         if (!foundResponse)
         {
-            foundResponse = line.startsWith("#__GR2PROTO__");
+            foundResponse = line.startsWith(QLatin1String("#__GR2PROTO__"));
         }
         else
         {
@@ -455,7 +460,7 @@ void GalleryTalker::parseResponseListAlbums(const QByteArray& data)
         line = ts.readLine();
         if (!foundResponse)
         {
-            foundResponse = line.startsWith("#__GR2PROTO__");
+            foundResponse = line.startsWith(QLatin1String("#__GR2PROTO__"));
         }
         else
         {
@@ -469,42 +474,42 @@ void GalleryTalker::parseResponseListAlbums(const QByteArray& data)
                 {
                     success = (value == "0");
                 }
-                else if (key.startsWith("album.name"))
+                else if (key.startsWith(QLatin1String("album.name")))
                 {
                         GAlbum album;
                         album.name    = value;
                         album.ref_num = key.section(".", 2, 2).toInt();
                         iter = albumList.insert(iter, album);
                 }
-                else if (key.startsWith("album.title"))
+                else if (key.startsWith(QLatin1String("album.title")))
                 {
                         (*iter).title = value;
                 }
-                else if (key.startsWith("album.summary"))
+                else if (key.startsWith(QLatin1String((QLatin1String(("album.summary"))))))
                 {
                         (*iter).summary = value;
                 }
-                else if (key.startsWith("album.parent"))
+                else if (key.startsWith(QLatin1String(("album.parent"))))
                 {
                         (*iter).parent_ref_num = value.toInt();
                 }
-                else if (key.startsWith("album.perms.add"))
+                else if (key.startsWith(QLatin1String(("album.perms.add"))))
                 {
                         (*iter).add = (value == "true");
                 }
-                else if (key.startsWith("album.perms.write"))
+                else if (key.startsWith(QLatin1String(("album.perms.write"))))
                 {
                         (*iter).write = (value == "true");
                 }
-                else if (key.startsWith("album.perms.del_item"))
+                else if (key.startsWith(QLatin1String(("album.perms.del_item"))))
                 {
                         (*iter).del_item = (value == "true");
                 }
-                else if (key.startsWith("album.perms.del_alb"))
+                else if (key.startsWith(QLatin1String(("album.perms.del_alb"))))
                 {
                         (*iter).del_alb = (value == "true");
                 }
-                else if (key.startsWith("album.perms.create_sub"))
+                else if (key.startsWith(QLatin1String(("album.perms.create_sub"))))
                 {
                         (*iter).create_sub = (value == "true");
                 }
@@ -554,7 +559,7 @@ void GalleryTalker::parseResponseListPhotos(const QByteArray &data)
 
         if (!foundResponse)
         {
-            foundResponse = line.startsWith("#__GR2PROTO__");
+            foundResponse = line.startsWith(QLatin1String(("#__GR2PROTO__")));
         }
         else
         {
@@ -568,22 +573,22 @@ void GalleryTalker::parseResponseListPhotos(const QByteArray &data)
                 {
                     success = (value == "0");
                 }
-                else if (key.startsWith("image.name"))
+                else if (key.startsWith(QLatin1String(("image.name"))))
                 {
                         GPhoto photo;
                         photo.name    = value;
                         photo.ref_num = key.section(".", 2, 2).toInt();
                         iter = photoList.insert(iter, photo);
                 }
-                else if (key.startsWith("image.caption"))
+                else if (key.startsWith(QLatin1String(("image.caption"))))
                 {
                         (*iter).caption = value;
                 }
-                else if (key.startsWith("image.thumbName"))
+                else if (key.startsWith(QLatin1String(("image.thumbName"))))
                 {
                         (*iter).thumbName = value;
                 }
-                else if (key.startsWith("baseurl"))
+                else if (key.startsWith(QLatin1String(("baseurl"))))
                 {
                         albumURL = value.replace("\\", "");     // doesn't compile fixing EBN Krazy issue!!
                 }
@@ -606,7 +611,6 @@ void GalleryTalker::parseResponseListPhotos(const QByteArray &data)
     emit signalPhotos(photoList);
 }
 
-
 void GalleryTalker::parseResponseCreateAlbum(const QByteArray& data)
 {
     QString str = QString::fromUtf8(data);
@@ -621,7 +625,7 @@ void GalleryTalker::parseResponseCreateAlbum(const QByteArray& data)
 
         if (!foundResponse)
         {
-            foundResponse = line.startsWith("#__GR2PROTO__");
+            foundResponse = line.startsWith(QLatin1String(("#__GR2PROTO__")));
         }
         else
         {
@@ -633,11 +637,11 @@ void GalleryTalker::parseResponseCreateAlbum(const QByteArray& data)
                 if (key == "status")      // key == "status" NOT FOUND!!!
                 {
                     success = (value == "0");
-                    kWarning( 51000 ) << "Create Album. success: " << success ;
+                    kWarning() << "Create Album. success: " << success ;
                 }
-                else if (key.startsWith("status_text"))
+                else if (key.startsWith(QLatin1String(("status_text"))))
                 {
-                    kDebug(51000) << "STATUS: Create Album: " << value ;
+                    kDebug() << "STATUS: Create Album: " << value ;
                 }
             }
         }
@@ -674,9 +678,9 @@ void GalleryTalker::parseResponseAddPhoto(const QByteArray& data)
         {
             // Gallery1 sends resizing debug code sometimes so we
             // have to detect things slightly differently
-            foundResponse = (line.startsWith("#__GR2PROTO__")
-                             || (line.startsWith("<br>- Resizing")
-                                 && line.endsWith("#__GR2PROTO__")));
+            foundResponse = (line.startsWith(QLatin1String(("#__GR2PROTO__")))
+                             || (line.startsWith(QLatin1String(("<br>- Resizing")))
+                                 && line.endsWith(QLatin1String(("#__GR2PROTO__")))));
         }
         else
         {
@@ -689,11 +693,11 @@ void GalleryTalker::parseResponseAddPhoto(const QByteArray& data)
                 if (key == "status")
                 {
                     success = (value == "0");
-                    kWarning( 51000 ) << "Add photo. success: " << success ;
+                    kWarning() << "Add photo. success: " << success ;
                 }
-                else if (key.startsWith("status_text"))
+                else if (key.startsWith(QLatin1String(("status_text"))))
                 {
-                    kDebug(51000) << "STATUS: Add Photo: " << value ;
+                    kDebug() << "STATUS: Add Photo: " << value ;
                 }
             }
         }
