@@ -6,9 +6,9 @@
  * Date        : 2003-10-01
  * Description : a plugin to export to a remote Gallery server.
  *
- * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2006 by Colin Guthrie <kde@colin.guthr.ie>
- * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2008 by Andrea Diamantini <adjam7 at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -24,8 +24,10 @@
  * ============================================================ */
 
 #include "gallerywindow.h"
+#include "gallerywindow.moc"
 
 // Qt includes
+
 #include <QCheckBox>
 #include <QDialog>
 #include <QFileInfo>
@@ -37,6 +39,7 @@
 #include <QPointer>
 
 // KDE includes
+
 #include <kaboutdata.h>
 #include <kapplication.h>
 #include <kconfig.h>
@@ -49,11 +52,16 @@
 #include <kpushbutton.h>
 #include <krun.h>
 #include <ktoolinvocation.h>
+#include <kurllabel.h>
+#include <ktoolinvocation.h>
+#include <kstandarddirs.h>
 
 // LibKIPI includes
+
 #include <libkipi/interface.h>
 
 // Local includes
+
 #include "albumdlg.h"
 #include "galleries.h"
 #include "galleryconfig.h"
@@ -62,111 +70,143 @@
 #include "imagedialog.h"
 #include "kpaboutdata.h"
 
-using namespace KIPIGalleryExportPlugin;
-
-// -------------------------------------------------------------------------------
+namespace KIPIGalleryExportPlugin
+{
 
 class GalleryWindow::Private
 {
-private:
+public:
+
     Private(GalleryWindow* parent);
 
-    QWidget *widget;
-    QTreeWidget *albumView;
-    QPushButton *newAlbumBtn;
-    QPushButton *addPhotoBtn;
-    QCheckBox *captTitleCheckBox;
-    QCheckBox *captDescrCheckBox;
-    QCheckBox *resizeCheckBox;
-    QSpinBox *dimensionSpinBox;
+    QWidget*               widget;
+
+    QTreeWidget*           albumView;
+
+    QPushButton*           newAlbumBtn;
+    QPushButton*           addPhotoBtn;
+
+    QCheckBox*             captTitleCheckBox;
+    QCheckBox*             captDescrCheckBox;
+    QCheckBox*             resizeCheckBox;
+
+    QSpinBox*              dimensionSpinBox;
 
     QHash<QString, GAlbum> albumDict;
 
-    friend class GalleryWindow;
+    KUrlLabel*             logo;
 };
 
-
 GalleryWindow::Private::Private(GalleryWindow* parent)
 {
     widget = new QWidget(parent);
     parent->setMainWidget(widget);
     parent->setModal(false);
 
-    QHBoxLayout *galleryWidgetLayout = new QHBoxLayout(widget);
+    QHBoxLayout *hlay = new QHBoxLayout(widget);
 
-    // --- creating and setting objects
+    // ---------------------------------------------------------------------------
+
+    logo = new KUrlLabel;
+    logo->setText(QString());
+    logo->setUrl("http://gallery.menalto.com");
+    logo->setPixmap(QPixmap(KStandardDirs::locate("data", "kipiplugin_galleryexport/pics/gallery_logo.png")));
+    logo->setAlignment(Qt::AlignLeft);
+
+    // ---------------------------------------------------------------------------
 
-    // 1st. QListWidget albumView
     albumView = new QTreeWidget;
     QStringList labels;
-    labels << i18n("albums"); // << i18n("ID");
+    labels << i18n("Albums"); // << i18n("ID");
     albumView->setHeaderLabels(labels);
-    galleryWidgetLayout->addWidget(albumView);
 
-    // 2nd. GroupBox optionBox
+    // ---------------------------------------------------------------------------
+
     QFrame *optionFrame = new QFrame;
-    QVBoxLayout *frameLayout = new QVBoxLayout();
+    QVBoxLayout *vlay   = new QVBoxLayout();
 
     newAlbumBtn = new QPushButton;
     newAlbumBtn->setText(i18n("&New Album"));
+    newAlbumBtn->setIcon(KIcon("folder-new"));
     newAlbumBtn->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     newAlbumBtn->setEnabled(false);
-    frameLayout->addWidget(newAlbumBtn);
 
     addPhotoBtn = new QPushButton;
     addPhotoBtn->setText(i18n("&Add Photos"));
+    addPhotoBtn->setIcon(KIcon("list-add"));
     addPhotoBtn->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     addPhotoBtn->setEnabled(false);
-    frameLayout->addWidget(addPhotoBtn);
 
     QGroupBox *optionsBox = new QGroupBox(i18n("Override Default Options"));
-    QVBoxLayout *optionsBoxLayout = new QVBoxLayout();
+    QVBoxLayout *vlay2    = new QVBoxLayout();
 
-    captTitleCheckBox = new QCheckBox(optionsBox);
+    captTitleCheckBox     = new QCheckBox(optionsBox);
     captTitleCheckBox->setText(i18n("Comment sets Title"));
-    optionsBoxLayout->addWidget(captTitleCheckBox);
 
-    captDescrCheckBox = new QCheckBox(optionsBox);
+    captDescrCheckBox     = new QCheckBox(optionsBox);
     captDescrCheckBox->setText(i18n("Comment sets Description"));
-    optionsBoxLayout->addWidget(captDescrCheckBox);
 
-    resizeCheckBox = new QCheckBox(optionsBox);
+    resizeCheckBox        = new QCheckBox(optionsBox);
     resizeCheckBox->setText(i18n("Resize photos before uploading"));
-    optionsBoxLayout->addWidget(resizeCheckBox);
 
-    QHBoxLayout *dimLayout = new QHBoxLayout;
+    QHBoxLayout *hlay2    = new QHBoxLayout;
+    QLabel *resizeLabel   = new QLabel(i18n("Maximum dimension:"));
 
-    QLabel *resizeLabel = new QLabel(i18n("Maximum dimension:"));
-    dimLayout->addWidget(resizeLabel);
-
-    dimensionSpinBox  = new QSpinBox;
+    dimensionSpinBox      = new QSpinBox;
     dimensionSpinBox->setRange(1,1600);
     dimensionSpinBox->setValue(600);
-    dimLayout->addWidget(dimensionSpinBox);
-
-    optionsBoxLayout->addLayout(dimLayout);
 
     captTitleCheckBox->setChecked(true);
     captDescrCheckBox->setChecked(false);
     resizeCheckBox->setChecked(false);
     dimensionSpinBox->setEnabled(false);
 
-    optionsBox->setLayout(optionsBoxLayout);
-    frameLayout->addWidget(optionsBox);
+    // ---------------------------------------------------------------------------
 
-    optionFrame->setLayout(frameLayout);
-    galleryWidgetLayout->addWidget(optionFrame);
+    hlay2->addWidget(resizeLabel);
+    hlay2->addWidget(dimensionSpinBox);
+    hlay2->setSpacing(KDialog::spacingHint());
+    hlay2->setMargin(KDialog::spacingHint());
 
-    widget->setLayout(galleryWidgetLayout);
+    // ---------------------------------------------------------------------------
+
+    vlay2->addWidget(captTitleCheckBox);
+    vlay2->addWidget(captDescrCheckBox);
+    vlay2->addWidget(resizeCheckBox);
+    vlay2->addLayout(hlay2);
+    vlay2->setSpacing(KDialog::spacingHint());
+    vlay2->setMargin(KDialog::spacingHint());
+
+    optionsBox->setLayout(vlay2);
+
+    // ---------------------------------------------------------------------------
+
+    vlay->addWidget(newAlbumBtn);
+    vlay->addWidget(addPhotoBtn);
+    vlay->addWidget(optionsBox);
+    vlay->setSpacing(KDialog::spacingHint());
+    vlay->setMargin(KDialog::spacingHint());
+
+    optionFrame->setLayout(vlay);
+
+    // ---------------------------------------------------------------------------
+
+    hlay->addWidget(logo);
+    hlay->addWidget(albumView);
+    hlay->addWidget(optionFrame);
+    hlay->setSpacing(KDialog::spacingHint());
+    hlay->setMargin(KDialog::spacingHint());
+
+    widget->setLayout(hlay);
 }
 
-// --------------------------------------------------------------------------------------------------------------------------
+// --------------------------------------------------------------------------------------------------------------
 
 GalleryWindow::GalleryWindow(KIPI::Interface* interface, QWidget *parent, Gallery* pGallery)
-        : KDialog(parent),
-        m_interface(interface),
-        mpGallery(pGallery),
-        d(new Private(this))
+             : KDialog(parent),
+               m_interface(interface),
+               mpGallery(pGallery),
+               d(new Private(this))
 {
     setWindowTitle( i18n("Gallery Export") );
     setButtons( KDialog::Close | KDialog::User1 | KDialog::Help);
@@ -179,11 +219,11 @@ GalleryWindow::GalleryWindow(KIPI::Interface* interface, QWidget *parent, Galler
                                            ki18n("A Kipi plugin to export image collections to a remote Gallery server."),
                                            ki18n("(c) 2003-2005, Renchi Raju\n"
                                                     "(c) 2006-2007, Colin Guthrie\n"
-                                                    "(c) 2008, Andrea Diamantini\n")
-    );
+                                                    "(c) 2006-2009, Gilles Caulier\n"
+                                                    "(c) 2008, Andrea Diamantini\n"));
 
     m_about->addAuthor(ki18n("Renchi Raju"), ki18n("Author"),
-                       "renchi at pooh dot tam dot uiuc dot edu");
+                       "renchi dot raju at gmail dot com");
 
     m_about->addAuthor(ki18n("Colin Guthrie"), ki18n("Maintainer"),
                        "kde at colin dot guthr dot ie");
@@ -191,8 +231,13 @@ GalleryWindow::GalleryWindow(KIPI::Interface* interface, QWidget *parent, Galler
     m_about->addAuthor(ki18n("Andrea Diamantini"), ki18n("Developer"),
                        "adjam7 at gmail dot com");
 
+    m_about->addAuthor(ki18n("Gilles Caulier"), ki18n("Developer"),
+                       "caulier dot gilles at gmail dot com");
+
     // help button
-    disconnect(this, SIGNAL(helpClicked()), this, SLOT(slotHelp()));
+
+    disconnect(this, SIGNAL(helpClicked()),
+               this, SLOT(slotHelp()));
 
     KHelpMenu *helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeAction(helpMenu->menu()->actions().first());
@@ -204,8 +249,8 @@ GalleryWindow::GalleryWindow(KIPI::Interface* interface, QWidget *parent, Galler
 
     // User1 Button : to conf gallery settings
     KPushButton *confButton = button( User1 );
-    confButton->setText( i18n("settings") );
-    confButton->setIcon( KIcon("applications-system") );
+    confButton->setText( i18n("Settings") );
+    confButton->setIcon( KIcon("configure") );
     connect(confButton, SIGNAL(clicked()),
             this, SLOT(slotSettings() ) );
 
@@ -219,7 +264,7 @@ GalleryWindow::GalleryWindow(KIPI::Interface* interface, QWidget *parent, Galler
     m_progressDlg->setAutoClose(true);
     m_uploadCount = 0;
     m_uploadTotal = 0;
-    mpUploadList = new QStringList;
+    mpUploadList  = new QStringList;
 
     // connect functions
     connectSignals();
@@ -230,41 +275,69 @@ GalleryWindow::GalleryWindow(KIPI::Interface* interface, QWidget *parent, Galler
     slotDoLogin();
 }
 
-
 GalleryWindow::~GalleryWindow()
 {
     // write config
     KConfig config("kipirc");
     KConfigGroup group = config.group("GallerySync Galleries");
 
-    group.writeEntry("Resize", d->resizeCheckBox->isChecked());
-    group.writeEntry("Set title", d->captTitleCheckBox->isChecked());
+    group.writeEntry("Resize",          d->resizeCheckBox->isChecked());
+    group.writeEntry("Set title",       d->captTitleCheckBox->isChecked());
     group.writeEntry("Set description", d->captDescrCheckBox->isChecked());
-    group.writeEntry("Maximum Width",  d->dimensionSpinBox->value());
-    delete mpUploadList;
-    delete d;
-    delete m_about;
-}
+    group.writeEntry("Maximum Width",   d->dimensionSpinBox->value());
 
+    delete mpUploadList;
+    delete m_about;
+
+    delete d;
+}
 
 void GalleryWindow::connectSignals()
 {
-    connect(d->albumView, SIGNAL(itemSelectionChanged()), this , SLOT( slotAlbumSelected() ) );
-    connect(d->newAlbumBtn, SIGNAL(clicked()), this, SLOT(slotNewAlbum()));
-    connect(d->addPhotoBtn, SIGNAL(clicked()), this, SLOT(slotAddPhoto()));
-    connect(d->resizeCheckBox, SIGNAL(stateChanged(int)), this, SLOT(slotEnableSpinBox(int)));
+    connect(d->albumView, SIGNAL(itemSelectionChanged()),
+            this , SLOT( slotAlbumSelected() ) );
 
-    connect(m_progressDlg, SIGNAL( canceled() ), this, SLOT( slotAddPhotoCancel() ));
+    connect(d->newAlbumBtn, SIGNAL(clicked()),
+            this, SLOT(slotNewAlbum()));
 
-    connect(m_talker, SIGNAL(signalError(const QString&)), this, SLOT(slotError(const QString&)));
-    connect(m_talker, SIGNAL(signalBusy(bool)), this, SLOT(slotBusy(bool)));
-    connect(m_talker, SIGNAL(signalLoginFailed(const QString&)), this, SLOT(slotLoginFailed(const QString&)));
-    connect(m_talker, SIGNAL(signalAlbums(const QList<GAlbum>&)), this, SLOT(slotAlbums(const QList<GAlbum>&)));
-    connect(m_talker, SIGNAL(signalPhotos(const QList<GPhoto>&)), this, SLOT(slotPhotos(const QList<GPhoto>&)));
-    connect(m_talker, SIGNAL(signalAddPhotoSucceeded()), this, SLOT(slotAddPhotoSucceeded()));
-    connect(m_talker, SIGNAL(signalAddPhotoFailed(const QString&)), this, SLOT(slotAddPhotoFailed(const QString&)));
+    connect(d->addPhotoBtn, SIGNAL(clicked()),
+            this, SLOT(slotAddPhoto()));
+
+    connect(d->resizeCheckBox, SIGNAL(stateChanged(int)),
+            this, SLOT(slotEnableSpinBox(int)));
+
+    connect(d->logo, SIGNAL(leftClickedUrl(const QString&)),
+            this, SLOT(slotProcessUrl(const QString&)));
+
+    connect(m_progressDlg, SIGNAL( canceled() ),
+            this, SLOT( slotAddPhotoCancel() ));
+
+    connect(m_talker, SIGNAL(signalError(const QString&)),
+            this, SLOT(slotError(const QString&)));
+
+    connect(m_talker, SIGNAL(signalBusy(bool)),
+            this, SLOT(slotBusy(bool)));
+
+    connect(m_talker, SIGNAL(signalLoginFailed(const QString&)),
+            this, SLOT(slotLoginFailed(const QString&)));
+
+    connect(m_talker, SIGNAL(signalAlbums(const QList<GAlbum>&)),
+            this, SLOT(slotAlbums(const QList<GAlbum>&)));
+
+    connect(m_talker, SIGNAL(signalPhotos(const QList<GPhoto>&)),
+            this, SLOT(slotPhotos(const QList<GPhoto>&)));
+
+    connect(m_talker, SIGNAL(signalAddPhotoSucceeded()),
+            this, SLOT(slotAddPhotoSucceeded()));
+
+    connect(m_talker, SIGNAL(signalAddPhotoFailed(const QString&)),
+            this, SLOT(slotAddPhotoFailed(const QString&)));
 }
 
+void GalleryWindow::slotProcessUrl(const QString& url)
+{
+    KToolInvocation::self()->invokeBrowser(url);
+}
 
 void GalleryWindow::readSettings()
 {
@@ -272,11 +345,14 @@ void GalleryWindow::readSettings()
     KConfig config("kipirc");
     KConfigGroup group = config.group("GallerySync Galleries");
 
-    if (group.readEntry("Resize", false)) {
+    if (group.readEntry("Resize", false))
+    {
         d->resizeCheckBox->setChecked(true);
         d->dimensionSpinBox->setEnabled(true);
         d->dimensionSpinBox->setValue(group.readEntry("Maximum Width", 600));
-    } else {
+    }
+    else
+    {
         d->resizeCheckBox->setChecked(false);
         d->dimensionSpinBox->setEnabled(false);
     }
@@ -293,31 +369,33 @@ void GalleryWindow::readSettings()
 
 }
 
-
 void GalleryWindow::slotHelp()
 {
     KToolInvocation::invokeHelp("galleryexport", "kipi-plugins");
-    return;
 }
 
-
 void GalleryWindow::slotDoLogin()
 {
     GalleryTalker::setGallery2((2 == mpGallery->version()));
 
     KUrl url(mpGallery->url());
-    if (url.protocol().isEmpty()) {
+    if (url.protocol().isEmpty())
+    {
         url.setProtocol("http");
         url.setHost(mpGallery->url());
     }
-    if (!url.url().endsWith(".php")) {
+
+    if (!url.url().endsWith(QLatin1String(".php")))
+    {
         if (GalleryTalker::isGallery2())
             url.addPath("main.php");
         else
             url.addPath("gallery_remote2.php");
     }
+
     // If we've done something clever, save it back to the gallery.
-    if (mpGallery->url() != url.url()) {
+    if (mpGallery->url() != url.url())
+    {
         mpGallery->setUrl(url.url());
         mpGallery->save();
     }
@@ -325,14 +403,14 @@ void GalleryWindow::slotDoLogin()
     m_talker->login(url.url(), mpGallery->username(), mpGallery->password());
 }
 
-
 void GalleryWindow::slotLoginFailed(const QString& msg)
 {
     if (KMessageBox::warningYesNo(this,
                                   i18n("Failed to login into remote gallery. ")
                                   + msg
                                   + i18n("\nDo you want to check your settings and try again?"))
-            != KMessageBox::Yes) {
+            != KMessageBox::Yes)
+    {
         close();
         return;
     }
@@ -347,7 +425,6 @@ void GalleryWindow::slotLoginFailed(const QString& msg)
     delete configDlg;
 }
 
-
 void GalleryWindow::slotBusy(bool val)
 {
     if (val)
@@ -365,14 +442,12 @@ void GalleryWindow::slotBusy(bool val)
     }
 }
 
-
 void GalleryWindow::slotError(const QString& msg)
 {
     m_progressDlg->hide();
     KMessageBox::error(this, msg);
 }
 
-
 // FIXME
 void GalleryWindow::slotAlbums(const QList<GAlbum>& albumList)
 {
@@ -405,14 +480,14 @@ void GalleryWindow::slotAlbums(const QList<GAlbum>& albumList)
         }
         else
         {
-            QTreeWidgetItem *parentItem;
-            bool found = false;
-            int i = 0;
+            QTreeWidgetItem *parentItem = 0;
+            bool found                  = false;
+            int i                       = 0;
 
             while( !found && i < parentItemList.size() )
             {
                 parentItem = parentItemList.at(i);
-                if( parentItem->text(1) == QString::number(parentRefNum) )
+                if(parentItem && (parentItem->text(1) == QString::number(parentRefNum)))
                 {
                     QTreeWidgetItem *item = new QTreeWidgetItem(parentItem);
                     item->setText(0, cleanName(album.title) );
@@ -435,7 +510,6 @@ void GalleryWindow::slotAlbums(const QList<GAlbum>& albumList)
     }
 }
 
-
 // FIXME: avoid duplications
 void GalleryWindow::slotPhotos(const QList<GPhoto>& photoList)
 {
@@ -454,7 +528,6 @@ void GalleryWindow::slotPhotos(const QList<GPhoto>& photoList)
     }
 }
 
-
 void GalleryWindow::slotAlbumSelected()
 {
     QTreeWidgetItem* item = d->albumView->currentItem();
@@ -482,7 +555,6 @@ void GalleryWindow::slotAlbumSelected()
     }
 }
 
-
 void GalleryWindow::slotNewAlbum()
 {
     QPointer<AlbumDlg> dlg = new AlbumDlg(d->widget);
@@ -493,8 +565,8 @@ void GalleryWindow::slotNewAlbum()
         return;
     }
 
-    QString name = dlg->nameEdit->text();
-    QString title = dlg->titleEdit->text();
+    QString name    = dlg->nameEdit->text();
+    QString title   = dlg->titleEdit->text();
     QString caption = dlg->captionEdit->text();
 
     delete dlg;
@@ -504,60 +576,96 @@ void GalleryWindow::slotNewAlbum()
     // TODO: Change this to a QRegExp check.
     QChar ch;
     bool  clean = true;
-    for (int i = 0; i < name.length(); ++i) {
+
+    for (int i = 0; i < name.length(); ++i)
+    {
         ch = name[i];
-        if (ch == '\\') {
+        if (ch == '\\')
+        {
             clean = false;
             break;
-        } else if (ch == '/') {
+        }
+        else if (ch == '/')
+        {
             clean = false;
             break;
-        } else if (ch == '*') {
+        }
+        else if (ch == '*')
+        {
             clean = false;
             break;
-        } else if (ch == '?') {
+        }
+        else if (ch == '?')
+        {
             clean = false;
             break;
-        } else if (ch == '"') {
+        }
+        else if (ch == '"')
+        {
             clean = false;
             break;
-        } else if (ch == '\'') {
+        }
+        else if (ch == '\'')
+        {
             clean = false;
             break;
-        } else if (ch == '&') {
+        }
+        else if (ch == '&')
+        {
             clean = false;
             break;
-        } else if (ch == '<') {
+        }
+        else if (ch == '<')
+        {
             clean = false;
             break;
-        } else if (ch == '>') {
+        }
+        else if (ch == '>')
+        {
             clean = false;
             break;
-        } else if (ch == '|') {
+        }
+        else if (ch == '|')
+        {
             clean = false;
             break;
-        } else if (ch == '.') {
+        }
+        else if (ch == '.')
+        {
             clean = false;
             break;
-        } else if (ch == '+') {
+        }
+        else if (ch == '+')
+        {
             clean = false;
             break;
-        } else if (ch == '#') {
+        }
+        else if (ch == '#')
+        {
             clean = false;
             break;
-        } else if (ch == '(') {
+        }
+        else if (ch == '(')
+        {
             clean = false;
             break;
-        } else if (ch == ')') {
+        }
+        else if (ch == ')')
+        {
             clean = false;
             break;
-        } /*else if (ch == ' ') {
+        }
+        /*
+        else if (ch == ' ')
+        {
             clean = false;
             break;
-        }*/
+        }
+        */
     }
 
-    if (!clean) {
+    if (!clean)
+    {
         KMessageBox::error(this, i18n("Sorry, these characters are not allowed in album name: \\ / * ? \" \' & < > | . + # ( ) or spaces"));
         return;
     }
@@ -565,11 +673,11 @@ void GalleryWindow::slotNewAlbum()
     QString parentAlbumName;
 
     QTreeWidgetItem* item = d->albumView->currentItem();
-    int column = d->albumView->currentColumn();
+    int column            = d->albumView->currentColumn();
     if (item)
     {
         const GAlbum& album = d->albumDict.value( item->text(column) );
-        parentAlbumName = album.name;
+        parentAlbumName     = album.name;
         m_talker->createAlbum( parentAlbumName, name, title, caption);
     }
     else
@@ -578,11 +686,10 @@ void GalleryWindow::slotNewAlbum()
     }
 }
 
-
 void GalleryWindow::slotAddPhoto()
 {
     QTreeWidgetItem* item = d->albumView->currentItem();
-    int column = d->albumView->currentColumn();
+    int column            = d->albumView->currentColumn();
     if (!item)
         return;     // NO album selected: FIXME: do something
 
@@ -592,7 +699,7 @@ void GalleryWindow::slotAddPhoto()
         return;     // NO album name found: FIXME: do something
 
     // photoPath
-    KUrl::List urls = KIPIPlugins::ImageDialog::getImageURLs(this, m_interface);
+    KUrl::List urls = KIPIPlugins::ImageDialog::getImageUrls(this, m_interface);
     if (urls.isEmpty())
         return; // NO photo selected: FIXME: do something
 
@@ -608,7 +715,6 @@ void GalleryWindow::slotAddPhoto()
     slotAddPhotoNext();
 }
 
-
 void GalleryWindow::slotAddPhotoNext()
 {
     if ( mpUploadList->isEmpty() )
@@ -620,17 +726,16 @@ void GalleryWindow::slotAddPhotoNext()
     }
 
     QTreeWidgetItem* item = d->albumView->currentItem();
-    int column = d->albumView->currentColumn();
-    QString albumTitle = item->text(column);
-    const GAlbum& album = d->albumDict.value(albumTitle);
-
-    QString photoPath = mpUploadList->takeFirst();
-    QString photoName = QFileInfo(photoPath).baseName();
-    bool res = m_talker->addPhoto(album.name, photoPath, photoName,
-                                  d->captTitleCheckBox->isChecked(),
-                                  d->captDescrCheckBox->isChecked(),
-                                  d->resizeCheckBox->isChecked(),
-                                  d->dimensionSpinBox->value() );
+    int column            = d->albumView->currentColumn();
+    QString albumTitle    = item->text(column);
+    const GAlbum& album   = d->albumDict.value(albumTitle);
+    QString photoPath     = mpUploadList->takeFirst();
+    QString photoName     = QFileInfo(photoPath).baseName();
+    bool res              = m_talker->addPhoto(album.name, photoPath, photoName,
+                                               d->captTitleCheckBox->isChecked(),
+                                               d->captDescrCheckBox->isChecked(),
+                                               d->resizeCheckBox->isChecked(),
+                                               d->dimensionSpinBox->value() );
 
     if (!res)
     {
@@ -638,12 +743,12 @@ void GalleryWindow::slotAddPhotoNext()
         return;
     }
 
-    m_progressDlg->setLabelText( i18n("Uploading file ") +  KUrl(photoPath).fileName()  );
+    m_progressDlg->setLabelText( i18n("Uploading file ") +  KUrl(photoPath).fileName() );
+
     if (m_progressDlg->isHidden())
         m_progressDlg->show();
 }
 
-
 void GalleryWindow::slotAddPhotoSucceeded()
 {
     m_uploadCount++;
@@ -651,7 +756,6 @@ void GalleryWindow::slotAddPhotoSucceeded()
     slotAddPhotoNext();
 }
 
-
 void GalleryWindow::slotAddPhotoFailed(const QString& msg)
 {
     m_progressDlg->reset();
@@ -662,40 +766,40 @@ void GalleryWindow::slotAddPhotoFailed(const QString& msg)
                                                 "remote gallery. ")
                                            + msg
                                            + i18n("\nDo you want to continue?"))
-            != KMessageBox::Continue) {
-    } else {
+            != KMessageBox::Continue)
+    {
+    }
+    else
+    {
         slotAddPhotoNext();
     }
 }
 
-
 void GalleryWindow::slotAddPhotoCancel()
 {
     m_progressDlg->reset();
     m_progressDlg->hide();
-
     m_talker->cancel();
 }
 
-
 void GalleryWindow::slotEnableSpinBox(int n)
 {
     bool b;
-    switch(n) {
-    case 0:
-        b = false;
-        break;
-    case 1:
-    case 2:
-        b = true;
-        break;
-    default:
-        b = false;
+    switch(n)
+    {
+        case 0:
+            b = false;
+            break;
+        case 1:
+        case 2:
+            b = true;
+            break;
+        default:
+            b = false;
     }
     d->dimensionSpinBox->setEnabled(b);
 }
 
-
 void GalleryWindow::slotSettings()
 {
     // TODO: reload albumlist if OK slot used.
@@ -708,7 +812,7 @@ void GalleryWindow::slotSettings()
 }
 
 
-QString GalleryWindow::cleanName(QString str)
+QString GalleryWindow::cleanName(const QString& str)
 {
     QString plain = str;
     plain.replace("&lt;", "<");
@@ -719,6 +823,4 @@ QString GalleryWindow::cleanName(QString str)
     return plain;
 }
 
-
-
-#include "gallerywindow.moc"
+} // namespace KIPIGalleryExportPlugin
