@@ -68,7 +68,7 @@ K_EXPORT_PLUGIN ( GPSSyncFactory("kipiplugin_gpssync") )
 Plugin_GPSSync::Plugin_GPSSync(QObject *parent, const QVariantList &)
               : KIPI::Plugin( GPSSyncFactory::componentData(), parent, "GPSSync")
 {
-    kDebug(51001) << "Plugin_GPSSync plugin loaded" ;
+    kDebug(AREA_CODE_LOADING) << "Plugin_GPSSync plugin loaded" ;
 }
 
 void Plugin_GPSSync::setup( QWidget* widget )
@@ -105,7 +105,7 @@ void Plugin_GPSSync::setup( QWidget* widget )
     addAction( m_action_geolocation );
 
     m_actionKMLExport = actionCollection()->addAction("kmlexport");
-    m_actionKMLExport->setText(i18n("KML Export..."));
+    m_actionKMLExport->setText(i18n("Export to KML..."));
     m_actionKMLExport->setIcon(KIcon("applications-internet"));
     connect(m_actionKMLExport, SIGNAL(triggered(bool)),
             this, SLOT(slotKMLExport()));
@@ -116,7 +116,7 @@ void Plugin_GPSSync::setup( QWidget* widget )
 
     if ( !m_interface )
     {
-        kError( 51000 ) << "Kipi interface is null!" ;
+        kError() << "Kipi interface is null!" ;
         return;
     }
 
@@ -254,7 +254,7 @@ void Plugin_GPSSync::slotGPSEdit()
             }
 
             if (!ret)
-                kDebug(51000) << "Cannot set GPS location into file metadata from "
+                kDebug() << "Cannot set GPS location into file metadata from "
                          << url.fileName() ;
 
             // Set kipi host GPS location
@@ -363,7 +363,7 @@ void Plugin_GPSSync::slotGPSTrackListEdit()
                 ret &= exiv2Iface.save(url.path());
 
                 if (!ret)
-                    kDebug(51000) << "Cannot set GPS location into file metadata from "
+                    kDebug() << "Cannot set GPS location into file metadata from "
                              << url.fileName() ;
 
                 // Set kipi host GPS location
@@ -415,7 +415,7 @@ void Plugin_GPSSync::slotGPSRemove()
         ret &= exiv2Iface.save(url.path());
 
         if (!ret)
-            kDebug(51000) << "Cannot remove GPS location into file metadata from "
+            kDebug() << "Cannot remove GPS location into file metadata from "
                      << url.fileName() ;
 
         // Remove kipi host GPS location
@@ -432,7 +432,7 @@ void Plugin_GPSSync::slotKMLExport()
 
     if ( !selection.isValid() )
     {
-        kDebug(51000) << "No Selection!" ;
+        kDebug() << "No Selection!" ;
     }
     else
     {
@@ -459,6 +459,6 @@ KIPI::Category Plugin_GPSSync::category( KAction* action ) const
     if ( action == m_actionKMLExport )
        return KIPI::ExportPlugin;
 
-    kWarning( 51000 ) << "Unrecognized action for plugin category identification" ;
+    kWarning() << "Unrecognized action for plugin category identification" ;
     return KIPI::ImagesPlugin; // no warning from compiler, please
 }
