@@ -73,9 +73,8 @@ void ImageList::droppedImagesItems(const QList<QUrl>& urls)
 
     if( !filesPath.isEmpty() )
     {
-       emit addedDropItems( filesPath );
+       emit signalAddedDropItems( filesPath );
     }
 }
 
-
 } // namespace KIPIIpodExportPlugin
