@@ -23,10 +23,11 @@
 #ifndef IMAGELIST_H
 #define IMAGELIST_H
 
+// Qt includes.
+
 #include <QTreeWidget>
 
 namespace KIPIIpodExportPlugin
-
 {
 
 class ImageList : public QTreeWidget
@@ -35,15 +36,24 @@ class ImageList : public QTreeWidget
 
 public:
 
-    enum ListType { UploadType, IpodType };
+    enum ListType
+    {
+        UploadType, 
+        IpodType
+    };
+
+public:
 
     ImageList( ListType = UploadType, QWidget *parent = 0 );
 
-    ListType getType() const { return m_type; }
+    ListType getType() const
+    {
+        return m_type;
+    };
 
 Q_SIGNALS:
 
-    void addedDropItems( QStringList filesPath );
+    void signalAddedDropItems( const QStringList& filesPath );
 
 protected:
 
