@@ -7,6 +7,7 @@
  * Description : a tool to export image to an Ipod device.
  *
  * Copyright (C) 2006-2008 by Seb Ruiz <ruiz@kde.org>
+ * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -20,18 +21,8 @@
  *
  * ============================================================ */
 
-// System Includes
-extern "C" {
-#include <gdk-pixbuf/gdk-pixbuf.h>
-}
-
-// Local includes
-
-#include "IpodHeader.h"
-#include "ImageList.h"
-#include "ImageListItem.h"
 #include "IpodExportDialog.h"
-#include "IpodListItem.h"
+#include "IpodExportDialog.moc"
 
 // Qt includes
 
@@ -48,6 +39,7 @@ extern "C" {
 #include <QTreeWidgetItem>
 #include <QTimer>
 #include <QPointer>
+#include <QCloseEvent>
 
 // KDE includes
 
@@ -69,29 +61,44 @@ extern "C" {
 #include <ktoolinvocation.h>
 #include <kurl.h>
 
+// Libgdk includes.
+
+extern "C"
+{
+#include <gdk-pixbuf/gdk-pixbuf.h>
+}
+
+// Local includes
+
+#include "IpodHeader.h"
+#include "ImageList.h"
+#include "ImageListItem.h"
+#include "IpodListItem.h"
+
 namespace KIPIIpodExportPlugin
 {
 
 UploadDialog *UploadDialog::s_instance = 0;
 
-UploadDialog::UploadDialog(
+UploadDialog::UploadDialog
+(
 #if KIPI_PLUGIN
     KIPI::Interface* interface,
 #endif
-    const QString &caption, QWidget *parent )
-    : KDialog( parent )
+    const QString& caption, QWidget* /*parent*/ )
+    : KDialog(0)
+    , m_transferring( false )
 #if KIPI_PLUGIN
     , m_interface( interface )
 #endif
     , m_itdb( 0 )
     , m_ipodInfo( 0 )
     , m_ipodHeader( 0 )
-    , m_transferring( false )
     , m_mountPoint( QString::null )
     , m_deviceNode( QString::null )
     , m_ipodAlbumList( 0 )
 {
-    s_instance = this;
+    s_instance   = this;
 
     QWidget *box = new QWidget();
     setMainWidget( box );
@@ -106,7 +113,8 @@ UploadDialog::UploadDialog(
                                            0,
                                            KAboutData::License_GPL,
                                            ki18n("A tool to export image to an iPod device"),
-                                           ki18n("(c) 2006-2008, Seb Ruiz"));
+                                           ki18n("(c) 2006-2008, Seb Ruiz\n"
+                                                 "(c) 2008-2009, Gilles Caulier"));
 
     m_about->addAuthor(ki18n("Seb Ruiz"), ki18n("Author and Maintainer"),
                        "ruiz@kde.org");
@@ -114,16 +122,18 @@ UploadDialog::UploadDialog(
     m_about->addAuthor(ki18n("Gilles Caulier"), ki18n("Developer"),
                        "caulier dot gilles at gmail dot com");
 
-    disconnect( this, SIGNAL( helpClicked() ), this, SLOT( slotHelp() ) );
+    // ------------------------------------------------------------
+
+    disconnect(this, SIGNAL( helpClicked() ),
+               this, SLOT( slotHelp() ) );
 
     KHelpMenu* helpMenu = new KHelpMenu( this, m_about, false );
-
-    QAction *handbook = new QAction( i18n("Plugin Handbook"), this );
-    connect( handbook, SIGNAL( triggered(bool) ), this, SLOT( slotHelp() ) );
+    QAction *handbook   = new QAction( i18n("Plugin Handbook"), this );
+    connect(handbook, SIGNAL( triggered(bool) ),
+            this, SLOT( slotHelp() ) );
 
     helpMenu->menu()->removeAction( helpMenu->menu()->actions().first() );
     helpMenu->menu()->insertAction( helpMenu->menu()->actions().first(), handbook );
-
     button( Help )->setDelayedMenu( helpMenu->menu() );
 
     // ------------------------------------------------------------
@@ -218,7 +228,6 @@ UploadDialog::UploadDialog(
 
     m_destinationBox->setLayout( destinationBoxLayout );
 
-
     // Add sub-layouts to the main layout
     grid->addWidget( m_ipodHeader,     0, 0, 1, 2 ); // colspan=2
     grid->addWidget( m_urlListBox,     1, 0, 1, 1 );
@@ -229,35 +238,36 @@ UploadDialog::UploadDialog(
     /// populate the ipod view with a list of albums etc
     refreshDevices();
 
-#if KIPI_PLUGIN
-    /// add selected items to the ImageList
-    KIPI::ImageCollection images = interface->currentSelection();
-
-    if( images.isValid() )
-    {
-        KUrl::List selected = images.images();
-        for( KUrl::List::Iterator it = selected.begin(); it != selected.end(); ++it )
-        {
-            addUrlToList( (*it).path() );
-        }
-    }
-#endif
+    loadImagesFromCurrentSelection();
 
     enableButtons();
 
     /// connect the signals & slots
-    connect( m_createAlbumButton, SIGNAL( clicked() ), this, SLOT( createIpodAlbum() ) );
-    connect( m_removeAlbumButton, SIGNAL( clicked() ), this, SLOT( deleteIpodAlbum() ) );
-    connect( m_renameAlbumButton, SIGNAL( clicked() ), this, SLOT( renameIpodAlbum() ) );
 
-    connect( m_addImagesButton, SIGNAL( clicked() ), this, SLOT( imagesFilesButtonAdd() ) );
-    connect( m_remImagesButton, SIGNAL( clicked() ), this, SLOT( imagesFilesButtonRem() ) );
-    connect( m_transferImagesButton, SIGNAL( clicked() ), this, SLOT( startTransfer() ) );
+    connect(m_createAlbumButton, SIGNAL( clicked() ),
+            this, SLOT( createIpodAlbum() ) );
 
-    connect( m_uploadList, SIGNAL( addedDropItems(QStringList) ), this, SLOT( addDropItems(QStringList) ) );
+    connect(m_removeAlbumButton, SIGNAL( clicked() ),
+            this, SLOT( deleteIpodAlbum() ) );
+
+    connect(m_renameAlbumButton, SIGNAL( clicked() ),
+            this, SLOT( renameIpodAlbum() ) );
+
+    connect(m_addImagesButton, SIGNAL( clicked() ),
+            this, SLOT( imagesFilesButtonAdd() ) );
+
+    connect(m_remImagesButton, SIGNAL( clicked() ),
+            this, SLOT( imagesFilesButtonRem() ) );
+
+    connect(m_transferImagesButton, SIGNAL( clicked() ),
+            this, SLOT( startTransfer() ) );
+
+    connect(m_uploadList, SIGNAL( signalAddedDropItems(const QStringList&) ),
+            this, SLOT( addDropItems(const QStringList&) ) );
 
     connect(m_uploadList, SIGNAL( currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*) ),
             this, SLOT( imageSelected(QTreeWidgetItem*) ));
+
     connect(m_ipodAlbumList, SIGNAL( currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*) ),
             this, SLOT( ipodItemSelected(QTreeWidgetItem*) ));
 }
@@ -275,12 +285,49 @@ void UploadDialog::slotHelp()
     KToolInvocation::invokeHelp("ipodexport", "kipi-plugins");
 }
 
+void UploadDialog::slotClose()
+{
+    m_uploadList->clear();
+    done(Close);
+}
+
+void UploadDialog::closeEvent(QCloseEvent *e)
+{
+    if (!e) return;
+
+    m_uploadList->clear();
+    e->accept();
+}
+
+void UploadDialog::reactivate()
+{
+    loadImagesFromCurrentSelection();
+    show();
+}
+
+void UploadDialog::loadImagesFromCurrentSelection()
+{
+#if KIPI_PLUGIN
+    /// add selected items to the ImageList
+    KIPI::ImageCollection images = m_interface->currentSelection();
+
+    if( images.isValid() )
+    {
+        KUrl::List selected = images.images();
+        for( KUrl::List::Iterator it = selected.begin(); it != selected.end(); ++it )
+        {
+            addUrlToList( (*it).path() );
+        }
+    }
+#endif
+}
+
 void UploadDialog::getIpodAlbums()
 {
     if( !m_itdb )
         return;
 
-    kDebug(51000) << "populating ipod view" ;
+    kDebug() << "populating ipod view" ;
 
     // clear cache
     m_ipodAlbumList->clear();
@@ -289,7 +336,7 @@ void UploadDialog::getIpodAlbums()
     {
         Itdb_PhotoAlbum *ipodAlbum = (Itdb_PhotoAlbum *) it->data;
 
-        kDebug(51000) << " found album: " << ipodAlbum->name ;
+        kDebug() << " found album: " << ipodAlbum->name ;
 
         IpodAlbumItem *albumItem = new IpodAlbumItem( m_ipodAlbumList, ipodAlbum );
 
@@ -308,8 +355,8 @@ void UploadDialog::getIpodAlbumPhotos(IpodAlbumItem *item, Itdb_PhotoAlbum *albu
     for( GList *it = album->members; it; it = it->next )
     {
         Itdb_Artwork *photo = (Itdb_Artwork*) it->data;
-        gint photo_id = photo->id;
-        last = new IpodPhotoItem( item, last, photo );
+        gint photo_id       = photo->id;
+        last                = new IpodPhotoItem( item, last, photo );
         last->setText( 0, QString::number( photo_id ) );
     }
 }
@@ -350,11 +397,11 @@ void UploadDialog::enableButtons()
 
     const QList<QTreeWidgetItem*> ipodSelection = m_ipodAlbumList->selectedItems();
 
-    const bool hasSelection = ipodSelection.count() != 0;
+    const bool hasSelection                     = ipodSelection.count() != 0;
 
-    const bool isMasterLibrary = hasSelection && ipodSelection.first() == m_ipodAlbumList->topLevelItem( 0 );
+    const bool isMasterLibrary                  = hasSelection && ipodSelection.first() == m_ipodAlbumList->topLevelItem( 0 );
 
-    const bool isAlbum = hasSelection && ( dynamic_cast<IpodAlbumItem*>( ipodSelection.first() ) != 0 );
+    const bool isAlbum                          = hasSelection && ( dynamic_cast<IpodAlbumItem*>( ipodSelection.first() ) != 0 );
 
     m_removeAlbumButton->setEnabled( hasSelection && !isMasterLibrary );
     m_renameAlbumButton->setEnabled( hasSelection && !isMasterLibrary && isAlbum );
@@ -366,12 +413,11 @@ void UploadDialog::startTransfer()
         return;
 
     QTreeWidgetItem *selected = m_ipodAlbumList->currentItem();
-    IpodAlbumItem *ipodAlbum = dynamic_cast<IpodAlbumItem*>( selected );
+    IpodAlbumItem *ipodAlbum  = dynamic_cast<IpodAlbumItem*>( selected );
     if( !selected || !ipodAlbum )
         return;
 
-    m_transferring = true;
-
+    m_transferring         = true;
     Itdb_PhotoAlbum *album = ipodAlbum->photoAlbum();
 
     enableButton(KDialog::User1, false);
@@ -382,7 +428,7 @@ void UploadDialog::startTransfer()
     while( QTreeWidgetItem *item = m_uploadList->takeTopLevelItem(0) )
     {
 #define item static_cast<ImageListItem*>(item)
-        kDebug(51000) << "Uploading "      << item->pathSrc()
+        kDebug() << "Uploading "      << item->pathSrc()
                       << " to ipod album " << album->name ;
 
         Itdb_Artwork *art = itdb_photodb_add_photo( m_itdb, QFile::encodeName( item->pathSrc() ), 0, 0, &err );
@@ -390,20 +436,22 @@ void UploadDialog::startTransfer()
         {
             if( err )
             {
-                kDebug(51000) << "Error adding photo " << item->pathSrc() << " to database:"
+                kDebug() << "Error adding photo " << item->pathSrc() << " to database:"
                               << err->message ;
                 err = 0;
             }
         }
         else
+        {
             itdb_photodb_photoalbum_add_photo( m_itdb, album, art, 0 );
+        }
 
         delete item;
 #undef item
     }
 
     itdb_photodb_write( m_itdb, &err );
-    if( err ) kDebug(51000) << "Failed with error: " << err->message ;
+    if( err ) kDebug() << "Failed with error: " << err->message ;
 
     reloadIpodAlbum( ipodAlbum, album );
 
@@ -437,7 +485,7 @@ void UploadDialog::ipodItemSelected( QTreeWidgetItem *item )
 
     if( !gpixbuf )
     {
-        kDebug(51000) << "no thumb was found" ;
+        kDebug() << "no thumb was found" ;
         return;
     }
 #undef item
@@ -445,7 +493,7 @@ void UploadDialog::ipodItemSelected( QTreeWidgetItem *item )
 //     GdkPixbuf *buf = itdb_thumb_get_gdk_pixbuf( m_itdb->device, thumb );
 //     int size = 0;
 //     QImage *image = buf->convertToImage();
-//     kDebug(51000) << "image size: " << image->size() ;
+//     kDebug() << "image size: " << image->size() ;
 //
 //     QPixmap pix;
 //     pix.convertFromImage( image );
@@ -474,8 +522,8 @@ void UploadDialog::imageSelected( QTreeWidgetItem *item )
 
     KIO::PreviewJob* m_thumbJob = KIO::filePreview( url, m_imagePreview->height() );
 
-    connect( m_thumbJob, SIGNAL( gotPreview(const KFileItem*, const QPixmap&) ),
-                   this,   SLOT( gotImagePreview(const KFileItem*, const QPixmap&) ) );
+    connect(m_thumbJob, SIGNAL( gotPreview(const KFileItem*, const QPixmap&) ),
+            this,   SLOT( gotImagePreview(const KFileItem*, const QPixmap&) ) );
 }
 
 void UploadDialog::gotImagePreview( const KFileItem* url, const QPixmap& pixmap )
@@ -508,7 +556,7 @@ void UploadDialog::imagesFilesButtonAdd()
     KUrl::List urls;
 
 #if KIPI_PLUGIN
-    urls = KIPIPlugins::ImageDialog::getImageURLs(this, m_interface);
+    urls = KIPIPlugins::ImageDialog::getImageUrls(this, m_interface);
 #else
     const QString filter = QString( "*.jpg *.jpeg *.jpe *.tiff *.gif *.png *.bmp|" + i18n("Image files") );
     QPointer<KFileDialog> dlg = new KFileDialog( QString(), filter, this );
@@ -552,7 +600,7 @@ void UploadDialog::createIpodAlbum()
                                               helper, &ok, this );
     if( ok )
     {
-        kDebug(51000) << "creating album " << newAlbum ;
+        kDebug() << "creating album " << newAlbum ;
 
         Itdb_PhotoAlbum *photoAlbum = itdb_photodb_photoalbum_create( m_itdb, QFile::encodeName( newAlbum ), -1/*end*/ );
         // add the new album to the list view
@@ -606,7 +654,7 @@ bool UploadDialog::deleteIpodPhoto( IpodPhotoItem *photo )
 
     if( !artwork )
     {
-        kDebug(51000) << "Could not find photo artwork with id: " << photo->text(0) ;
+        kDebug() << "Could not find photo artwork with id: " << photo->text(0) ;
         return false;
     }
 
@@ -625,7 +673,7 @@ bool UploadDialog::deleteIpodPhoto( IpodPhotoItem *photo )
                 QTreeWidgetItem *photoItem = albumItem->child( j );
                 if( photoItem->text(0) == photo->text(0) ) // FIXME
                 {
-                    kDebug(51000) << "removing reference to photo from album " << albumItem->text(0) ;
+                    kDebug() << "removing reference to photo from album " << albumItem->text(0) ;
                     delete photoItem;
                     break; // Items can't be duplicated in the same album
                 }
@@ -637,7 +685,7 @@ bool UploadDialog::deleteIpodPhoto( IpodPhotoItem *photo )
 
 bool UploadDialog::deleteIpodAlbum( IpodAlbumItem *album )
 {
-    kDebug(51000) << "deleting album: " << album->name() << ", and removing all photos" ;
+    kDebug() << "deleting album: " << album->name() << ", and removing all photos" ;
     itdb_photodb_photoalbum_remove( m_itdb, album->photoAlbum(), true/*remove photos*/);
 
     return true;
@@ -670,7 +718,7 @@ void UploadDialog::deleteIpodAlbum()
     itdb_photodb_write( m_itdb, &err );
 }
 
-void UploadDialog::addDropItems( QStringList filesPath )
+void UploadDialog::addDropItems( const QStringList& filesPath )
 {
     if( filesPath.isEmpty() ) return;
 
@@ -683,7 +731,7 @@ void UploadDialog::addDropItems( QStringList filesPath )
     enableButton( KDialog::User1, m_uploadList->model()->hasChildren() > 0 );
 }
 
-void UploadDialog::addUrlToList( QString file )
+void UploadDialog::addUrlToList( const QString& file )
 {
     QFileInfo *fi = new QFileInfo( file );
 
@@ -692,12 +740,11 @@ void UploadDialog::addUrlToList( QString file )
     delete fi;
 }
 
-
 bool UploadDialog::openDevice()
 {
     if( m_itdb )
     {
-        kDebug(51000) <<  "ipod at " << m_mountPoint << " already opened" ;
+        kDebug() <<  "ipod at " << m_mountPoint << " already opened" ;
         return false;
     }
 
@@ -754,7 +801,7 @@ bool UploadDialog::openDevice()
 
     if( !ipodFound )
     {
-        kDebug(51000) << "no mounted ipod found" ;
+        kDebug() << "no mounted ipod found" ;
         if( m_itdb )
         {
             itdb_photodb_free( m_itdb );
@@ -763,12 +810,12 @@ bool UploadDialog::openDevice()
         return false;
     }
 
-    kDebug(51000) << "ipod found mounted at " << m_mountPoint ;
+    kDebug() << "ipod found mounted at " << m_mountPoint ;
 
     /// No photodb was able to be parsed, so offer to initialise the ipod for the user.
     if( !m_itdb )
     {
-        kDebug(51000) << "could not find iTunesDB on device mounted at " << m_mountPoint ;
+        kDebug() << "could not find iTunesDB on device mounted at " << m_mountPoint ;
 
         QString msg = i18n( "An iPod photo database could not be found on the device mounted at %1. "
                             "Initialize the iPod photo database?",
@@ -783,7 +830,7 @@ bool UploadDialog::openDevice()
 
             if( !m_itdb )
             {
-                kDebug(51000) << "Could not initialise photodb..." ;
+                kDebug() << "Could not initialise photodb..." ;
                 return false;
             }
 
@@ -791,7 +838,9 @@ bool UploadDialog::openDevice()
             itdb_photodb_write( m_itdb, &err );
         }
         else
+        {
             return false;
+        }
     }
 
     return true;
@@ -822,10 +871,9 @@ QString UploadDialog::ipodModel() const
     return QString::null;
 }
 
-
 void UploadDialog::refreshDevices()
 {
-    kDebug(51000) << "refreshing ipod devices" ;
+    kDebug() << "refreshing ipod devices" ;
 
     if( !m_ipodHeader )
         return;
@@ -846,7 +894,7 @@ void UploadDialog::refreshDevices()
 
         if( !m_ipodInfo || model.isEmpty() || model == "Invalid" )
         {
-            kDebug(51000) << "the ipod model must be set before photos can be added" ;
+            kDebug() << "the ipod model must be set before photos can be added" ;
             m_ipodHeader->setViewType( IpodHeader::IncompatibleIpod );
 
             connect(m_ipodHeader, SIGNAL( updateSysInfo() ),
@@ -869,7 +917,7 @@ void UploadDialog::refreshDevices()
 
 void UploadDialog::updateSysInfo()
 {
-    kDebug(51000) << "updateSysInfo()" ;
+    kDebug() << "updateSysInfo()" ;
 }
 
 } // namespace KIPIIpodExportPlugin
