@@ -6,7 +6,7 @@
  * Date        : 2003-10-14
  * Description : batch image rotation
  *
- * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2004-2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
@@ -24,6 +24,9 @@
 
 #define XMD_H
 
+#include "imagerotate.h"
+#include "imagerotate.moc"
+
 // C++ includes
 
 #include <cstdio>
@@ -53,8 +56,6 @@ extern "C"
 #include "utils.h"
 #include "transupp.h"
 #include "jpegtransform.h"
-#include "imagerotate.h"
-#include "imagerotate.moc"
 
 namespace KIPIJPEGLossLessPlugin
 {
@@ -117,7 +118,7 @@ bool ImageRotate::rotate(const QString& src, RotateAction angle, QString& err, b
     }
 
     // Move back to original file
-    if (!Utils::MoveFile(tmp, src)) 
+    if (!Utils::moveOneFile(tmp, src))
     {
         err = i18n("Cannot update source image");
         return false;
@@ -155,7 +156,7 @@ bool ImageRotate::rotateJPEG(const QString& src, const QString& dest, RotateActi
         }
         default:
         {
-            kError( 51000 ) << "ImageRotate: Nonstandard rotation angle";
+            kError() << "ImageRotate: Nonstandard rotation angle";
             err = i18n("Nonstandard rotation angle");
             return false;
         }
@@ -195,7 +196,7 @@ bool ImageRotate::rotateImageMagick(const QString& src, const QString& dest,
         }
         default:
         {
-            kError( 51000 ) << "ImageRotate: Nonstandard rotation angle";
+            kError() << "ImageRotate: Nonstandard rotation angle";
             err = i18n("Nonstandard rotation angle");
             return false;
         }
@@ -203,7 +204,7 @@ bool ImageRotate::rotateImageMagick(const QString& src, const QString& dest,
 
     process << src + QString("[0]") << dest;
 
-    kDebug(51000) << "ImageMagick Command line: " << process.program();
+    kDebug() << "ImageMagick Command line: " << process.program();
 
     process.start();
 
