@@ -6,7 +6,7 @@
  * Date        : 2003-09-26
  * Description : loss less images transformations plugin.
  *
- * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2004-2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
@@ -22,6 +22,9 @@
  *
  * ============================================================ */
 
+#include "plugin_jpeglossless.h"
+#include "plugin_jpeglossless.moc"
+
 // C++ includes
 
 #include <iostream>
@@ -50,8 +53,6 @@
 
 #include "batchprogressdialog.h"
 #include "actionthread.h"
-#include "plugin_jpeglossless.h"
-#include "plugin_jpeglossless.moc"
 
 K_PLUGIN_FACTORY( JPEGLosslessFactory, registerPlugin<Plugin_JPEGLossless>(); )
 K_EXPORT_PLUGIN ( JPEGLosslessFactory("kipiplugin_jpeglossless") )
@@ -91,10 +92,11 @@ public:
     KIPIJPEGLossLessPlugin::ActionThread *thread;
 };
 
-Plugin_JPEGLossless::Plugin_JPEGLossless(QObject *parent, const QVariantList &)
-                   : KIPI::Plugin( JPEGLosslessFactory::componentData(), parent, "JPEGLossless"), d(new Plugin_JPEGLosslessPriv)
+Plugin_JPEGLossless::Plugin_JPEGLossless(QObject *parent, const QVariantList&)
+                   : KIPI::Plugin(JPEGLosslessFactory::componentData(), parent, "JPEGLossless"), 
+                     d(new Plugin_JPEGLosslessPriv)
 {
-    kDebug(51001) << "Plugin_JPEGLossless plugin loaded";
+    kDebug(AREA_CODE_LOADING) << "Plugin_JPEGLossless plugin loaded";
 }
 
 Plugin_JPEGLossless::~Plugin_JPEGLossless()
@@ -103,7 +105,7 @@ Plugin_JPEGLossless::~Plugin_JPEGLossless()
     delete d;
 }
 
-void Plugin_JPEGLossless::setup( QWidget* widget )
+void Plugin_JPEGLossless::setup(QWidget* widget)
 {
     KIPI::Plugin::setup( widget );
 
@@ -119,14 +121,14 @@ void Plugin_JPEGLossless::setup( QWidget* widget )
 
     KAction *left = actionCollection()->addAction("rotate_ccw");
     left->setText(i18n("Left"));
-    left->setShortcut(Qt::SHIFT+Qt::CTRL+Qt::Key_Left);
+    left->setShortcut(KShortcut(Qt::SHIFT+Qt::CTRL+Qt::Key_Left));
     connect(left, SIGNAL(triggered(bool)),
             this, SLOT(slotRotateLeft()));
     d->action_RotateImage->addAction(left);
 
     KAction *right = actionCollection()->addAction("rotate_cw");
     right->setText(i18n("Right"));
-    right->setShortcut(Qt::SHIFT+Qt::CTRL+Qt::Key_Right);
+    right->setShortcut(KShortcut(Qt::SHIFT+Qt::CTRL+Qt::Key_Right));
     connect(right, SIGNAL(triggered(bool)),
             this, SLOT(slotRotateRight()));
     d->action_RotateImage->addAction(right);
@@ -136,14 +138,14 @@ void Plugin_JPEGLossless::setup( QWidget* widget )
 
     KAction *hori = actionCollection()->addAction("flip_horizontal");
     hori->setText(i18n("Horizontally"));
-    hori->setShortcut(Qt::CTRL+Qt::Key_Asterisk);
+    hori->setShortcut(KShortcut(Qt::CTRL+Qt::Key_Asterisk));
     connect(hori, SIGNAL(triggered(bool)),
             this, SLOT(slotFlipHorizontally()));
     d->action_FlipImage->addAction(hori);
 
     KAction *verti = actionCollection()->addAction("flip_vertical");
     verti->setText(i18n("Vertically"));
-    verti->setShortcut(Qt::CTRL+Qt::Key_Slash);
+    verti->setShortcut(KShortcut(Qt::CTRL+Qt::Key_Slash));
     connect(verti, SIGNAL(triggered(bool)),
             this, SLOT(slotFlipVertically()));
     d->action_FlipImage->addAction(verti);
@@ -158,7 +160,7 @@ void Plugin_JPEGLossless::setup( QWidget* widget )
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>( parent() );
     if ( !interface )
     {
-        kError( 51000 ) << "Kipi interface is null!";
+        kError() << "Kipi interface is null!";
         return;
     }
 
@@ -169,14 +171,14 @@ void Plugin_JPEGLossless::setup( QWidget* widget )
 
     d->thread = new KIPIJPEGLossLessPlugin::ActionThread(interface, this);
 
-    connect( d->thread, SIGNAL(starting(const QString &, int)),
-             this, SLOT(slotStarting(const QString &, int)));
+    connect( d->thread, SIGNAL(starting(const QString&, int)),
+             this, SLOT(slotStarting(const QString&, int)));
 
-    connect( d->thread, SIGNAL(finished(const QString &, int)),
-             this, SLOT(slotFinished(const QString &, int)));
+    connect( d->thread, SIGNAL(finished(const QString&, int)),
+             this, SLOT(slotFinished(const QString&, int)));
 
-    connect( d->thread, SIGNAL(failed(const QString &, int, const QString &)),
-             this, SLOT(slotFailed(const QString &, int, const QString &)));
+    connect( d->thread, SIGNAL(failed(const QString&, int, const QString&)),
+             this, SLOT(slotFailed(const QString&, int, const QString&)));
 
     connect( interface, SIGNAL( selectionChanged( bool ) ),
              d->action_AutoExif, SLOT( setEnabled( bool ) ) );
@@ -201,7 +203,7 @@ void Plugin_JPEGLossless::slotFlipVertically()
     flip(KIPIJPEGLossLessPlugin::FlipVertical, i18n("vertically"));
 }
 
-void Plugin_JPEGLossless::flip(KIPIJPEGLossLessPlugin::FlipAction action, const QString &title)
+void Plugin_JPEGLossless::flip(KIPIJPEGLossLessPlugin::FlipAction action, const QString& title)
 {
     KUrl::List items = images();
     if (items.count() <= 0) return;
@@ -245,7 +247,7 @@ void Plugin_JPEGLossless::slotRotateExif()
     rotate(KIPIJPEGLossLessPlugin::Rot0, i18n("using Exif orientation tag"));
 }
 
-void Plugin_JPEGLossless::rotate(KIPIJPEGLossLessPlugin::RotateAction action, const QString &title)
+void Plugin_JPEGLossless::rotate(KIPIJPEGLossLessPlugin::RotateAction action, const QString& title)
 {
     KUrl::List items = images();
     if (items.count() <= 0) return;
@@ -278,7 +280,7 @@ void Plugin_JPEGLossless::slotConvert2GrayScale()
 {
     KUrl::List items = images();
     if (items.count() <= 0 ||
-        KMessageBox::No==KMessageBox::warningYesNo(kapp->activeWindow(),
+        KMessageBox::No == KMessageBox::warningYesNo(kapp->activeWindow(),
                      i18n("<p>Are you sure you wish to convert the selected image(s) to "
                          "black and white? This operation <b>cannot</b> be undone.</p>")))
         return;
@@ -316,14 +318,14 @@ void Plugin_JPEGLossless::slotCancel()
 
     if ( !interface )
     {
-        kError( 51000 ) << "Kipi interface is null!";
+        kError() << "Kipi interface is null!";
         return;
     }
 
     interface->refreshImages( d->images );
 }
 
-void Plugin_JPEGLossless::slotStarting(const QString &filePath, int action)
+void Plugin_JPEGLossless::slotStarting(const QString& filePath, int action)
 {
     QString text;
 
@@ -346,14 +348,14 @@ void Plugin_JPEGLossless::slotStarting(const QString &filePath, int action)
         }
         default:
         {
-            kWarning( 51000 ) << "KIPIJPEGLossLessPlugin: Unknown event";
+            kWarning() << "KIPIJPEGLossLessPlugin: Unknown event";
         }
     }
 
     d->progressDlg->addedAction(text, KIPIPlugins::StartingMessage);
 }
 
-void Plugin_JPEGLossless::slotFinished(const QString &filePath, int action)
+void Plugin_JPEGLossless::slotFinished(const QString& filePath, int action)
 {
     Q_UNUSED(filePath);
 
@@ -378,7 +380,7 @@ void Plugin_JPEGLossless::slotFinished(const QString &filePath, int action)
         }
         default:
         {
-            kWarning( 51000 ) << "KIPIJPEGLossLessPlugin: Unknown event";
+            kWarning() << "KIPIJPEGLossLessPlugin: Unknown event";
         }
     }
 
@@ -387,7 +389,7 @@ void Plugin_JPEGLossless::slotFinished(const QString &filePath, int action)
     oneTaskCompleted();
 }
 
-void Plugin_JPEGLossless::slotFailed(const QString &filePath, int action, const QString &errString)
+void Plugin_JPEGLossless::slotFailed(const QString& filePath, int action, const QString& errString)
 {
     Q_UNUSED(filePath);
 
@@ -413,7 +415,7 @@ void Plugin_JPEGLossless::slotFailed(const QString &filePath, int action, const
         }
         default:
         {
-            kWarning( 51000 ) << "KIPIJPEGLossLessPlugin: Unknown event";
+            kWarning() << "KIPIJPEGLossLessPlugin: Unknown event";
         }
     }
 
@@ -452,7 +454,7 @@ void Plugin_JPEGLossless::oneTaskCompleted()
 
         if ( !interface )
         {
-           kError( 51000 ) << "Kipi interface is null!";
+           kError() << "Kipi interface is null!";
            return;
         }
 
@@ -460,7 +462,7 @@ void Plugin_JPEGLossless::oneTaskCompleted()
     }
 }
 
-KIPI::Category Plugin_JPEGLossless::category( KAction* action ) const
+KIPI::Category Plugin_JPEGLossless::category(KAction* action) const
 {
     if (action == d->action_AutoExif)
         return KIPI::ImagesPlugin;
@@ -471,7 +473,7 @@ KIPI::Category Plugin_JPEGLossless::category( KAction* action ) const
     else if ( action == d->action_Convert2GrayScale )
        return KIPI::ImagesPlugin;
 
-    kWarning( 51000 ) << "Unrecognized action for plugin category identification";
+    kWarning() << "Unrecognized action for plugin category identification";
     return KIPI::ImagesPlugin; // no warning from compiler, please
 }
 
@@ -481,7 +483,7 @@ KUrl::List Plugin_JPEGLossless::images()
 
     if ( !interface )
     {
-        kError( 51000 ) << "Kipi interface is null!";
+        kError() << "Kipi interface is null!";
         return KUrl::List();
     }
 
