@@ -23,7 +23,7 @@
 #include "iptcenvelope.h"
 #include "iptcenvelope.moc"
 
-// Qt includes.
+// Qt includes
 
 #include <QCheckBox>
 #include <QLabel>
@@ -32,7 +32,7 @@
 #include <QValidator>
 #include <QGridLayout>
 
-// KDE includes.
+// KDE includes
 
 #include <kcombobox.h>
 #include <kdatewidget.h>
@@ -42,15 +42,15 @@
 #include <klocale.h>
 #include <ktextedit.h>
 
-// LibKExiv2 includes.
+// LibKExiv2 includes
 
 #include <libkexiv2/kexiv2.h>
 
-// LibKDcraw includes.
+// LibKDcraw includes
 
 #include <libkdcraw/squeezedcombobox.h>
 
-// Local includes.
+// Local includes
 
 #include "metadatacheckbox.h"
 #include "pluginsversion.h"
@@ -270,7 +270,7 @@ IPTCEnvelope::IPTCEnvelope(QWidget* parent)
                  "<b><a href='http://en.wikipedia.org/wiki/IPTC'>IPTC</a></b> "
                  "text tags only support the printable "
                  "<b><a href='http://en.wikipedia.org/wiki/Ascii'>ASCII</a></b> "
-                 "characters set and limit strings size. "
+                 "characters and limit string sizes. "
                  "Use contextual help for details.</b>"), this);
     note->setOpenExternalLinks(true);
     note->setWordWrap(true);
