@@ -70,7 +70,7 @@ Plugin_MetadataEdit::Plugin_MetadataEdit(QObject *parent, const QVariantList&)
                      m_interface(0),
                      m_lastSelectedDirectory()
 {
-    kDebug(51001) << "Plugin_MetadataEdit plugin loaded";
+    kDebug(AREA_CODE_LOADING) << "Plugin_MetadataEdit plugin loaded";
 }
 
 void Plugin_MetadataEdit::setup( QWidget* widget )
@@ -163,7 +163,7 @@ void Plugin_MetadataEdit::setup( QWidget* widget )
     m_interface = dynamic_cast< KIPI::Interface* >( parent() );
     if ( !m_interface )
     {
-        kError( 51000 ) << "Kipi interface is null!";
+        kError() << "Kipi interface is null!";
         return;
     }
 
@@ -852,6 +852,6 @@ KIPI::Category Plugin_MetadataEdit::category( KAction* action ) const
     if ( action == m_actionMetadataEdit )
        return KIPI::ImagesPlugin;
 
-    kWarning( 51000 ) << "Unrecognized action for plugin category identification";
+    kWarning() << "Unrecognized action for plugin category identification";
     return KIPI::ImagesPlugin; // no warning from compiler, please
 }
