@@ -7,7 +7,7 @@
  * Description : a kipi plugin to export images to Picasa web service
  *
  * Copyright (C) 2007-2008 by Vardhman Jain <vardhman at gmail dot com>
- * Copyright (C) 2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009 by Luka Renko <lure at kubuntu dot org>
  *
  * This program is free software; you can redistribute it
@@ -110,7 +110,8 @@ QString PicasawebTalker::getApiSig(QString secret, QStringList headers)
 {
     QStringList compressed ;//= new List<string>(headers.Length);
 
-    for ( QStringList::ConstIterator it = headers.constBegin(); it != headers.constEnd(); ++it ) {
+    for ( QStringList::ConstIterator it = headers.constBegin(); it != headers.constEnd(); ++it )
+    {
 	QString str = (*it);
         QStringList strList = str.split("=");
         compressed.append(strList[0].trimmed()+strList[1].trimmed());
@@ -140,7 +141,7 @@ void PicasawebTalker::getToken(const QString& username, const QString& password
 
     if (!loginDialog)
     {
-        kDebug(51000) << " Out of memory error " ;
+        kDebug() << " Out of memory error " ;
     }
 
     if (loginDialog->exec() == QDialog::Accepted)
@@ -190,7 +191,7 @@ void PicasawebTalker::authenticate(const QString& token, const QString& username
 {
     if (!token.isNull() || token.length() > 0)
     {
-        kDebug(51000) << " Checktoken being called" << token ;
+        kDebug() << " Checktoken being called" << token ;
         m_username = username;
         m_password = password; //this would be needed if the checktoken failed
                                 //we would need to reauthenticate using auth
@@ -212,7 +213,7 @@ void PicasawebTalker::checkToken(const QString& token)
     }
 
     QString url = "http://picasaweb.google.com/data/feed/api/user/" + m_username + "?kind=album";
-    kDebug(51000) << " token value is " << token ;
+    kDebug() << " token value is " << token ;
     QString auth_string = "GoogleLogin auth=" + token;
     KIO::TransferJob* job = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
     job->ui()->setWindow(m_parent);
@@ -306,7 +307,8 @@ void PicasawebTalker::getPhotoProperty(const QString& method,const QString& argL
 
 void PicasawebTalker::addPhotoTag(const QString& photoURI, const QString& tag)
 {
-    //if (m_job && m_state != FE_ADDTAG){ //we shouldn't kill the old tag request
+    //if (m_job && m_state != FE_ADDTAG)
+    //{ // we shouldn't kill the old tag request
     //	m_job->kill();
     //	m_job = 0;
     //}
@@ -476,10 +478,10 @@ bool PicasawebTalker::addPhoto(const QString& photoPath, FPhotoInfo& info,
         }
         else
         {
-            kWarning(51000) << "Image " << photoPath << " has no exif data";
+            kWarning() << "Image " << photoPath << " has no exif data";
         }
 
-        kDebug(51000) << "Resizing and saving to temp file: " << tmpPath;
+        kDebug() << "Resizing and saving to temp file: " << tmpPath;
 
         if (!form.addFile("photo", tmpPath))
         {
@@ -634,7 +636,7 @@ void PicasawebTalker::slotResult(KJob *job)
     {
         if (m_state == FE_CHECKTOKEN) 
         {
-            kDebug(51000) << " Error encountered in checking token, require user credentials" ;
+            kDebug() << " Error encountered in checking token, require user credentials" ;
             return getToken(m_username, "");
         }
     }
@@ -683,7 +685,7 @@ void PicasawebTalker::parseResponseCheckToken(const QByteArray &data)
     // TODO(vardhman): Fix this with proper error handling.
     if(!success)
         getToken(m_username, m_password);
-     // kDebug(51000) << "Return code is " << transReturn ;
+     // kDebug() << "Return code is " << transReturn ;
      emit slotCheckTokenSuccessful();
     // emit signalError(errorString);
 }
@@ -703,7 +705,7 @@ void PicasawebTalker::parseResponseGetToken(const QByteArray &data)
         if ( strList.count() > 0 )
         {
             m_token = strList[1].trimmed();
-            kDebug(51000) << " m_token as obtained in token Response " << m_token ;
+            kDebug() << " m_token as obtained in token Response " << m_token ;
             success = true;
         }
     }
@@ -954,16 +956,16 @@ void PicasawebTalker::parseResponsePhotoProperty(const QByteArray &data)
 
         if ( node.isElement() && node.nodeName() == "err" )
         {
-            kDebug(51001) << "Checking Error in response" ;
+            kDebug(AREA_CODE_LOADING) << "Checking Error in response" ;
             QString code = node.toElement().attribute("code");
-            kDebug(51001) << "Error code=" << code ;
-            kDebug(51001) << "Msg=" << node.toElement().attribute("msg") ;
+            kDebug(AREA_CODE_LOADING) << "Error code=" << code ;
+            kDebug(AREA_CODE_LOADING) << "Msg=" << node.toElement().attribute("msg") ;
             emit signalError(code);
         }
         node = node.nextSibling();
     }
 
-    kDebug(51001) << "GetToken finished" ;
+    kDebug(AREA_CODE_LOADING) << "GetToken finished" ;
     if (!success)
     {
         emit signalAddPhotoFailed(i18n("Failed to query photo information"));
