@@ -71,8 +71,7 @@ namespace KIPIPicasawebExportPlugin
 {
 
 PicasawebWindow::PicasawebWindow(KIPI::Interface* interface, const QString &tmpFolder, QWidget* /*parent*/)
-               : KDialog(0),
-                 m_tmp(tmpFolder)
+               : KDialog(0), m_tmp(tmpFolder)
 {
     setWindowTitle(i18n("Export to Picasa Web Service"));
     setWindowIcon(KIcon("picasa"));
@@ -190,9 +189,9 @@ PicasawebWindow::PicasawebWindow(KIPI::Interface* interface, const QString &tmpF
     KConfig config("kipirc");
     KConfigGroup grp = config.group( "PicasawebExport Settings");
     QString token    = grp.readEntry("token");
-    kDebug(51000) << "Read token from database to be " << token ;
     QString username = grp.readEntry("username");
     QString password = grp.readEntry("password");
+    kDebug() << "Read token from database to be " << token ;
 
     //no saving password rt now
     if (grp.readEntry("Resize", false))
@@ -216,6 +215,24 @@ PicasawebWindow::PicasawebWindow(KIPI::Interface* interface, const QString &tmpF
     m_talker->authenticate(token, username, password);
 }
 
+void PicasawebWindow::slotClose()
+{
+    kDebug() << "Writing token value as ########### " << m_talker->token() << " #######" ;
+    saveSettings();
+    delete m_urls;
+    done(Close);
+}
+
+void PicasawebWindow::closeEvent(QCloseEvent *e) 
+{
+    if (!e) return;
+
+    kDebug() << "Writing token value as ########### " << m_talker->token() << " #######" ;
+    saveSettings();
+    delete m_urls;
+    e->accept();
+}
+
 void PicasawebWindow::slotRefreshSizeButtons(bool /*st*/)
 {
     if(m_resizeCheckBox->isChecked())
@@ -235,43 +252,25 @@ void PicasawebWindow::slotUpdateAlbumsList()
     m_talker->listAllAlbums();
 }
 
-void PicasawebWindow::slotClose()
-{
-    //handle the close of the window that is calling the destructor.
-    delete this;
-}
-
-void PicasawebWindow::closeEvent(QCloseEvent *e) 
-{
-    if (!e) return;
-
-    kDebug(51000) << "Writing token value as ########### " << m_talker->token() << " #######" ;
-    saveSettings();
-    e->accept();
-}
-
 void PicasawebWindow::saveSettings() 
 {
     KConfig config("kipirc");
     KConfigGroup grp = config.group("PicasawebExport Settings");
-    kDebug(51000) << "Writing token value as ########### " << m_talker->token() << " #######" ;
-    grp.writeEntry("token", m_talker->token());
-    grp.writeEntry("username", m_username);
-    grp.writeEntry("Resize", m_resizeCheckBox->isChecked());
-    grp.writeEntry("Maximum Width",  m_dimensionSpinBox->value());
-    grp.writeEntry("Image Quality",  m_imageQualitySpinBox->value());
+    kDebug() << "Writing token value as ########### " << m_talker->token() << " #######" ;
+    grp.writeEntry("token",         m_talker->token());
+    grp.writeEntry("username",      m_username);
+    grp.writeEntry("Resize",        m_resizeCheckBox->isChecked());
+    grp.writeEntry("Maximum Width", m_dimensionSpinBox->value());
+    grp.writeEntry("Image Quality", m_imageQualitySpinBox->value());
 }
 
 PicasawebWindow::~PicasawebWindow()
 {
-    // write config
     delete m_urls;
-
     delete m_progressDlg;
     delete m_authProgressDlg;
     delete m_talker;
     delete m_widget;
-
     delete m_about;
 }
 
@@ -309,11 +308,11 @@ void PicasawebWindow::slotGetAlbumsListSucceeded()
     m_albumsListComboBox->clear();
     if (m_talker && m_talker->m_albumsList)
     {
-        QLinkedList <PicasaWebAlbum> *list = m_talker->m_albumsList;
+        QLinkedList <PicasaWebAlbum> *list       = m_talker->m_albumsList;
         QLinkedList<PicasaWebAlbum>::iterator it = list->begin();
         while(it != list->end())
         {
-            PicasaWebAlbum pwa=*it;
+            PicasaWebAlbum pwa = *it;
             m_albumsListComboBox->addItem(pwa.title, pwa.id);
             it++;
         }
@@ -352,7 +351,7 @@ void PicasawebWindow::slotError( const QString& msg )
 
 void PicasawebWindow::slotUserChangeRequest()
 {
-    kDebug(51000) << "Slot Change User Request ";
+    kDebug() << "Slot Change User Request ";
     m_talker->authenticate();
 }
 
@@ -387,9 +386,10 @@ void PicasawebWindow::slotCreateNewAlbum()
     {
         if (t == QDialog::Rejected)
         {
-            kDebug(51000) << "Album Creation cancelled" ;
+            kDebug() << "Album Creation cancelled" ;
         }
     }
+
     delete dlg;
 }
 
@@ -424,27 +424,23 @@ void PicasawebWindow::slotAddPhotos()
 
 void PicasawebWindow::slotUploadImages()
 {
-
     if (m_albumsListComboBox->currentIndex() == -1) 
     {
-        KMessageBox::error(this, 
-            i18n("No album selected - please create and select album."));
+        KMessageBox::error(this, i18n("No album selected - please create and select album."));
         return;
     }
-    m_currentAlbumId = m_albumsListComboBox->itemData(
-                            m_albumsListComboBox->currentIndex()).toString();
+    m_currentAlbumId = m_albumsListComboBox->itemData(m_albumsListComboBox->currentIndex()).toString();
 
     if (m_widget->m_currentSelectionButton->isChecked())
     {
         delete m_urls;
 
-        m_urls=new KUrl::List(m_interface->currentSelection().images());
+        m_urls = new KUrl::List(m_interface->currentSelection().images());
     }
 
     if (m_urls == NULL || m_urls->isEmpty()) 
     {
-        KMessageBox::error(this, 
-            i18n("Nothing to upload - please select photos to upload."));
+        KMessageBox::error(this, i18n("Nothing to upload - please select photos to upload."));
         return;
     }
 
@@ -508,7 +504,6 @@ void PicasawebWindow::slotUploadImages()
     slotAddPhotoNext();
 }
 
-
 void PicasawebWindow::slotAddPhotoNext()
 {
     if ( m_uploadQueue.isEmpty() )
@@ -521,11 +516,13 @@ void PicasawebWindow::slotAddPhotoNext()
 
     typedef QPair<QString,FPhotoInfo> Pair;
     Pair pathComments = m_uploadQueue.first();
-    FPhotoInfo info=pathComments.second;
+    FPhotoInfo info   = pathComments.second;
     m_uploadQueue.pop_front();
 
-/*    int upload_image_size;
-    int upload_image_quality;*/
+/*
+    int upload_image_size;
+    int upload_image_quality;
+*/
 
     bool res = m_talker->addPhoto(pathComments.first,          //the file path
                                   info, m_currentAlbumId,
@@ -583,7 +580,6 @@ void PicasawebWindow::slotAddPhotoCancel()
     m_uploadQueue.clear();
     m_progressDlg->reset();
     m_progressDlg->hide();
-
     m_talker->cancel();
 
     // refresh the thumbnails
