@@ -59,7 +59,7 @@ K_EXPORT_PLUGIN ( PrintImagesFactory ( "kipiplugin_printimages" ) )
 Plugin_PrintImages::Plugin_PrintImages ( QObject *parent, const QVariantList& /*args*/ )
                   : KIPI::Plugin ( PrintImagesFactory::componentData(), parent, "PrintImages" )
 {
-    kDebug(51001) << "Plugin_PrintImages plugin loaded" ;
+    kDebug(AREA_CODE_LOADING) << "Plugin_PrintImages plugin loaded" ;
 }
 
 void Plugin_PrintImages::setup ( QWidget* widget )
@@ -87,7 +87,7 @@ void Plugin_PrintImages::setup ( QWidget* widget )
 
     if ( !m_interface )
     {
-        kError( 51000 ) << "Kipi interface is null!";
+        kError() << "Kipi interface is null!";
         return;
     }
 
@@ -160,6 +160,6 @@ KIPI::Category Plugin_PrintImages::category ( KAction* action ) const
     if ( action == m_printImagesAction || action == m_printAssistantAction )
         return KIPI::ImagesPlugin;
 
-    kWarning ( 51000 ) << "Unrecognized action for plugin category identification";
+    kWarning () << "Unrecognized action for plugin category identification";
     return KIPI::ImagesPlugin; // no warning from compiler, please
 }
