@@ -36,9 +36,6 @@
 
 #include <libkdcraw/kdcraw.h>
 
-// Local includes
-// #include "utils.h"
-
 #define IMAGE_FILE_MASK "*"
 //"*.jpg;*.jpeg;*.JPG;*.JPEG;*.png;*.PNG"
 
@@ -46,11 +43,13 @@ namespace KIPIPrintImagesPlugin
 {
 
 TPhoto::TPhoto(int thumbnailSize)
-      : pAddInfo(NULL)
+      : pAddInfo(NULL), pCaptionInfo(NULL)
 {
     m_size = 0;
     cropRegion = QRect(-1, -1, -1, -1);
     rotation = 0;
+    first = false;
+
     copies = 1;
     //TODO mPrintPosition;
     filename = "";
@@ -61,12 +60,37 @@ TPhoto::TPhoto(int thumbnailSize)
     this->m_thumbnailSize = thumbnailSize;
 }
 
+//to get old photo info
+TPhoto::TPhoto (const TPhoto& photo): pAddInfo(NULL), pCaptionInfo(NULL)
+{
+  m_thumbnailSize = photo.m_thumbnailSize;
+  cropRegion      = photo.cropRegion;
+  filename        = photo.filename;
+  first           = photo.first;
+  copies          = photo.copies;
+  rotation        = photo.rotation;
+  
+  if (photo.pAddInfo)
+  {
+    pAddInfo = new AdditionalInfo(*photo.pAddInfo);
+  }
+  if (photo.pCaptionInfo)
+  {
+    pCaptionInfo = new CaptionInfo(*photo.pCaptionInfo);
+  }
+  
+  m_size       = 0;
+  m_exiv2Iface = NULL;
+  m_thumbnail  = NULL;
+}
+
 TPhoto::~TPhoto()
 {
     delete m_thumbnail;
     delete m_size;
     delete m_exiv2Iface;
     delete pAddInfo;
+    delete pCaptionInfo;
 }
 
 void TPhoto::loadCache()
