@@ -6,7 +6,7 @@
  * Date        : 2003-12-03
  * Description : a class to manage plugin actions using threads
  *
- * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -82,10 +82,10 @@ public:
     KDcrawIface::RawDecodingSettings rawDecodingSettings;
 };
 
-ActionThread::ActionThread(QObject *parent, bool updateFileTimeStamp)
+ActionThread::ActionThread(QObject* parent, bool updateFileTimeStamp)
             : QThread(parent), d(new ActionThreadPriv)
 {
-    qRegisterMetaType<ActionData>("ActionData");
+    qRegisterMetaType<ActionData>();
     d->dcrawIface.setUpdateFileTimeStamp(updateFileTimeStamp);
 }
 
@@ -344,7 +344,6 @@ void ActionThread::run()
                                 << endl;
                 }
             }
-
         }
 
         delete t;
