@@ -6,7 +6,7 @@
  * Date        : 2003-10-24
  * Description : Raw converter batch dialog
  *
- * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -226,7 +226,7 @@ BatchDialog::BatchDialog(KIPI::Interface* iface)
 
     d->about->addAuthor(ki18n("Renchi Raju"),
                        ki18n("Author"),
-                             "renchi at pooh dot tam dot uiuc dot edu");
+                             "renchi dot raju at gmail dot com");
 
     d->about->addAuthor(ki18n("Gilles Caulier"),
                        ki18n("Developer and maintainer"),
@@ -277,11 +277,11 @@ BatchDialog::BatchDialog(KIPI::Interface* iface)
     connect(this, SIGNAL(user2Clicked()),
             this, SLOT(slotRemoveItems()));
 
-    connect(d->thread, SIGNAL(starting(const ActionData&)),
-            this, SLOT(slotAction(const ActionData&)));
+    connect(d->thread, SIGNAL(starting(const KIPIRawConverterPlugin::ActionData&)),
+            this, SLOT(slotAction(const KIPIRawConverterPlugin::ActionData&)));
 
-    connect(d->thread, SIGNAL(finished(const ActionData&)),
-            this, SLOT(slotAction(const ActionData&)));
+    connect(d->thread, SIGNAL(finished(const KIPIRawConverterPlugin::ActionData&)),
+            this, SLOT(slotAction(const KIPIRawConverterPlugin::ActionData&)));
 
     connect(d->iface, SIGNAL(gotThumbnail( const KUrl&, const QPixmap& )),
             this, SLOT(slotThumbnail(const KUrl&, const QPixmap&)));
@@ -317,6 +317,7 @@ void BatchDialog::closeEvent(QCloseEvent *e)
     // Stop current conversion if necessary
     if (d->busy) slotStartStop();
     saveSettings();
+    d->listView->clear();
     e->accept();
 }
 
@@ -325,6 +326,7 @@ void BatchDialog::slotClose()
     // Stop current conversion if necessary
     if (d->busy) slotStartStop();
     saveSettings();
+    d->listView->clear();
     done(Close);
 }
 
@@ -568,7 +570,7 @@ void BatchDialog::addItems(const KUrl::List& itemList)
         QFileInfo fi(url.path());
         if (fi.exists() && !findItem(url))
         {
-            QString dest = fi.baseName() + QString(".") + ext;
+            QString dest = fi.completeBaseName() + QString(".") + ext;
             new CListViewItem(d->listView, pix, url, dest);
             urlList.append(url);
         }
@@ -629,7 +631,7 @@ void BatchDialog::slotSaveFormatChanged()
             if (lvItem->isEnabled())
             {
                 QFileInfo fi(lvItem->url().path());
-                QString dest = fi.baseName() + QString(".") + ext;
+                QString dest = fi.completeBaseName() + QString(".") + ext;
                 lvItem->setDestFileName(dest);
             }
         }
@@ -776,7 +778,7 @@ void BatchDialog::processingFailed(const KUrl& /*url*/)
     d->currentConvertItem = 0;
 }
 
-void BatchDialog::slotAction(const ActionData& ad)
+void BatchDialog::slotAction(const KIPIRawConverterPlugin::ActionData& ad)
 {
     QString text;
 
@@ -795,7 +797,7 @@ void BatchDialog::slotAction(const ActionData& ad)
             }
             default:
             {
-                kWarning(51000) << "KIPIRawConverterPlugin: Unknown action";
+                kWarning() << "KIPIRawConverterPlugin: Unknown action";
                 break;
             }
         }
@@ -817,7 +819,7 @@ void BatchDialog::slotAction(const ActionData& ad)
                 }
                 default:
                 {
-                    kWarning(51000) << "KIPIRawConverterPlugin: Unknown action";
+                    kWarning() << "KIPIRawConverterPlugin: Unknown action";
                     break;
                 }
             }
@@ -856,7 +858,7 @@ void BatchDialog::slotAction(const ActionData& ad)
                 }
                 default:
                 {
-                    kWarning(51000) << "KIPIRawConverterPlugin: Unknown action";
+                    kWarning() << "KIPIRawConverterPlugin: Unknown action";
                     break;
                 }
             }
