@@ -6,7 +6,7 @@
  * Date        : 2003-10-22
  * Description : Raw converter single dialog
  *
- * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -131,10 +131,7 @@ public:
 SingleDialog::SingleDialog(const QString& file, KIPI::Interface* iface)
             : KDialog(0), d(new SingleDialogPriv)
 {
-    d->iface         = iface;
-    d->inputFile     = file;
-    d->inputFileName = QFileInfo(file).fileName();
-
+    d->iface = iface;
     setButtons(Help | Default | User1 | User2 | User3 | Close);
     setDefaultButton(KDialog::Close);
     setButtonText(User1, i18n("&Preview"));
@@ -185,7 +182,7 @@ SingleDialog::SingleDialog(const QString& file, KIPI::Interface* iface)
 
     d->about->addAuthor(ki18n("Renchi Raju"),
                        ki18n("Author"),
-                             "renchi at pooh dot tam dot uiuc dot edu");
+                             "renchi dot raju at gmail dot com");
 
     d->about->addAuthor(ki18n("Gilles Caulier"),
                        ki18n("Developer and maintainer"),
@@ -248,17 +245,17 @@ SingleDialog::SingleDialog(const QString& file, KIPI::Interface* iface)
     connect(this, SIGNAL(user3Clicked()),
             this, SLOT(slotUser3()));
 
-    connect(d->thread, SIGNAL(starting(const ActionData&)),
-            this, SLOT(slotAction(const ActionData&)));
+    connect(d->thread, SIGNAL(starting(const KIPIRawConverterPlugin::ActionData&)),
+            this, SLOT(slotAction(const KIPIRawConverterPlugin::ActionData&)));
 
-    connect(d->thread, SIGNAL(finished(const ActionData&)),
-            this, SLOT(slotAction(const ActionData&)));
+    connect(d->thread, SIGNAL(finished(const KIPIRawConverterPlugin::ActionData&)),
+            this, SLOT(slotAction(const KIPIRawConverterPlugin::ActionData&)));
 
     // ---------------------------------------------------------------
 
     busy(false);
     readSettings();
-    QTimer::singleShot(0, this, SLOT( slotIdentify() ) );
+    setFile(file);
 }
 
 SingleDialog::~SingleDialog()
@@ -268,6 +265,13 @@ SingleDialog::~SingleDialog()
     delete d;
 }
 
+void SingleDialog::setFile(const QString& file)
+{
+    d->inputFile     = file;
+    d->inputFileName = QFileInfo(file).fileName();
+    QTimer::singleShot(0, this, SLOT( slotIdentify() ));
+}
+
 void SingleDialog::slotHelp()
 {
     KToolInvocation::invokeHelp("rawconverter", "kipi-plugins");
@@ -566,7 +570,7 @@ void SingleDialog::processed(const KUrl& url, const QString& tmpFile)
 
     filter += ext;
     QFileInfo fi(d->inputFile.path());
-    QString destFile = fi.absolutePath() + QString("/") + fi.baseName() + QString(".") + ext;
+    QString destFile = fi.absolutePath() + QString("/") + fi.completeBaseName() + QString(".") + ext;
 
     if (d->saveSettingsBox->conflictRule() != SaveSettingsWidget::OVERWRITE)
     {
@@ -646,7 +650,7 @@ void SingleDialog::slotConvertBlinkTimerDone()
     d->blinkConvertTimer->start(200);
 }
 
-void SingleDialog::slotAction(const ActionData& ad)
+void SingleDialog::slotAction(const KIPIRawConverterPlugin::ActionData& ad)
 {
     QString text;
 
@@ -671,7 +675,7 @@ void SingleDialog::slotAction(const ActionData& ad)
             }
             default:
             {
-                kWarning(51000) << "KIPIRawConverterPlugin: Unknown action";
+                kWarning() << "KIPIRawConverterPlugin: Unknown action";
                 break;
             }
         }
@@ -699,7 +703,7 @@ void SingleDialog::slotAction(const ActionData& ad)
                 }
                 default:
                 {
-                    kWarning(51000) << "KIPIRawConverterPlugin: Unknown action";
+                    kWarning() << "KIPIRawConverterPlugin: Unknown action";
                     break;
                 }
             }
@@ -735,7 +739,7 @@ void SingleDialog::slotAction(const ActionData& ad)
                 }
                 default:
                 {
-                    kWarning(51000) << "KIPIRawConverterPlugin: Unknown action";
+                    kWarning() << "KIPIRawConverterPlugin: Unknown action";
                     break;
                 }
             }
