@@ -6,7 +6,7 @@
  * Date        : 2003-10-22
  * Description : Raw converter single dialog
  *
- * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -56,6 +56,8 @@ public:
     SingleDialog(const QString& file, KIPI::Interface* iface);
     ~SingleDialog();
 
+    void setFile(const QString& file);
+
 protected:
 
     void closeEvent(QCloseEvent *e);
@@ -92,7 +94,7 @@ private Q_SLOTS:
     void slotPreviewBlinkTimerDone();
     void slotConvertBlinkTimerDone();
 
-    void slotAction(const ActionData&);
+    void slotAction(const KIPIRawConverterPlugin::ActionData&);
 
     void slotThumbnail(const KUrl&, const QPixmap&);
 
