@@ -46,12 +46,7 @@ public:
     MyImagesList(KIPI::Interface *iface, QWidget* parent = 0);
     ~MyImagesList();
 
-    int totalImages() const;
-    int processedImages() const;
-    int failedImages() const;
-
     bool hasUnprocessedImages();
-
     void removeUnprocessedImages();
     void resetEyeCounterColumn();
 
@@ -59,11 +54,6 @@ public Q_SLOTS:
 
     void addEyeCounterByUrl(const KUrl&, int);
 
-private Q_SLOTS:
-
-    void updateSummary();
-    void resetCounters();
-
 private:
 
     MyImagesListPriv* const d;
