@@ -5,10 +5,10 @@
  *
  * Date        : 2005-17-06
  * Description : a kipi plugin to import/export images to/from
-                 SmugMug web service
+ *                SmugMug web service
  *
  * Copyright (C) 2005-2008 by Vardhman Jain <vardhman at gmail dot com>
- * Copyright (C) 2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2008-2009 by Luka Renko <lure at kubuntu dot org>
  *
  * This program is free software; you can redistribute it
@@ -27,12 +27,15 @@
 #include "smugwindow.moc"
 
 // Qt includes
+
 #include <QFileInfo>
 #include <QSpinBox>
 #include <QCheckBox>
 #include <QGroupBox>
+#include <QCloseEvent>
 
 // KDE includes
+
 #include <KDebug>
 #include <KConfig>
 #include <KLocale>
@@ -47,9 +50,11 @@
 #include <KToolInvocation>
 
 // LibKExiv2 includes
+
 #include <libkexiv2/kexiv2.h>
 
 // LibKDcraw includes
+
 #include <libkdcraw/version.h>
 #include <libkdcraw/kdcraw.h>
 
@@ -58,13 +63,15 @@
 #endif
 
 // LibKIPI includes
+
 #include <libkipi/interface.h>
 #include <libkipi/uploadwidget.h>
+
+// Local includes
+
 #include "imageslist.h"
 #include "kpaboutdata.h"
 #include "pluginsversion.h"
-
-// Local includes
 #include "smugitem.h"
 #include "smugtalker.h"
 #include "smugwidget.h"
@@ -73,17 +80,17 @@
 namespace KIPISmugPlugin
 {
 
-SmugWindow::SmugWindow(KIPI::Interface* interface, const QString &tmpFolder,
-                       bool import, QWidget *parent)
-            : KDialog(parent)
+SmugWindow::SmugWindow(KIPI::Interface* interface, const QString& tmpFolder,
+                       bool import, QWidget* /*parent*/)
+          : KDialog(0)
 {
     m_tmpPath.clear();
-    m_tmpDir                 = tmpFolder;
-    m_interface              = interface;
-    m_import                 = import;
-    m_imagesCount            = 0;
-    m_imagesTotal            = 0;
-    m_widget                 = new SmugWidget(this, interface, import);
+    m_tmpDir      = tmpFolder;
+    m_interface   = interface;
+    m_import      = import;
+    m_imagesCount = 0;
+    m_imagesTotal = 0;
+    m_widget      = new SmugWidget(this, interface, import);
 
     setMainWidget(m_widget);
     setWindowIcon(KIcon("smugmug"));
@@ -128,12 +135,13 @@ SmugWindow::SmugWindow(KIPI::Interface* interface, const QString &tmpFolder,
             this, SLOT( slotStartTransfer()) );
 
     // ------------------------------------------------------------------------
+
     m_about = new KIPIPlugins::KPAboutData(ki18n("Smug Import/Export"), 0,
                       KAboutData::License_GPL,
                       ki18n("A Kipi plugin to import/export image collections "
                             "from/to the SmugMug web service."),
                       ki18n("(c) 2005-2008, Vardhman Jain\n"
-                            "(c) 2008, Gilles Caulier\n"
+                            "(c) 2008-2009, Gilles Caulier\n"
                             "(c) 2008-2009, Luka Renko"));
 
     m_about->addAuthor(ki18n("Luka Renko"), ki18n("Author and maintainer"),
@@ -206,7 +214,7 @@ SmugWindow::SmugWindow(KIPI::Interface* interface, const QString &tmpFolder,
 
     readSettings();
 
-    kDebug(51000) << "Calling Login method";
+    kDebug() << "Calling Login method";
     buttonStateChange(m_talker->loggedIn());
 
 
@@ -238,6 +246,39 @@ SmugWindow::~SmugWindow()
     delete m_about;
 }
 
+void SmugWindow::slotHelp()
+{
+    KToolInvocation::invokeHelp("smug", "kipi-plugins");
+}
+
+void SmugWindow::closeEvent(QCloseEvent *e)
+{
+    if (!e) return;
+
+    if (m_talker->loggedIn())
+        m_talker->logout();
+
+    writeSettings();
+    m_widget->imagesList()->listView()->clear();
+    e->accept();
+}
+
+void SmugWindow::slotClose()
+{
+    if (m_talker->loggedIn())
+        m_talker->logout();
+
+    writeSettings();
+    m_widget->imagesList()->listView()->clear();
+    done(Close);
+}
+
+void SmugWindow::reactivate()
+{
+    m_widget->imagesList()->loadImagesFromCurrentSelection();
+    show();
+}
+
 void SmugWindow::authenticate(const QString& email, const QString& password)
 {
     m_authProgressDlg = new KProgressDialog(this, i18n("Authentication"));
@@ -255,11 +296,11 @@ void SmugWindow::authenticate(const QString& email, const QString& password)
 void SmugWindow::readSettings()
 {
     KConfig config("kipirc");
-    KConfigGroup grp = config.group("Smug Settings");
+    KConfigGroup grp  = config.group("Smug Settings");
     m_anonymousImport = grp.readEntry("AnonymousImport", true);
-    m_email = grp.readEntry("Email");
-    m_password = grp.readEntry("Password");
-    m_currentAlbumID = grp.readEntry("Current Album", -1);
+    m_email           = grp.readEntry("Email");
+    m_password        = grp.readEntry("Password");
+    m_currentAlbumID  = grp.readEntry("Current Album", -1);
 
     if (grp.readEntry("Resize", false))
     {
@@ -293,12 +334,12 @@ void SmugWindow::writeSettings()
     KConfig config("kipirc");
     KConfigGroup grp = config.group("Smug Settings");
     grp.writeEntry("AnonymousImport", m_anonymousImport);
-    grp.writeEntry("Email", m_email);
-    grp.writeEntry("Password", m_password);
-    grp.writeEntry("Current Album", m_currentAlbumID);
-    grp.writeEntry("Resize", m_widget->m_resizeChB->isChecked());
-    grp.writeEntry("Maximum Width",  m_widget->m_dimensionSpB->value());
-    grp.writeEntry("Image Quality",  m_widget->m_imageQualitySpB->value());
+    grp.writeEntry("Email",           m_email);
+    grp.writeEntry("Password",        m_password);
+    grp.writeEntry("Current Album",   m_currentAlbumID);
+    grp.writeEntry("Resize",          m_widget->m_resizeChB->isChecked());
+    grp.writeEntry("Maximum Width",   m_widget->m_dimensionSpB->value());
+    grp.writeEntry("Image Quality",   m_widget->m_imageQualitySpB->value());
     if (m_import)
     {
         KConfigGroup dialogGroup = config.group("Smug Import Dialog");
@@ -312,21 +353,6 @@ void SmugWindow::writeSettings()
     config.sync();
 }
 
-void SmugWindow::slotHelp()
-{
-    KToolInvocation::invokeHelp("smug", "kipi-plugins");
-}
-
-void SmugWindow::slotClose()
-{
-    if (m_talker->loggedIn())
-        m_talker->logout();
-
-    writeSettings();
-
-    done(Close);
-}
-
 void SmugWindow::slotLoginProgress(int step, int maxStep, const QString &label)
 {
     if (!m_authProgressDlg)
@@ -363,8 +389,10 @@ void SmugWindow::slotLoginDone(int errCode, const QString &errMsg)
             }
         }
         else
+        {
             // get albums from current user
             m_talker->listAlbums();
+        }
     }
     else
     {
@@ -392,12 +420,10 @@ void SmugWindow::slotListAlbumsDone(int errCode, const QString &errMsg,
         else
             albumIcon = "folder";
 
-        m_widget->m_albumsCoB->addItem(
-            KIcon(albumIcon),
-            albumsList.at(i).title,
-            albumsList.at(i).id);
-       if (m_currentAlbumID == albumsList.at(i).id)
-           m_widget->m_albumsCoB->setCurrentIndex(i);
+        m_widget->m_albumsCoB->addItem(KIcon(albumIcon), albumsList.at(i).title, albumsList.at(i).id);
+
+        if (m_currentAlbumID == albumsList.at(i).id)
+            m_widget->m_albumsCoB->setCurrentIndex(i);
     }
 }
 
@@ -459,15 +485,13 @@ void SmugWindow::slotListAlbumTmplDone(int errCode, const QString &errMsg,
         else
             albumIcon = "folder";
 
-        m_albumDlg->m_templateCoB->addItem(
-            KIcon(albumIcon),
-            albumTList.at(i).name,
-            albumTList.at(i).id);
-       if (m_currentTmplID == albumTList.at(i).id)
-           m_albumDlg->m_templateCoB->setCurrentIndex(i+1);
+        m_albumDlg->m_templateCoB->addItem(KIcon(albumIcon), albumTList.at(i).name, albumTList.at(i).id);
+
+        if (m_currentTmplID == albumTList.at(i).id)
+            m_albumDlg->m_templateCoB->setCurrentIndex(i+1);
     }
-    m_currentTmplID = m_albumDlg->m_templateCoB->itemData(
-                          m_albumDlg->m_templateCoB->currentIndex()).toInt();
+
+    m_currentTmplID = m_albumDlg->m_templateCoB->itemData(m_albumDlg->m_templateCoB->currentIndex()).toInt();
 
     // now fill in categories
     m_talker->listCategories();
@@ -483,6 +507,7 @@ void SmugWindow::slotListCategoriesDone(int errCode, const QString &errMsg,
     }
 
     m_albumDlg->m_categCoB->clear();
+
     for (int i = 0; i < categoriesList.size(); ++i)
     {
         m_albumDlg->m_categCoB->addItem(
@@ -491,6 +516,7 @@ void SmugWindow::slotListCategoriesDone(int errCode, const QString &errMsg,
        if (m_currentCategoryID == categoriesList.at(i).id)
            m_albumDlg->m_categCoB->setCurrentIndex(i);
     }
+
     m_currentCategoryID = m_albumDlg->m_categCoB->itemData(
                           m_albumDlg->m_categCoB->currentIndex()).toInt();
     m_talker->listSubCategories(m_currentCategoryID);
@@ -563,7 +589,7 @@ void SmugWindow::slotBusy(bool val)
 
 void SmugWindow::slotUserChangeRequest(bool anonymous)
 {
-    kDebug(51000) << "Slot Change User Request";
+    kDebug() << "Slot Change User Request";
 
     if (m_talker->loggedIn())
         m_talker->logout();
@@ -602,14 +628,14 @@ void SmugWindow::slotReloadAlbumsRequest()
 
 void SmugWindow::slotNewAlbumRequest()
 {
-    kDebug(51000) << "Slot New Album Request";
+    kDebug() << "Slot New Album Request";
 
     // get list of album templates from SmugMug to fill in dialog
     m_talker->listAlbumTmpl();
 
     if (m_albumDlg->exec() == QDialog::Accepted)
     {
-        kDebug(51000) << "Calling New Album method";
+        kDebug() << "Calling New Album method";
         m_currentTmplID = m_albumDlg->m_templateCoB->itemData(
                         m_albumDlg->m_templateCoB->currentIndex()).toInt();
         m_currentCategoryID = m_albumDlg->m_categCoB->itemData(
@@ -629,7 +655,7 @@ void SmugWindow::slotLoginCancel()
 
 void SmugWindow::slotStartTransfer()
 {
-    kDebug(51000) << "slotStartTransfer invoked";
+    kDebug() << "slotStartTransfer invoked";
 
     if (m_import)
     {
@@ -647,7 +673,7 @@ void SmugWindow::slotStartTransfer()
             return;
 
         m_currentAlbumID = m_widget->m_albumsCoB->itemData(
-                                    m_widget->m_albumsCoB->currentIndex()).toInt();
+                                     m_widget->m_albumsCoB->currentIndex()).toInt();
         m_imagesTotal = m_transferQueue.count();
         m_imagesCount = 0;
 
@@ -661,9 +687,9 @@ void SmugWindow::slotStartTransfer()
         connect(m_progressDlg, SIGNAL( cancelClicked() ),
                 this, SLOT( slotTransferCancel() ));
 
-        kDebug(51000) << "m_currentAlbumID" << m_currentAlbumID;
+        kDebug() << "m_currentAlbumID" << m_currentAlbumID;
         uploadNextPhoto();
-        kDebug(51000) << "slotStartTransfer done";
+        kDebug() << "slotStartTransfer done";
     }
 }
 
@@ -672,29 +698,32 @@ bool SmugWindow::prepareImageForUpload(const QString& imgPath, bool isRAW)
     QImage image;
     if (isRAW)
     {
-        kDebug(51000) << "Get RAW preview " << imgPath;
+        kDebug() << "Get RAW preview " << imgPath;
         KDcrawIface::KDcraw::loadDcrawPreview(image, imgPath);
     }
     else
-        image.load(imgPath);
+    {
+       image.load(imgPath);
+    }
 
     if (image.isNull())
         return false;
 
     // get temporary file name
-    m_tmpPath = m_tmpDir + QFileInfo(imgPath).baseName().trimmed() + ".jpg";
+    m_tmpPath  = m_tmpDir + QFileInfo(imgPath).baseName().trimmed() + ".jpg";
 
     // rescale image if requested
     int maxDim = m_widget->m_dimensionSpB->value();
+
     if (m_widget->m_resizeChB->isChecked()
-        && (image.width() > maxDim || image.width() > maxDim))
+        && (image.width() > maxDim || image.height() > maxDim))
     {
-        kDebug(51000) << "Resizing to " << maxDim;
+        kDebug() << "Resizing to " << maxDim;
         image = image.scaled(maxDim, maxDim, Qt::KeepAspectRatio,
                                              Qt::SmoothTransformation);
     }
 
-    kDebug(51000) << "Saving to temp file: " << m_tmpPath;
+    kDebug() << "Saving to temp file: " << m_tmpPath;
     image.save(m_tmpPath, "JPEG", m_widget->m_imageQualitySpB->value());
 
     // copy meta data to temporary image
@@ -705,6 +734,7 @@ bool SmugWindow::prepareImageForUpload(const QString& imgPath, bool isRAW)
         exiv2Iface.setImageProgramId("Kipi-plugins", kipiplugins_version);
         exiv2Iface.save(m_tmpPath);
     }
+
     return true;
 }
 
@@ -730,6 +760,7 @@ void SmugWindow::uploadNextPhoto()
     QFileInfo fileInfo(imgPath);
     bool isRAW = rawFilesExt.toUpper().contains(fileInfo.suffix().toUpper());
     bool res;
+
     if (isRAW || m_widget->m_resizeChB->isChecked())
     {
         if (!prepareImageForUpload(imgPath, isRAW))
@@ -744,6 +775,7 @@ void SmugWindow::uploadNextPhoto()
         m_tmpPath.clear();
         res = m_talker->addPhoto(imgPath, m_currentAlbumID);
     }
+
     if (!res)
     {
         slotAddPhotoDone(666, i18n("Cannot open file"));
