@@ -51,7 +51,7 @@ K_EXPORT_PLUGIN ( TimeAdjustFactory("kipiplugin_timeadjust") )
 Plugin_TimeAdjust::Plugin_TimeAdjust(QObject *parent, const QVariantList&)
                  : KIPI::Plugin( TimeAdjustFactory::componentData(), parent, "TimeAdjust")
 {
-    kDebug(51001) << "Plugin_TimeAdjust plugin loaded";
+    kDebug(AREA_CODE_LOADING) << "Plugin_TimeAdjust plugin loaded";
 }
 
 Plugin_TimeAdjust::~Plugin_TimeAdjust()
@@ -74,7 +74,7 @@ void Plugin_TimeAdjust::setup(QWidget* widget)
     m_interface = dynamic_cast< KIPI::Interface* >(parent());
     if (!m_interface)
     {
-       kError( 51000 ) << "Kipi interface is null!";
+       kError() << "Kipi interface is null!";
        return;
     }
 
@@ -103,6 +103,6 @@ KIPI::Category Plugin_TimeAdjust::category( KAction* action ) const
     if ( action == m_actionTimeAjust )
        return KIPI::ImagesPlugin;
 
-    kWarning( 51000 ) << "Unrecognized action for plugin category identification";
+    kWarning() << "Unrecognized action for plugin category identification";
     return KIPI::ImagesPlugin; // no warning from compiler, please
 }
