@@ -53,7 +53,7 @@ K_EXPORT_PLUGIN ( WallPaperFactory("kipiplugin_wallpaper") )
 Plugin_WallPaper::Plugin_WallPaper(QObject *parent, const QVariantList&)
                 : KIPI::Plugin(WallPaperFactory::componentData(), parent, "WallPaper")
 {
-    kDebug(51001) << "Plugin_WallPaper plugin loaded";
+    kDebug(AREA_CODE_LOADING) << "Plugin_WallPaper plugin loaded";
 }
 
 void Plugin_WallPaper::setup( QWidget* widget )
@@ -112,7 +112,7 @@ void Plugin_WallPaper::setup( QWidget* widget )
 
     if ( !interface )
     {
-        kError( 51000 ) << "Kipi interface is null!";
+        kError() << "Kipi interface is null!";
         return;
     }
 
@@ -172,7 +172,7 @@ void Plugin_WallPaper::setWallpaper(int layout)
 
    if ( !interface )
    {
-       kError( 51000 ) << "Kipi interface is null!";
+       kError() << "Kipi interface is null!";
        return;
    }
 
@@ -211,6 +211,6 @@ KIPI::Category  Plugin_WallPaper::category( KAction* action ) const
     if ( action == m_actionBackground )
        return KIPI::IMAGESPLUGIN;
 
-    kWarning( 51000 ) << "Unrecognized action for plugin category identification";
+    kWarning() << "Unrecognized action for plugin category identification";
     return KIPI::IMAGESPLUGIN; // no warning from compiler, please
 }
